@@ -2,7 +2,7 @@
  * Routines to put up various "standard" alert boxes used in multiple
  * places
  *
- * $Id: alert_box.c,v 1.7 2004/05/09 10:03:36 guy Exp $
+ * $Id: alert_box.c 12852 2004-12-29 01:08:20Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -113,7 +113,7 @@ bad_dfilter_alert_box(const char *dftext)
   simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, 
                 "%s%s%s\n"
                 "\n"
-                "The filter expression \"%s\" is not a valid display filter.\n"
+                "The filter expression \"%s\" isn't a valid display filter.\n"
                 "See the help for a description of the display filter syntax.",
                 simple_dialog_primary_start(), dfilter_error_msg,
                 simple_dialog_primary_end(), dftext);
