@@ -3,7 +3,7 @@
  * time, so that we only need one Ethereal binary and one Tethereal binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
- * $Id: capture-wpcap.c,v 1.10 2004/06/12 07:47:12 guy Exp $
+ * $Id: capture-wpcap.c 12109 2004-09-27 01:11:23Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -69,6 +69,12 @@ static int     (*p_pcap_loop) (pcap_t *, int, pcap_handler, guchar *);
 static int     (*p_pcap_findalldevs) (pcap_if_t **, char *);
 static void    (*p_pcap_freealldevs) (pcap_if_t *);
 #endif
+#ifdef HAVE_PCAP_DATALINK_NAME_TO_VAL
+static int (*p_pcap_datalink_name_to_val) (const char *);
+#endif
+#ifdef HAVE_PCAP_DATALINK_VAL_TO_NAME
+static const char *(*p_pcap_datalink_val_to_name) (int);
+#endif
 static const char *(*p_pcap_lib_version) (void);
 static int     (*p_pcap_setbuff) (pcap_t *, int dim);
 
@@ -101,6 +107,12 @@ load_wpcap(void)
 #ifdef HAVE_PCAP_FINDALLDEVS
 		SYM(pcap_findalldevs, TRUE),
 		SYM(pcap_freealldevs, TRUE),
+#endif
+#ifdef HAVE_PCAP_DATALINK_NAME_TO_VAL
+		SYM(pcap_datalink_name_to_val, TRUE),
+#endif
+#ifdef HAVE_PCAP_DATALINK_VAL_TO_NAME
+		SYM(pcap_datalink_val_to_name, TRUE),
 #endif
 		SYM(pcap_lib_version, TRUE),
 		SYM(pcap_setbuff, TRUE),
@@ -250,6 +262,148 @@ pcap_freealldevs(pcap_if_t *a)
 }
 #endif
 
+#if defined(HAVE_PCAP_DATALINK_NAME_TO_VAL) || defined(HAVE_PCAP_DATALINK_VAL_TO_NAME)
+/*
+ * Table of DLT_ types, names, and descriptions, for use if the version
+ * of WinPcap we have installed lacks "pcap_datalink_name_to_val()"
+ * or "pcap_datalink_val_to_name()".
+ */
+struct dlt_choice {
+	const char *name;
+	const char *description;
+	int	dlt;
+};
+
+#define DLT_CHOICE(code, description) { #code, description, code }
+#define DLT_CHOICE_SENTINEL { NULL, NULL, 0 }
+
+static struct dlt_choice dlt_choices[] = {
+	DLT_CHOICE(DLT_NULL, "BSD loopback"),
+	DLT_CHOICE(DLT_EN10MB, "Ethernet"),
+	DLT_CHOICE(DLT_IEEE802, "Token ring"),
+	DLT_CHOICE(DLT_ARCNET, "ARCNET"),
+	DLT_CHOICE(DLT_SLIP, "SLIP"),
+	DLT_CHOICE(DLT_PPP, "PPP"),
+	DLT_CHOICE(DLT_FDDI, "FDDI"),
+	DLT_CHOICE(DLT_ATM_RFC1483, "RFC 1483 IP-over-ATM"),
+	DLT_CHOICE(DLT_RAW, "Raw IP"),
+#ifdef DLT_SLIP_BSDOS
+	DLT_CHOICE(DLT_SLIP_BSDOS, "BSD/OS SLIP"),
+#endif
+#ifdef DLT_PPP_BSDOS
+	DLT_CHOICE(DLT_PPP_BSDOS, "BSD/OS PPP"),
+#endif
+#ifdef DLT_ATM_CLIP
+	DLT_CHOICE(DLT_ATM_CLIP, "Linux Classical IP-over-ATM"),
+#endif
+#ifdef DLT_PPP_SERIAL
+	DLT_CHOICE(DLT_PPP_SERIAL, "PPP over serial"),
+#endif
+#ifdef DLT_PPP_ETHER
+	DLT_CHOICE(DLT_PPP_ETHER, "PPPoE"),
+#endif
+#ifdef DLT_C_HDLC
+	DLT_CHOICE(DLT_C_HDLC, "Cisco HDLC"),
+#endif
+#ifdef DLT_IEEE802_11
+	DLT_CHOICE(DLT_IEEE802_11, "802.11"),
+#endif
+#ifdef DLT_FRELAY
+	DLT_CHOICE(DLT_FRELAY, "Frame Relay"),
+#endif
+#ifdef DLT_LOOP
+	DLT_CHOICE(DLT_LOOP, "OpenBSD loopback"),
+#endif
+#ifdef DLT_ENC
+	DLT_CHOICE(DLT_ENC, "OpenBSD encapsulated IP"),
+#endif
+#ifdef DLT_LINUX_SLL
+	DLT_CHOICE(DLT_LINUX_SLL, "Linux cooked"),
+#endif
+#ifdef DLT_LTALK
+	DLT_CHOICE(DLT_LTALK, "Localtalk"),
+#endif
+#ifdef DLT_PFLOG
+	DLT_CHOICE(DLT_PFLOG, "OpenBSD pflog file"),
+#endif
+#ifdef DLT_PRISM_HEADER
+	DLT_CHOICE(DLT_PRISM_HEADER, "802.11 plus Prism header"),
+#endif
+#ifdef DLT_IP_OVER_FC
+	DLT_CHOICE(DLT_IP_OVER_FC, "RFC 2625 IP-over-Fibre Channel"),
+#endif
+#ifdef DLT_SUNATM
+	DLT_CHOICE(DLT_SUNATM, "Sun raw ATM"),
+#endif
+#ifdef DLT_IEEE802_11_RADIO
+	DLT_CHOICE(DLT_IEEE802_11_RADIO, "802.11 plus radio information header"),
+#endif
+#ifdef DLT_ARCNET_LINUX
+	DLT_CHOICE(DLT_ARCNET_LINUX, "Linux ARCNET"),
+#endif
+#ifdef DLT_LINUX_IRDA
+	DLT_CHOICE(DLT_LINUX_IRDA, "Linux IrDA"),
+#endif
+#ifdef DLT_LANE8023
+	DLT_CHOICE(DLT_LANE8023, "Linux 802.3 LANE"),
+#endif
+#ifdef DLT_CIP
+	DLT_CHOICE(DLT_CIP, "Linux Classical IP-over-ATM"),
+#endif
+#ifdef DLT_HDLC
+	DLT_CHOICE(DLT_HDLC, "Cisco HDLC"),
+#endif
+	DLT_CHOICE_SENTINEL
+};
+#endif /* defined(HAVE_PCAP_DATALINK_NAME_TO_VAL) || defined(HAVE_PCAP_DATALINK_VAL_TO_NAME) */
+
+#ifdef HAVE_PCAP_DATALINK_NAME_TO_VAL
+int
+pcap_datalink_name_to_val(const char *name)
+{
+	int i;
+
+	g_assert(has_wpcap);
+
+	if (p_pcap_datalink_name_to_val != NULL)
+		return p_pcap_datalink_name_to_val(name);
+	else {
+		/*
+		 * We don't have it in WinPcap; do it ourselves.
+		 */
+		for (i = 0; dlt_choices[i].name != NULL; i++) {
+			if (strcasecmp(dlt_choices[i].name + sizeof("DLT_") - 1,
+			    name) == 0)
+				return dlt_choices[i].dlt;
+		}
+		return -1;
+	}
+}
+#endif
+
+#ifdef HAVE_PCAP_DATALINK_VAL_TO_NAME
+const char *
+pcap_datalink_val_to_name(int dlt)
+{
+	int i;
+
+	g_assert(has_wpcap);
+
+	if (p_pcap_datalink_val_to_name != NULL)
+		return p_pcap_datalink_val_to_name(dlt);
+	else {
+		/*
+		 * We don't have it in WinPcap; do it ourselves.
+		 */
+		for (i = 0; dlt_choices[i].name != NULL; i++) {
+			if (dlt_choices[i].dlt == dlt)
+				return dlt_choices[i].name + sizeof("DLT_") - 1;
+		}
+		return NULL;
+	}
+}
+#endif
+
 /* setbuff is win32 specific! */
 int pcap_setbuff(pcap_t *a, int b)
 {
@@ -454,10 +608,23 @@ get_runtime_pcap_version(GString *str)
 	 * not and, if we have it and we have "pcap_lib_version()",
 	 * what version we have.
 	 */
+	GModule *handle;		/* handle returned by dlopen */
+	gchar *packetVer = NULL;
+
 	if (has_wpcap) {
+		/* An alternative method of obtaining the version number */
+		if ((handle = g_module_open("Packet.dll", 0)) != NULL) {
+			if (g_module_symbol(handle, "PacketLibraryVersion",
+			    (gpointer*)&packetVer) == FALSE)
+				packetVer = NULL;
+			g_module_close(handle);
+		}
+
 		g_string_sprintfa(str, "with ");
 		if (p_pcap_lib_version != NULL)
 			g_string_sprintfa(str, p_pcap_lib_version());
+		else if (packetVer != NULL)
+			g_string_sprintfa(str, "WinPcap (%s)", packetVer);
 		else
 			g_string_append(str, "WinPcap (version unknown)");
 	} else
