@@ -1,7 +1,7 @@
 /* capture.h
  * Definitions for packet capture windows
  *
- * $Id: capture.h,v 1.48 2004/07/06 19:16:03 gerald Exp $
+ * $Id: capture.h 12855 2004-12-29 12:37:06Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -35,26 +35,34 @@
 #ifdef HAVE_LIBPCAP
 
 /** Capture options coming from user interface */
-typedef struct {
+typedef struct capture_options_tag {
+    /* general */
 #ifdef _WIN32
     int buffer_size;        /**< the capture buffer size (MB) */
 #endif
 	gboolean has_snaplen;		/**< TRUE if maximum capture packet
 					   length is specified */
 	int snaplen;			/**< Maximum captured packet length */
-	int promisc_mode;		/**< Capture in promiscuous mode */
+	gboolean promisc_mode;  /**< Capture in promiscuous mode */
 	int linktype;			/**< Data link type to use, or -1 for
 					   "use default" */
-	int sync_mode;			/**< Fork a child to do the capture,
+	gboolean capture_child;	/**< True if this is the child for "-S" */
+
+    /* GUI related */
+	gboolean sync_mode;			/**< Fork a child to do the capture,
 					   and sync between them */
     gboolean show_info;     /**< show the info dialog */
+    gboolean quit_after_cap;    /** Makes a "capture only mode". Implies -k */
 
+    /* multiple files (and ringbuffer) */
     gboolean multi_files_on;    /**< TRUE if ring buffer in use */
 
 	gboolean has_file_duration;	/**< TRUE if ring duration specified */
 	gint32 file_duration;     /* Switch file after n seconds */
 	gboolean has_ring_num_files;/**< TRUE if ring num_files specified */
 	guint32 ring_num_files;	        /**< Number of multiple buffer files */
+
+    /* autostop conditions */
     gboolean has_autostop_files;/**< TRUE if maximum number of capture files
 					   are specified */
     gint32 autostop_files;      /**< Maximum number of capture files */
@@ -70,32 +78,29 @@ typedef struct {
 	gint32 autostop_duration;	/**< Maximum capture duration */
 } capture_options;
 
-/** Global capture options. */
-extern capture_options capture_opts;
-
-/** Makes a "capture only mode". Implies -k */
-extern gboolean quit_after_cap; 
-
-/** If this is the child for "-S" */
-extern gboolean capture_child;	
 
 /** Open a specified file, or create a temporary file, and start a capture
-   to the file in question.  Returns TRUE if the capture starts
-   successfully, FALSE otherwise. */
-gboolean do_capture(const char *save_file);
+ * to the file in question.  
+ *
+ * @return TRUE if the capture starts successfully, FALSE otherwise. */
+extern gboolean do_capture(capture_options *capture_opts, const char *save_file);
 
-/** Do the low-level work of a capture. */
-int    capture(gboolean *stats_known, struct pcap_stat *stats);
+/** Do the low-level work of a capture (start the capture child). */
+extern int  capture_start(capture_options *capture_opts, gboolean *stats_known, struct pcap_stat *stats);
 
 /** Stop a capture from a menu item. */
-void   capture_stop(void);
+extern void capture_stop(gboolean sync_mode);
 
 /** Terminate the capture child cleanly when exiting. */
-void   kill_capture_child(void);
+extern void kill_capture_child(gboolean sync_mode);
+
+/** Do the low-level work of a capture. */
+extern int  capture_loop_start(capture_options *capture_opts, gboolean *stats_known, struct pcap_stat *stats);
+
+/** Stop a low-level capture. */
+extern void capture_loop_stop(void);
+
 
-/** Number of packet counts.
- * @todo improve this macro (put something like this into epan/packet.h?) */
-#define CAPTURE_PACKET_COUNTS sizeof(packet_counts) / sizeof (gint)
 
 /** Current Capture info. */
 typedef struct {
