@@ -1,6 +1,6 @@
 /* dftest.c.c
  *
- * $Id: dftest.c 12180 2004-10-02 01:53:02Z guy $
+ * $Id: dftest.c 12834 2004-12-25 18:35:21Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -135,7 +135,7 @@ main(int argc, char **argv)
 		epan_cleanup();
 		exit(2);
 	}
-	printf("dfilter ptr = 0x%08x\n", (unsigned int) df);
+	printf("dfilter ptr = 0x%08x\n", GPOINTER_TO_INT(df));
 
 	printf("\n\n");
 
