@@ -1,7 +1,7 @@
 /* addr_resolv.c
  * Routines for network object lookup
  *
- * $Id: addr_resolv.c 12214 2004-10-06 07:25:38Z guy $
+ * $Id: addr_resolv.c 13090 2005-01-17 21:38:31Z guy $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -32,6 +32,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 
 /*
  * Win32 doesn't have SIGALRM (and it's the OS where name lookup calls
@@ -109,12 +110,16 @@
 # include <ws2tcpip.h>
 #endif
 
+#include <glib.h>
+
+#include "report_err.h"
 #include "packet.h"
 #include "ipv6-utils.h"
 #include "addr_resolv.h"
 #include "filesystem.h"
 #include <epan/prefs.h>
 
+#define ENAME_HOSTS		"hosts"
 #define ENAME_ETHERS 		"ethers"
 #define ENAME_IPXNETS 		"ipxnets"
 #define ENAME_MANUF		"manuf"
@@ -126,18 +131,38 @@
 #define HASHMANUFSIZE   256
 #define HASHPORTSIZE	256
 
-/* hash table used for host and port lookup */
+/* hash table used for IPv4 lookup */
 
 #define HASH_IPV4_ADDRESS(addr)	((addr) & (HASHHOSTSIZE - 1))
 
-#define HASH_PORT(port)	((port) & (HASHPORTSIZE - 1))
-
-typedef struct hashname {
+typedef struct hashipv4 {
   guint			addr;
   gchar   		name[MAXNAMELEN];
-  gboolean              is_dummy_entry;	/* name is IP address in dot format */
-  struct hashname 	*next;
-} hashname_t;
+  gboolean              is_dummy_entry;	/* name is IPv4 address in dot format */
+  struct hashipv4 	*next;
+} hashipv4_t;
+
+/* hash table used for IPv6 lookup */
+
+#define HASH_IPV6_ADDRESS(addr)	\
+	((((addr).s6_addr8[14] << 8)|((addr).s6_addr8[15])) & (HASHHOSTSIZE - 1))
+
+typedef struct hashipv6 {
+  struct e_in6_addr	addr;
+  gchar   		name[MAXNAMELEN];
+  gboolean              is_dummy_entry;	/* name is IPv6 address in colon format */
+  struct hashipv6 	*next;
+} hashipv6_t;
+
+/* hash table used for TCP/UDP/SCTP port lookup */
+
+#define HASH_PORT(port)	((port) & (HASHPORTSIZE - 1))
+
+typedef struct hashport {
+  guint16		port;
+  gchar   		name[MAXNAMELEN];
+  struct hashport 	*next;
+} hashport_t;
 
 /* hash table used for IPX network lookup */
 
@@ -145,7 +170,11 @@ typedef struct hashname {
 
 #define HASH_IPX_NET(net)	((net) & (HASHIPXNETSIZE - 1))
 
-typedef struct hashname hashipxnet_t;
+typedef struct hashipxnet {
+  guint			addr;
+  gchar   		name[MAXNAMELEN];
+  struct hashipxnet 	*next;
+} hashipxnet_t;
 
 /* hash tables used for ethernet and manufacturer lookup */
 
@@ -184,14 +213,15 @@ typedef struct _ipxnet
   char 			name[MAXNAMELEN];
 } ipxnet_t;
 
-static hashname_t 	*host_table[HASHHOSTSIZE];
-static hashname_t 	*udp_port_table[HASHPORTSIZE];
-static hashname_t 	*tcp_port_table[HASHPORTSIZE];
-static hashname_t       *sctp_port_table[HASHPORTSIZE];
-static hashether_t 	*eth_table[HASHETHSIZE];
-static hashmanuf_t 	*manuf_table[HASHMANUFSIZE];
-static hashether_t 	*(*wka_table[48])[HASHETHSIZE];
-static hashipxnet_t 	*ipxnet_table[HASHIPXNETSIZE];
+static hashipv4_t	*ipv4_table[HASHHOSTSIZE];
+static hashipv6_t	*ipv6_table[HASHHOSTSIZE];
+static hashport_t	*udp_port_table[HASHPORTSIZE];
+static hashport_t	*tcp_port_table[HASHPORTSIZE];
+static hashport_t	*sctp_port_table[HASHPORTSIZE];
+static hashether_t	*eth_table[HASHETHSIZE];
+static hashmanuf_t	*manuf_table[HASHMANUFSIZE];
+static hashether_t	*(*wka_table[48])[HASHETHSIZE];
+static hashipxnet_t	*ipxnet_table[HASHIPXNETSIZE];
 
 static int 		eth_resolution_initialized = 0;
 static int 		ipxnet_resolution_initialized = 0;
@@ -219,6 +249,8 @@ gchar *g_pipxnets_path = NULL;		/* personal ipxnets file */
 
 #ifdef HAVE_GNU_ADNS
 
+static gboolean gnu_adns_initialized = FALSE;
+
 adns_state ads;
 
 int adns_currently_queued = 0;
@@ -243,8 +275,8 @@ GList *adns_queue_head = NULL;
 static gchar *serv_name_lookup(guint port, port_type proto)
 {
   int hash_idx;
-  hashname_t *tp;
-  hashname_t **table;
+  hashport_t *tp;
+  hashport_t **table;
   char *serv_proto = NULL;
   struct servent *servp;
 
@@ -272,14 +304,14 @@ static gchar *serv_name_lookup(guint port, port_type proto)
   tp = table[hash_idx];
 
   if( tp == NULL ) {
-    tp = table[hash_idx] = (hashname_t *)g_malloc(sizeof(hashname_t));
+    tp = table[hash_idx] = (hashport_t *)g_malloc(sizeof(hashport_t));
   } else {
     while(1) {
-      if( tp->addr == port ) {
+      if( tp->port == port ) {
 	return tp->name;
       }
       if (tp->next == NULL) {
-	tp->next = (hashname_t *)g_malloc(sizeof(hashname_t));
+	tp->next = (hashport_t *)g_malloc(sizeof(hashport_t));
 	tp = tp->next;
 	break;
       }
@@ -288,7 +320,7 @@ static gchar *serv_name_lookup(guint port, port_type proto)
   }
 
   /* fill in a new entry */
-  tp->addr = port;
+  tp->port = port;
   tp->next = NULL;
 
   if (!(g_resolv_flags & RESOLV_TRANSPORT) ||
@@ -320,7 +352,7 @@ static void abort_network_query(int sig _U_)
 static gchar *host_name_lookup(guint addr, gboolean *found)
 {
   int hash_idx;
-  hashname_t * volatile tp;
+  hashipv4_t * volatile tp;
   struct hostent *hostp;
 #ifdef HAVE_GNU_ADNS
   adns_queue_msg_t *qmsg;
@@ -330,10 +362,10 @@ static gchar *host_name_lookup(guint addr, gboolean *found)
 
   hash_idx = HASH_IPV4_ADDRESS(addr);
 
-  tp = host_table[hash_idx];
+  tp = ipv4_table[hash_idx];
 
   if( tp == NULL ) {
-    tp = host_table[hash_idx] = (hashname_t *)g_malloc(sizeof(hashname_t));
+    tp = ipv4_table[hash_idx] = (hashipv4_t *)g_malloc(sizeof(hashipv4_t));
   } else {
     while(1) {
       if( tp->addr == addr ) {
@@ -342,7 +374,7 @@ static gchar *host_name_lookup(guint addr, gboolean *found)
 	return tp->name;
       }
       if (tp->next == NULL) {
-	tp->next = (hashname_t *)g_malloc(sizeof(hashname_t));
+	tp->next = (hashipv4_t *)g_malloc(sizeof(hashipv4_t));
 	tp = tp->next;
 	break;
       }
@@ -356,7 +388,8 @@ static gchar *host_name_lookup(guint addr, gboolean *found)
 
 #ifdef HAVE_GNU_ADNS
   if ((g_resolv_flags & RESOLV_CONCURRENT) && 
-      prefs.name_resolve_concurrency > 0) {
+      prefs.name_resolve_concurrency > 0 &&
+      gnu_adns_initialized) {
     qmsg = g_malloc(sizeof(adns_queue_msg_t));
     qmsg->type = AF_INET;
     qmsg->ip4_addr = addr;
@@ -420,10 +453,41 @@ static gchar *host_name_lookup(guint addr, gboolean *found)
 
 static gchar *host_name_lookup6(struct e_in6_addr *addr, gboolean *found)
 {
-  static gchar name[MAXNAMELEN];
+  int hash_idx;
+  hashipv6_t * volatile tp;
 #ifdef INET6
   struct hostent *hostp;
+#endif
 
+  *found = TRUE;
+
+  hash_idx = HASH_IPV6_ADDRESS(*addr);
+
+  tp = ipv6_table[hash_idx];
+
+  if( tp == NULL ) {
+    tp = ipv6_table[hash_idx] = (hashipv6_t *)g_malloc(sizeof(hashipv6_t));
+  } else {
+    while(1) {
+      if( memcmp(&tp->addr, addr, sizeof (struct e_in6_addr)) == 0 ) {
+	if (tp->is_dummy_entry)
+	  *found = FALSE;
+	return tp->name;
+      }
+      if (tp->next == NULL) {
+	tp->next = (hashipv6_t *)g_malloc(sizeof(hashipv6_t));
+	tp = tp->next;
+	break;
+      }
+      tp = tp->next;
+    }
+  }
+
+  /* fill in a new entry */
+  tp->addr = *addr;
+  tp->next = NULL;
+
+#ifdef INET6
   if (g_resolv_flags & RESOLV_NETWORK) {
 #ifdef AVOID_DNS_TIMEOUT
 
@@ -436,24 +500,29 @@ static gchar *host_name_lookup6(struct e_in6_addr *addr, gboolean *found)
       hostp = gethostbyaddr((char *)addr, sizeof(*addr), AF_INET6);
 #ifdef AVOID_DNS_TIMEOUT
       alarm(0);
-#endif
+# endif /* AVOID_DNS_TIMEOUT */
+
       if (hostp != NULL) {
-	strncpy(name, hostp->h_name, MAXNAMELEN);
-	name[MAXNAMELEN-1] = '\0';
-	*found = TRUE;
-	return name;
+	strncpy(tp->name, hostp->h_name, MAXNAMELEN);
+	tp->name[MAXNAMELEN-1] = '\0';
+	tp->is_dummy_entry = FALSE;
+	return tp->name;
       }
+
 #ifdef AVOID_DNS_TIMEOUT
     }
-#endif
+# endif /* AVOID_DNS_TIMEOUT */
+
   }
 
   /* unknown host or DNS timeout */
 #endif /* INET6 */
+  ip6_to_str_buf(addr, tp->name);
+  tp->is_dummy_entry = TRUE;
   *found = FALSE;
-  ip6_to_str_buf(addr, name);
-  return (name);
-}
+  return (tp->name);
+
+} /* host_name_lookup6 */
 
 /*
  *  Miscellaneous functions
@@ -628,7 +697,7 @@ static int parse_ether_line(char *line, ether_t *eth, unsigned int *mask,
 			    gboolean manuf_file)
 {
   /*
-   *  See man ethers(4) for ethers file format
+   *  See the ethers(4) or ethers(5) man page for ethers file format
    *  (not available on all systems).
    *  We allow both ethernet address separators (':' and '-'),
    *  as well as Ethereal's '.' separator.
@@ -639,13 +708,13 @@ static int parse_ether_line(char *line, ether_t *eth, unsigned int *mask,
   if ((cp = strchr(line, '#')))
     *cp = '\0';
 
-  if ((cp = strtok(line, " \t\n")) == NULL)
+  if ((cp = strtok(line, " \t")) == NULL)
     return -1;
 
   if (!parse_ether_address(cp, eth, mask, manuf_file))
     return -1;
 
-  if ((cp = strtok(NULL, " \t\n")) == NULL)
+  if ((cp = strtok(NULL, " \t")) == NULL)
     return -1;
 
   strncpy(eth->name, cp, MAXNAMELEN);
@@ -1439,22 +1508,142 @@ static guint ipxnet_addr_lookup(const gchar *name, gboolean *success)
 
 } /* ipxnet_addr_lookup */
 
+static gboolean
+read_hosts_file (const char *hostspath)
+{
+  FILE *hf;
+  char *line = NULL;
+  int size = 0;
+  gchar *cp;
+  guint32 host_addr[4]; /* IPv4 or IPv6 */
+  struct e_in6_addr ipv6_addr;
+  gboolean is_ipv6;
+  int ret;
+
+  /*
+   *  See the hosts(4) or hosts(5) man page for hosts file format
+   *  (not available on all systems).
+   */
+  if ((hf = fopen(hostspath, "r")) == NULL)
+    return FALSE;
+
+  while (fgetline(&line, &size, hf) >= 0) {
+    if ((cp = strchr(line, '#')))
+      *cp = '\0';
+
+    if ((cp = strtok(line, " \t")) == NULL)
+      continue; /* no tokens in the line */
+
+    ret = inet_pton(AF_INET6, cp, &host_addr);
+    if (ret == -1)
+      continue; /* error parsing */
+    if (ret == 1) {
+      /* Valid IPv6 */
+      is_ipv6 = TRUE;
+    } else {
+      /* Not valid IPv6 - valid IPv4? */
+      if (inet_pton(AF_INET, cp, &host_addr) != 1)
+        continue; /* no */
+      is_ipv6 = FALSE;
+    }
+
+    if ((cp = strtok(NULL, " \t")) == NULL)
+      continue; /* no host name */
+
+    if (is_ipv6) {
+      memcpy(&ipv6_addr, host_addr, sizeof ipv6_addr);
+      add_ipv6_name(&ipv6_addr, cp);
+    } else
+      add_ipv4_name(host_addr[0], cp);
+
+    /*
+     * Add the aliases, too, if there are any.
+     */
+    while ((cp = strtok(NULL, " \t")) != NULL) {
+      if (is_ipv6) {
+        memcpy(&ipv6_addr, host_addr, sizeof ipv6_addr);
+        add_ipv6_name(&ipv6_addr, cp);
+      } else
+        add_ipv4_name(host_addr[0], cp);
+    }
+  }
+  if (line != NULL)
+    g_free(line);
+
+  fclose(hf);
+  return TRUE;
+} /* read_hosts_file */
 
 /*
  *  External Functions
  */
 
-#ifdef HAVE_GNU_ADNS
-
-void 
+void
 host_name_lookup_init(void) {
+  char *hostspath;
+#ifdef HAVE_GNU_ADNS
+  /*
+   * We're using GNU ADNS, which doesn't check the system hosts file;
+   * we load that file ourselves.
+   */
+#ifdef WIN32
+  char *sysroot;
+  static char rootpath_nt[] = "\\system32\\drivers\\etc\\hosts";
+  static char rootpath_ot[] = "\\hosts";
+
+  sysroot = getenv("WINDIR");
+  if (sysroot != NULL) {
+    /*
+     * The file should be under WINDIR.
+     * If this is Windows NT (NT 4.0,2K,XP,Server2K3), it's in
+     * %WINDIR%\system32\drivers\etc\hosts.
+     * If this is Windows OT (95,98,Me), it's in %WINDIR%\hosts.
+     * Try both.
+     * XXX - should we base it on the dwPlatformId value from
+     * GetVersionEx()?
+     */
+    hostspath = g_strconcat(sysroot, rootpath_nt, NULL);
+    if (!read_hosts_file(hostspath)) {
+      g_free(hostspath);
+      hostspath = g_strconcat(sysroot, rootpath_ot, NULL);
+      read_hosts_file(hostspath);
+    }
+    g_free(hostspath);
+  }
+#else /* WIN32 */
+  read_hosts_file("/etc/hosts");
+#endif /* WIN32 */
+#endif /* HAVE_GNU_ADNS */
+
+  /*
+   * Load the user's hosts file, if they have one.
+   */
+  hostspath = get_persconffile_path(ENAME_HOSTS, FALSE);
+  if (!read_hosts_file(hostspath) && errno != ENOENT) {
+    report_open_failure(hostspath, errno, FALSE);
+  }
+
+#ifdef HAVE_GNU_ADNS
   /* XXX - Any flags we should be using? */
   /* XXX - We could provide config settings for DNS servers, and
            pass them to ADNS with adns_init_strcfg */
-  adns_init(&ads, 0, 0 /*0=>stderr*/);
+  if (adns_init(&ads, 0, 0 /*0=>stderr*/) != 0) {
+    /*
+     * XXX - should we report the error?  I'm assuming that some crashes
+     * reported on a Windows machine with TCP/IP not configured are due
+     * to "adns_init()" failing (due to the lack of TCP/IP) and leaving
+     * ADNS in a state where it crashes due to that.  We'll still try
+     * doing name resolution anyway.
+     */
+    return;
+  }
+  gnu_adns_initialized = TRUE;
   adns_currently_queued = 0;
+#endif /* HAVE_GNU_ADNS */
 }
 
+#ifdef HAVE_GNU_ADNS
+
 /* XXX - The ADNS "documentation" isn't very clear:
  * - Do we need to keep our query structures around?
  */
@@ -1477,6 +1666,7 @@ host_name_lookup_process(gpointer data _U_) {
       addr_bytes = (guint8 *) &almsg->ip4_addr;
       sprintf(addr_str, "%u.%u.%u.%u.in-addr.arpa.", addr_bytes[3],
           addr_bytes[2], addr_bytes[1], addr_bytes[0]);
+      /* XXX - what if it fails? */
       adns_submit (ads, addr_str, adns_r_ptr, 0, NULL, &almsg->query);
       almsg->submitted = TRUE;
       adns_currently_queued++;
@@ -1492,7 +1682,7 @@ host_name_lookup_process(gpointer data _U_) {
       ret = adns_check(ads, &almsg->query, &ans, NULL);
       if (ret == 0) {
 	if (ans->status == adns_s_ok) {
-	  add_host_name(almsg->ip4_addr, *ans->rrs.str);
+	  add_ipv4_name(almsg->ip4_addr, *ans->rrs.str);
 	}
 	dequeue = TRUE;
       }
@@ -1520,15 +1710,12 @@ host_name_lookup_cleanup(void) {
     g_free(qdata);
   }
   
-  adns_finish(ads);
+  if (gnu_adns_initialized)
+    adns_finish(ads);
 }
 
 #else
 
-void
-host_name_lookup_init(void) {
-}
-
 gint
 host_name_lookup_process(gpointer data _U_) {
   /* Kill the timeout, as there's nothing for it to do */
@@ -1569,17 +1756,17 @@ extern const gchar *get_hostname6(struct e_in6_addr *addr)
   return host_name_lookup6(addr, &found);
 }
 
-extern void add_host_name(guint addr, const gchar *name)
+extern void add_ipv4_name(guint addr, const gchar *name)
 {
   int hash_idx;
-  hashname_t *tp;
+  hashipv4_t *tp;
 
   hash_idx = HASH_IPV4_ADDRESS(addr);
 
-  tp = host_table[hash_idx];
+  tp = ipv4_table[hash_idx];
 
   if( tp == NULL ) {
-    tp = host_table[hash_idx] = (hashname_t *)g_malloc(sizeof(hashname_t));
+    tp = ipv4_table[hash_idx] = (hashipv4_t *)g_malloc(sizeof(hashipv4_t));
   } else {
     while(1) {
       if (tp->addr == addr) {
@@ -1592,7 +1779,7 @@ extern void add_host_name(guint addr, const gchar *name)
 	}
       }
       if (tp->next == NULL) {
-	tp->next = (hashname_t *)g_malloc(sizeof(hashname_t));
+	tp->next = (hashipv4_t *)g_malloc(sizeof(hashipv4_t));
 	tp = tp->next;
 	break;
       }
@@ -1606,7 +1793,46 @@ extern void add_host_name(guint addr, const gchar *name)
   tp->next = NULL;
   tp->is_dummy_entry = FALSE;
 
-} /* add_host_name */
+} /* add_ipv4_name */
+
+extern void add_ipv6_name(struct e_in6_addr *addrp, const gchar *name)
+{
+  int hash_idx;
+  hashipv6_t *tp;
+
+  hash_idx = HASH_IPV6_ADDRESS(*addrp);
+
+  tp = ipv6_table[hash_idx];
+
+  if( tp == NULL ) {
+    tp = ipv6_table[hash_idx] = (hashipv6_t *)g_malloc(sizeof(hashipv6_t));
+  } else {
+    while(1) {
+      if (memcmp(&tp->addr, addrp, sizeof (struct e_in6_addr)) == 0) {
+	/* address already known */
+	if (!tp->is_dummy_entry) {
+	  return;
+	} else {
+	  /* replace this dummy entry with the new one */
+	  break;
+	}
+      }
+      if (tp->next == NULL) {
+	tp->next = (hashipv6_t *)g_malloc(sizeof(hashipv6_t));
+	tp = tp->next;
+	break;
+      }
+      tp = tp->next;
+    }
+  }
+
+  strncpy(tp->name, name, MAXNAMELEN);
+  tp->name[MAXNAMELEN-1] = '\0';
+  tp->addr = *addrp;
+  tp->next = NULL;
+  tp->is_dummy_entry = FALSE;
+
+} /* add_ipv6_name */
 
 extern gchar *get_udp_port(guint port)
 {
@@ -1671,6 +1897,32 @@ extern gchar *get_sctp_port(guint port)
 
 } /* get_sctp_port */
 
+const gchar *get_addr_name(address *addr)
+{
+  guint32 ipv4_addr;
+  struct e_in6_addr ipv6_addr;
+
+  switch (addr->type) {
+
+  case AT_ETHER:
+    return get_ether_name(addr->data);
+
+  case AT_IPv4:
+    memcpy(&ipv4_addr, addr->data, sizeof ipv4_addr);
+    return get_hostname(ipv4_addr);
+
+  case AT_IPv6:
+    memcpy(&ipv6_addr.s6_addr, addr->data, sizeof ipv6_addr.s6_addr);
+    return get_hostname6(&ipv6_addr);
+
+  case AT_STRINGZ:
+    return addr->data;
+
+  default:
+    return NULL;
+  }
+}
+
 extern gchar *get_ether_name(const guint8 *addr)
 {
   if (!(g_resolv_flags & RESOLV_MAC))
@@ -1914,7 +2166,11 @@ gboolean get_host_ipaddr6(const char *host, struct e_in6_addr *addrp)
  * Return "ip6" if it is IPv6, "ip" otherwise (including the case
  * that we don't know)
  */
-const char* host_ip_af(const char *host)
+const char* host_ip_af(const char *host
+#ifndef HAVE_GETHOSTBYNAME2
+_U_
+#endif
+)
 {
 #ifdef HAVE_GETHOSTBYNAME2
 	struct hostent *h;
