@@ -1,7 +1,7 @@
 /* column-utils.c
  * Routines for column utilities.
  *
- * $Id: column-utils.c,v 1.47 2004/03/18 19:04:32 obiot Exp $
+ * $Id: column-utils.c 12889 2004-12-31 02:03:16Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,7 +40,7 @@
 #include "to_str.h"
 #include "packet_info.h"
 #include "pint.h"
-#include "resolv.h"
+#include "addr_resolv.h"
 #include "ipv6-utils.h"
 #include "osi-utils.h"
 #include "value_string.h"
@@ -58,7 +58,7 @@ col_setup(column_info *col_info, gint num_cols)
   col_info->col_first	= (int *) g_malloc(sizeof(int) * (NUM_COL_FMTS));
   col_info->col_last 	= (int *) g_malloc(sizeof(int) * (NUM_COL_FMTS));
   col_info->col_title	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
-  col_info->col_data	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
+  col_info->col_data	= (const gchar **) g_malloc(sizeof(gchar *) * num_cols);
   col_info->col_buf	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
   col_info->col_fence	= (int *) g_malloc(sizeof(int) * num_cols);
   col_info->col_expr	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
@@ -191,11 +191,11 @@ col_clear(column_info *cinfo, gint el)
 /* Use this if "str" points to something that will stay around (and thus
    needn't be copied). */
 void
-col_set_str(column_info *cinfo, gint el, gchar* str)
+col_set_str(column_info *cinfo, gint el, const gchar* str)
 {
   int i;
   int fence;
-  size_t len, max_len;
+  size_t max_len;
 
   if (el == COL_INFO)
 	max_len = COL_MAX_INFO_LEN;
@@ -213,8 +213,7 @@ col_set_str(column_info *cinfo, gint el, gchar* str)
          */
         COL_CHECK_APPEND(cinfo, i, max_len);
 
-        len = strlen(cinfo->col_buf[i]);
-        strncat(cinfo->col_buf[i], str, max_len - len);
+        strncpy(&cinfo->col_buf[i][fence], str, max_len - fence);
         cinfo->col_buf[i][max_len - 1] = 0;
       } else {
         /*
@@ -258,18 +257,18 @@ col_add_fstr(column_info *cinfo, gint el, const gchar *format, ...) {
         cinfo->col_data[i] = cinfo->col_buf[i];
       }
       vsnprintf(&cinfo->col_buf[i][fence], max_len - fence, format, ap);
+      cinfo->col_buf[i][max_len - 1] = '\0';
     }
   }
   va_end(ap);
 }
 
-/* Appends a vararg list to a packet info string. */
-void
-col_append_fstr(column_info *cinfo, gint el, const gchar *format, ...)
+static void
+col_do_append_sep_va_fstr(column_info *cinfo, gint el, const gchar *separator,
+			  const gchar *format, va_list ap)
 {
-  va_list ap;
   int     i;
-  size_t  len, max_len;
+  size_t  len, max_len, sep_len;
 
   g_assert(cinfo->col_first[el] >= 0);
   if (el == COL_INFO)
@@ -277,17 +276,42 @@ col_append_fstr(column_info *cinfo, gint el, const gchar *format, ...)
   else
 	max_len = COL_MAX_LEN;
 
-  va_start(ap, format);
+  if (separator == NULL)
+    sep_len = 0;
+  else
+    sep_len = strlen(separator);
   for (i = cinfo->col_first[el]; i <= cinfo->col_last[el]; i++) {
     if (cinfo->fmt_matx[i][el]) {
       /*
        * First arrange that we can append, if necessary.
        */
       COL_CHECK_APPEND(cinfo, i, max_len);
+
       len = strlen(cinfo->col_buf[i]);
+
+      /*
+       * If we have a separator, append it if the column isn't empty.
+       */
+      if (separator != NULL) {
+        if (len != 0) {
+          strncat(cinfo->col_buf[i], separator, max_len - len);
+          len += sep_len;
+        }
+      }
       vsnprintf(&cinfo->col_buf[i][len], max_len - len, format, ap);
+      cinfo->col_buf[i][max_len-1] = 0;
     }
   }
+}
+
+/* Appends a vararg list to a packet info string. */
+void
+col_append_fstr(column_info *cinfo, gint el, const gchar *format, ...)
+{
+  va_list ap;
+
+  va_start(ap, format);
+  col_do_append_sep_va_fstr(cinfo, el, NULL, format, ap);
   va_end(ap);
 }
 
@@ -298,29 +322,11 @@ col_append_sep_fstr(column_info *cinfo, gint el, const gchar *separator,
 		const gchar *format, ...)
 {
   va_list ap;
-  int     i;
-  size_t  len, max_len;
 
-  g_assert(cinfo->col_first[el] >= 0);
-  if (el == COL_INFO)
-	max_len = COL_MAX_INFO_LEN;
-  else
-	max_len = COL_MAX_LEN;
-
-  if (cinfo->col_buf[0]) {
-    col_append_str(cinfo, el, separator ? separator : ", ");
-  }
+  if (separator == NULL)
+    separator = ", ";    /* default */
   va_start(ap, format);
-  for (i = cinfo->col_first[el]; i <= cinfo->col_last[el]; i++) {
-    if (cinfo->fmt_matx[i][el]) {
-      /*
-       * First arrange that we can append, if necessary.
-       */
-      COL_CHECK_APPEND(cinfo, i, max_len);
-      len = strlen(cinfo->col_buf[i]);
-      vsnprintf(&cinfo->col_buf[i][len], max_len - len, format, ap);
-    }
-  }
+  col_do_append_sep_va_fstr(cinfo, el, separator, format, ap);
   va_end(ap);
 }
 
@@ -332,11 +338,11 @@ col_append_sep_fstr(column_info *cinfo, gint el, const gchar *separator,
 void
 col_prepend_fstr(column_info *cinfo, gint el, const gchar *format, ...)
 {
-  va_list ap;
-  int     i;
-  char    orig_buf[COL_BUF_MAX_LEN];
-  char   *orig;
-  size_t  max_len;
+  va_list     ap;
+  int         i;
+  char        orig_buf[COL_BUF_MAX_LEN];
+  const char *orig;
+  size_t      max_len;
 
   g_assert(cinfo->col_first[el] >= 0);
   if (el == COL_INFO)
@@ -348,12 +354,12 @@ col_prepend_fstr(column_info *cinfo, gint el, const gchar *format, ...)
   for (i = cinfo->col_first[el]; i <= cinfo->col_last[el]; i++) {
     if (cinfo->fmt_matx[i][el]) {
       if (cinfo->col_data[i] != cinfo->col_buf[i]) {
-      	/* This was set with "col_set_str()"; which is effectively const */
+        /* This was set with "col_set_str()"; which is effectively const */
         orig = cinfo->col_data[i];
       } else {
+        strncpy(orig_buf, cinfo->col_buf[i], max_len);
+        orig_buf[max_len - 1] = '\0';
         orig = orig_buf;
-	strncpy(orig, cinfo->col_buf[i], max_len);
-	orig[max_len - 1] = '\0';
       }
       vsnprintf(cinfo->col_buf[i], max_len, format, ap);
       cinfo->col_buf[i][max_len - 1] = '\0';
@@ -408,11 +414,12 @@ col_add_str(column_info *cinfo, gint el, const gchar* str)
   }
 }
 
-void
-col_append_str(column_info *cinfo, gint el, const gchar* str)
+static void
+col_do_append_str(column_info *cinfo, gint el, const gchar* separator,
+    const gchar* str)
 {
   int    i;
-  size_t len, max_len;
+  size_t len, max_len, sep_len;
 
   g_assert(cinfo->col_first[el] >= 0);
   if (el == COL_INFO)
@@ -420,27 +427,48 @@ col_append_str(column_info *cinfo, gint el, const gchar* str)
   else
 	max_len = COL_MAX_LEN;
 
+  if (separator == NULL)
+    sep_len = 0;
+  else
+    sep_len = strlen(separator);
+
   for (i = cinfo->col_first[el]; i <= cinfo->col_last[el]; i++) {
     if (cinfo->fmt_matx[i][el]) {
       /*
        * First arrange that we can append, if necessary.
        */
       COL_CHECK_APPEND(cinfo, i, max_len);
+
       len = strlen(cinfo->col_buf[i]);
+
+      /*
+       * If we have a separator, append it if the column isn't empty.
+       */
+      if (separator != NULL) {
+        if (len != 0) {
+          strncat(cinfo->col_buf[i], separator, max_len - len);
+          len += sep_len;
+        }
+      }
       strncat(cinfo->col_buf[i], str, max_len - len);
       cinfo->col_buf[i][max_len - 1] = 0;
     }
   }
 }
 
+void
+col_append_str(column_info *cinfo, gint el, const gchar* str)
+{
+  col_do_append_str(cinfo, el, NULL, str);
+}
+
 void
 col_append_sep_str(column_info *cinfo, gint el, const gchar* separator,
     const gchar* str)
 {
-  if (cinfo->col_buf[0]) {
-    col_append_str(cinfo, el, separator ? separator : ", ");
-  }  
-  col_append_str(cinfo, el, str);
+  if (separator == NULL)
+    separator = ", ";    /* default */
+  col_do_append_str(cinfo, el, separator, str);
 }
 
 static void
@@ -546,7 +574,7 @@ static void
 col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
 	     gboolean is_src)
 {
-  guint32 ipv4_addr;
+  const char *addr_string;
   struct e_in6_addr ipv6_addr;
 
   pinfo->cinfo->col_expr[col][0] = '\0';
@@ -554,23 +582,20 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
   if (addr->type == AT_NONE)
     return;	/* no address, nothing to do */
   if (is_res) {
+    addr_string = get_addr_name(addr);
+    if (addr_string != NULL) {
+      strncpy(pinfo->cinfo->col_buf[col], addr_string, COL_MAX_LEN);
+      pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
+    } else
+      address_to_str_buf(addr, pinfo->cinfo->col_buf[col]);
+  } else {
     switch (addr->type) {
 
-    case AT_ETHER:
-      strncpy(pinfo->cinfo->col_buf[col], get_ether_name(addr->data), COL_MAX_LEN);
-      pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
-      pinfo->cinfo->col_data[col] = pinfo->cinfo->col_buf[col];
-      break;
-
-    case AT_IPv4:
-      memcpy(&ipv4_addr, addr->data, sizeof ipv4_addr);
-      strncpy(pinfo->cinfo->col_buf[col], get_hostname(ipv4_addr), COL_MAX_LEN);
-      pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
-      break;
-
-    case AT_IPv6:
-      memcpy(&ipv6_addr.s6_addr, addr->data, sizeof ipv6_addr.s6_addr);
-      strncpy(pinfo->cinfo->col_buf[col], get_hostname6(&ipv6_addr), COL_MAX_LEN);
+    case AT_STRINGZ:
+      /* XXX - should be done in "address_to_str_buf()", but that routine
+         doesn't know COL_MAX_LEN; it should be changed to take the
+         maximum length as an argument. */
+      strncpy(pinfo->cinfo->col_buf[col], addr->data, COL_MAX_LEN);
       pinfo->cinfo->col_buf[col][COL_MAX_LEN - 1] = '\0';
       break;
 
@@ -578,8 +603,7 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
       address_to_str_buf(addr, pinfo->cinfo->col_buf[col]);
       break;
     }
-  } else
-    address_to_str_buf(addr, pinfo->cinfo->col_buf[col]);
+  }
   pinfo->cinfo->col_data[col] = pinfo->cinfo->col_buf[col];
 
   switch (addr->type) {
