@@ -2,7 +2,7 @@
 *
 * Routine to dissect OSI ACSE Protocol packets
 *
-* $Id: packet-acse.c 12115 2004-09-27 22:55:15Z guy $
+* $Id: packet-acse.c 13074 2005-01-16 16:06:15Z ulfl $
 *
 * Yuriy Sidelnikov <YSidelnikov@hotmail.com>
 *
@@ -73,32 +73,24 @@ static const value_string acse_vals[] =
 {
   {ACSE_AARQ,  "A-associate request" },
   {ACSE_AARE,  "A-associate response" },
-  {ACSE_RLRQ,  "A-reliase request" },
-  {ACSE_RLRE,  "A-reliase response" },
+  {ACSE_RLRQ,  "A-release request" },
+  {ACSE_RLRE,  "A-release response" },
   {ACSE_ABRT,  "A-abort" },
   {0,             NULL           }
 };
 
-static const value_string cr_vals[] =
-{
-  {MODE_SELECTOR, "Mode Selector"},
-  {SEQUENCE_TOP, "Sequence"},
-  {SET_TOP, "Set"},
-  {0, NULL}
-};
-
 static const value_string request_sequence_top_vals[] =
 {
   {PROTOCOL_VERSION, "Protocol version"},
   {APPLICATION_CONTEXT_NAME, "Application context name"},
   {CALLED_AP_TITLE, "Called AP title"},
   {CALLED_AE_QUALIFIER, "Called AE qualifier"},
-  {CALLED_AP_INVOKATION_ID, "Called AP invokation id"},
-  {CALLED_AE_INVOKATION_ID, "Called AE invokation id"},
+  {CALLED_AP_INVOKATION_ID, "Called AP invocation id"},
+  {CALLED_AE_INVOKATION_ID, "Called AE invocation id"},
   {CALLING_AP_TITLE, "Calling AP title"},
   {CALLING_AE_QUALIFIER, "Calling AE qualifier"},
-  {CALLING_AP_INVOKATION_ID, "Calling AP invokation id"},
-  {CALLING_AE_INVOKATION_ID, "Calling AE invokation id"},
+  {CALLING_AP_INVOKATION_ID, "Calling AP invocation id"},
+  {CALLING_AE_INVOKATION_ID, "Calling AE invocation id"},
   {IMPLEMENTATION_INFORMATION,"Implementation information"},
   {USER_INFORMATION,"User information"},
   {0, NULL}
@@ -111,8 +103,8 @@ static const value_string response_sequence_top_vals[] =
   {ACSE_RESULT_SOURCE_DIAGNOSTIC, "Result source diagnostic"},
   {RESPONDING_AP_TITLE, "Responding AP title"},
   {RESPONDING_AE_QUALIFIER, "Responding AE qualifier"},
-  {RESPONDING_AP_INVOKATION_ID, "Responding AP invokation id"},
-  {RESPONDING_AE_INVOKATION_ID, "Responding AE invokation id"},
+  {RESPONDING_AP_INVOKATION_ID, "Responding AP invocation id"},
+  {RESPONDING_AE_INVOKATION_ID, "Responding AE invocation id"},
   {IMPLEMENTATION_INFORMATION,"Implementation information"},
   {USER_INFORMATION,"User information"},
   {0, NULL}
@@ -127,8 +119,8 @@ static const value_string associate_result_values_vals[] =
 
 static const value_string acse_associate_source_diagnostic_vals[] =
 {
-  {ACSE_SERVICE_USER,"Acse service user"},
-  {ACSE_SERVICE_PROVIDER,"Acse service provider"},
+  {ACSE_SERVICE_USER,"ACSE service user"},
+  {ACSE_SERVICE_PROVIDER,"ACSE service provider"},
   {0, NULL}
 };
 static const value_string acse_service_user_values_vals[] =
@@ -137,13 +129,13 @@ static const value_string acse_service_user_values_vals[] =
   {ACSE_NO_REASON_GIVEN,"No reason given"},
   {ACSE_APPLICATION_CONTEXT_NAME_NOT_SUPPORTED,"Application context name not supported"},
   {ACSE_CALLING_AP_TITLE_NOT_RECOGNIZED,"Calling AP title not recognized"},
-  {ACSE_CALLING_AP_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Calling AP invokation identifier not recognized"},
+  {ACSE_CALLING_AP_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Calling AP invocation identifier not recognized"},
   {ACSE_CALLING_AE_QUALIFIER_NOT_RECOGNIZED,"Calling AE qualifier not recognized"},
-  {ACSE_CALLING_AE_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Calling AE invokation identifier not recognized"},
+  {ACSE_CALLING_AE_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Calling AE invocation identifier not recognized"},
   {ACSE_CALLED_AP_TITLE_NOT_RECOGNIZED,"Called AP title not recognized"},
-  {ACSE_CALLED_AP_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Called AP invokation identifier not recognized"},
+  {ACSE_CALLED_AP_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Called AP invocation identifier not recognized"},
   {ACSE_CALLED_AE_QUALIFIER_NOT_RECOGNIZED,"Called AE qualifier not recognized"},
-  {ACSE_CALLED_AE_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Called AE invokation identifier not recognized"},
+  {ACSE_CALLED_AE_INVOKATION_IDENTIFIER_NOT_RECOGNIZED,"Called AE invocation identifier not recognized"},
   {0, NULL}
 };
 static const value_string acse_service_provider_values_vals[] =
@@ -159,13 +151,6 @@ static const value_string acse_user_information_vals[] =
   {ACSE_EXTERNAL_USER,"External"},
   {0, NULL}
 };
-static const value_string sequence_list_vals[] =
-{
-  {PRESENTATION_CONTEXT_IDENTIFIER,"Presentation context identifier"},
-  {ABSTRACT_SYNTAX_NAME,"Abstract syntax name"},
-  {TRANSFER_SYNTAX_NAMES,"Transfer syntax names"},
-  {0, NULL}
-};
 static const value_string presentation_context_definition_vals[] =
 {
   {SEQUENCE, "Sequence"},
@@ -203,18 +188,11 @@ static const value_string release_response_reason[] =
 
 static const value_string abort_reason[] =
 {
-  {ABRT_ACSE_SERVICE_USER,"Acse service user"},
-  {ABRT_ACSE_SERVICE_PROVIDER,"Acse service provider"},
+  {ABRT_ACSE_SERVICE_USER,"ACSE service user"},
+  {ABRT_ACSE_SERVICE_PROVIDER,"ACSE service provider"},
   {0, NULL}
 };
 
-static const value_string type_app[] =
-{
-	{0,""},             /*   for unknown dissector   */
-	{FTAM_APP,"FTAM"},
-	{CMIP_APP,"CMIP"},
-	{0, NULL}
-};
 
 /*      pointers for acse dissector  */
 static proto_tree *global_tree  = NULL;
@@ -250,7 +228,7 @@ call_app_dissector(tvbuff_t *tvb, gint offset, gint param_len,
 			}
 			CATCH_ALL
 			{
-				show_exception(tvb, pinfo, tree, EXCEPT_CODE);
+				show_exception(tvb, pinfo, tree, EXCEPT_CODE, GET_MESSAGE);
 			}
 			ENDTRY;
 	}
@@ -305,7 +283,7 @@ static int read_length(ASN1_SCK *a, proto_tree *tree, int hf_id, guint *len)
   if (len)
     *len = length;
 
-  if (tree && hf_id)
+  if (hf_id)
     proto_tree_add_uint(tree, hf_id, a->tvb, start, a->offset-start,
 length);
 
@@ -333,7 +311,7 @@ static int read_integer_value(ASN1_SCK *a, proto_tree *tree, int hf_id,
   if (i)
     *i = integer;
 
-  if (tree && hf_id)
+  if (hf_id)
     temp_item = proto_tree_add_uint(tree, hf_id, a->tvb, start,
 a->offset-start, integer);
 
@@ -1506,7 +1484,6 @@ dissect_pdu(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
 				}
 			return FALSE;
 			}
-			if(tree)
 			{
 				if(session->spdu_type == SES_CONNECTION_REQUEST)
 				{
