@@ -5,7 +5,7 @@
  * This information is based off the released idl files from opengroup.
  * ftp://ftp.opengroup.org/pub/dce122/dce/src/security.tar.gz  security/idl/rs_pgo.idl
  *
- * $Id: packet-dcerpc-rs_pgo.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-dcerpc-rs_pgo.c 12455 2004-10-31 02:47:07Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -92,6 +92,7 @@ static int hf_sec_rgy_domain_t = -1;
 static int hf_sec_rgy_name_t_principalName_string = -1;
 static int hf_sec_rgy_name_t_size = -1;
 static int hf_sec_rgy_pname_t_principalName_string = -1;
+static int hf_sec_rgy_pname_t_size = -1;
 static int hf_sec_rgy_unix_sid_t_group = -1;
 static int hf_sec_rgy_unix_sid_t_org = -1;
 static int hf_sec_rgy_unix_sid_t_person = -1;
@@ -237,7 +238,7 @@ dissect    sec_rgy_pname const signed32        sec_rgy_pname_t_size  = 257; * In
 
   offset =
     dissect_ndr_uint32 (tvb, offset, pinfo, tree, drep,
-			sec_rgy_pname_t_size, &string_size);
+			hf_sec_rgy_pname_t_size, &string_size);
   if (check_col (pinfo->cinfo, COL_INFO))
     col_append_fstr (pinfo->cinfo, COL_INFO, " String_size:%u", string_size);
   if (string_size < sec_rgy_pname_t_size)
@@ -251,11 +252,11 @@ dissect    sec_rgy_pname const signed32        sec_rgy_pname_t_size  = 257; * In
       if (string_size > 1)
 	{
 	  namestring = tvb_get_ptr (tvb, offset, string_size);
-	  offset += string_size;
 	  if (check_col (pinfo->cinfo, COL_INFO))
 	    col_append_fstr (pinfo->cinfo, COL_INFO, " Principal:%s",
 			     namestring);
 	}
+      offset += string_size;
     }
   else
     {
@@ -483,11 +484,11 @@ dissect_sec_rgy_name_t (tvbuff_t * tvb, int offset,
       if (string_size > 1)
 	{
 	  namestring = tvb_get_ptr (tvb, offset, string_size);
-	  offset += string_size;
 	  if (check_col (pinfo->cinfo, COL_INFO))
 	    col_append_fstr (pinfo->cinfo, COL_INFO, " Principal:%s",
 			     namestring);
 	}
+      offset += string_size;
     }
   else
     {
@@ -1702,150 +1703,154 @@ proto_register_rs_pgo (void)
      {"hf_error_status_t", "hf_error_status_t", FT_UINT32, BASE_DEC, NULL,
       0x0, "", HFILL}},
     {&hf_rgy_acct_user_flags_t,
-     {"hf_rgy_acct_user_flags_t ", "hf_rgy_acct_user_flags_t", FT_UINT32,
+     {"hf_rgy_acct_user_flags_t", "hf_rgy_acct_user_flags_t", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_get_rqst_key_size,
-     {"hf_rgy_get_rqst_key_size ", "hf_rgy_get_rqst_key_size", FT_UINT32,
+     {"hf_rgy_get_rqst_key_size", "hf_rgy_get_rqst_key_size", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_get_rqst_key_t,
-     {"hf_rgy_get_rqst_key_t ", "hf_rgy_get_rqst_key_t", FT_UINT32, BASE_DEC,
+     {"hf_rgy_get_rqst_key_t", "hf_rgy_get_rqst_key_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rgy_get_rqst_name_domain,
-     {"hf_rgy_get_rqst_name_domain ", "hf_rgy_get_rqst_name_domain",
+     {"hf_rgy_get_rqst_name_domain", "hf_rgy_get_rqst_name_domain",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_get_rqst_var,
-     {"hf_rgy_get_rqst_var ", "hf_rgy_get_rqst_var", FT_UINT32, BASE_DEC,
+     {"hf_rgy_get_rqst_var", "hf_rgy_get_rqst_var", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rgy_get_rqst_var2,
-     {"hf_rgy_get_rqst_var2 ", "hf_rgy_get_rqst_var2", FT_UINT32, BASE_DEC,
+     {"hf_rgy_get_rqst_var2", "hf_rgy_get_rqst_var2", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_key1,
-     {"hf_rgy_is_member_rqst_key1 ", "hf_rgy_is_member_rqst_key1", FT_UINT32,
+     {"hf_rgy_is_member_rqst_key1", "hf_rgy_is_member_rqst_key1", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_key1_size,
-     {"hf_rgy_is_member_rqst_key1_size ", "hf_rgy_is_member_rqst_key1_size",
+     {"hf_rgy_is_member_rqst_key1_size", "hf_rgy_is_member_rqst_key1_size",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_key2,
-     {"hf_rgy_is_member_rqst_key2 ", "hf_rgy_is_member_rqst_key2", FT_UINT32,
+     {"hf_rgy_is_member_rqst_key2", "hf_rgy_is_member_rqst_key2", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_key2_size,
-     {"hf_rgy_is_member_rqst_key2_size ", "hf_rgy_is_member_rqst_key2_size",
+     {"hf_rgy_is_member_rqst_key2_size", "hf_rgy_is_member_rqst_key2_size",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_var1,
-     {"hf_rgy_is_member_rqst_var1 ", "hf_rgy_is_member_rqst_var1", FT_UINT32,
+     {"hf_rgy_is_member_rqst_var1", "hf_rgy_is_member_rqst_var1", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_var2,
-     {"hf_rgy_is_member_rqst_var2 ", "hf_rgy_is_member_rqst_var2", FT_UINT32,
+     {"hf_rgy_is_member_rqst_var2", "hf_rgy_is_member_rqst_var2", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_var3,
-     {"hf_rgy_is_member_rqst_var3 ", "hf_rgy_is_member_rqst_var3", FT_UINT32,
+     {"hf_rgy_is_member_rqst_var3", "hf_rgy_is_member_rqst_var3", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_is_member_rqst_var4,
-     {"hf_rgy_is_member_rqst_var4 ", "hf_rgy_is_member_rqst_var4", FT_UINT32,
+     {"hf_rgy_is_member_rqst_var4", "hf_rgy_is_member_rqst_var4", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_key_transfer_rqst_var1,
-     {"hf_rgy_key_transfer_rqst_var1 ", "hf_rgy_key_transfer_rqst_var1",
+     {"hf_rgy_key_transfer_rqst_var1", "hf_rgy_key_transfer_rqst_var1",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_key_transfer_rqst_var2,
-     {"hf_rgy_key_transfer_rqst_var2 ", "hf_rgy_key_transfer_rqst_var2",
+     {"hf_rgy_key_transfer_rqst_var2", "hf_rgy_key_transfer_rqst_var2",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_key_transfer_rqst_var3,
-     {"hf_rgy_key_transfer_rqst_var3 ", "hf_rgy_key_transfer_rqst_var3",
+     {"hf_rgy_key_transfer_rqst_var3", "hf_rgy_key_transfer_rqst_var3",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_name_domain,
-     {"hf_rgy_name_domain ", "hf_rgy_name_domain", FT_UINT32, BASE_DEC, NULL,
+     {"hf_rgy_name_domain", "hf_rgy_name_domain", FT_UINT32, BASE_DEC, NULL,
       0x0, "", HFILL}},
     {&hf_rgy_sec_rgy_name_max_len,
-     {"hf_rgy_sec_rgy_name_max_len ", "hf_rgy_sec_rgy_name_max_len",
+     {"hf_rgy_sec_rgy_name_max_len", "hf_rgy_sec_rgy_name_max_len",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rgy_sec_rgy_name_t,
-     {"hf_rgy_sec_rgy_name_t ", "hf_rgy_sec_rgy_name_t", FT_UINT32, BASE_DEC,
+     {"hf_rgy_sec_rgy_name_t", "hf_rgy_sec_rgy_name_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rgy_sec_rgy_name_t_size,
-     {"hf_rgy_sec_rgy_name_t_size ", "hf_rgy_sec_rgy_name_t_size", FT_UINT32,
+     {"hf_rgy_sec_rgy_name_t_size", "hf_rgy_sec_rgy_name_t_size", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rs_pgo_id_key_t,
-     {"hf_rs_pgo_id_key_t ", "hf_rs_pgo_id_key_t", FT_UINT32, BASE_DEC, NULL,
+     {"hf_rs_pgo_id_key_t", "hf_rs_pgo_id_key_t", FT_UINT32, BASE_DEC, NULL,
       0x0, "", HFILL}},
     {&hf_rs_pgo_query_key_t,
-     {"hf_rs_pgo_query_key_t ", "hf_rs_pgo_query_key_t", FT_UINT32, BASE_DEC,
+     {"hf_rs_pgo_query_key_t", "hf_rs_pgo_query_key_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rs_pgo_query_result_t,
-     {"hf_rs_pgo_query_result_t ", "hf_rs_pgo_query_result_t", FT_UINT32,
+     {"hf_rs_pgo_query_result_t", "hf_rs_pgo_query_result_t", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rs_pgo_query_t,
-     {"hf_rs_pgo_query_t ", "hf_rs_pgo_query_t", FT_UINT32, BASE_DEC, NULL,
+     {"hf_rs_pgo_query_t", "hf_rs_pgo_query_t", FT_UINT32, BASE_DEC, NULL,
       0x0, "", HFILL}},
     {&hf_rs_sec_rgy_pgo_item_t_quota,
-     {"hf_rs_sec_rgy_pgo_item_t_quota ", "hf_rs_sec_rgy_pgo_item_t_quota",
+     {"hf_rs_sec_rgy_pgo_item_t_quota", "hf_rs_sec_rgy_pgo_item_t_quota",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_rs_sec_rgy_pgo_item_t_unix_num,
-     {"hf_rs_sec_rgy_pgo_item_t_unix_num ",
+     {"hf_rs_sec_rgy_pgo_item_t_unix_num",
       "hf_rs_sec_rgy_pgo_item_t_unix_num", FT_UINT32, BASE_DEC, NULL, 0x0, "",
       HFILL}},
     {&hf_rs_timeval,
-     {"hf_rs_timeval ", "hf_rs_timeval", FT_RELATIVE_TIME, BASE_DEC, NULL,
+     {"hf_rs_timeval", "hf_rs_timeval", FT_RELATIVE_TIME, BASE_DEC, NULL,
       0x0, "", HFILL}},
     {&hf_rs_uuid1,
-     {"hf_rs_uuid1 ", "hf_rs_uuid1", FT_STRING, BASE_NONE, NULL, 0x0, "UUID",
+     {"hf_rs_uuid1", "hf_rs_uuid1", FT_STRING, BASE_NONE, NULL, 0x0, "UUID",
       HFILL}},
     {&hf_rs_var1,
-     {"hf_rs_var1 ", "hf_rs_var1", FT_UINT32, BASE_DEC, NULL, 0x0, "",
+     {"hf_rs_var1", "hf_rs_var1", FT_UINT32, BASE_DEC, NULL, 0x0, "",
       HFILL}},
     {&hf_sec_attr_component_name_t_handle,
-     {"hf_sec_attr_component_name_t_handle ",
+     {"hf_sec_attr_component_name_t_handle",
       "hf_sec_attr_component_name_t_handle", FT_UINT32, BASE_DEC, NULL, 0x0,
       "", HFILL}},
     {&hf_sec_attr_component_name_t_valid,
-     {"hf_sec_attr_component_name_t_valid ",
+     {"hf_sec_attr_component_name_t_valid",
       "hf_sec_attr_component_name_t_valid", FT_UINT32, BASE_DEC, NULL, 0x0,
       "", HFILL}},
     {&hf_sec_passwd_type_t,
-     {"hf_sec_passwd_type_t ", "hf_sec_passwd_type_t", FT_UINT32, BASE_DEC,
+     {"hf_sec_passwd_type_t", "hf_sec_passwd_type_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_sec_passwd_version_t,
-     {"hf_sec_passwd_version_t ", "hf_sec_passwd_version_t", FT_UINT32,
+     {"hf_sec_passwd_version_t", "hf_sec_passwd_version_t", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_acct_admin_flags,
-     {"hf_sec_rgy_acct_admin_flags ", "hf_sec_rgy_acct_admin_flags",
+     {"hf_sec_rgy_acct_admin_flags", "hf_sec_rgy_acct_admin_flags",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_acct_auth_flags_t,
-     {"hf_sec_rgy_acct_auth_flags_t ", "hf_sec_rgy_acct_auth_flags_t",
+     {"hf_sec_rgy_acct_auth_flags_t", "hf_sec_rgy_acct_auth_flags_t",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_acct_key_t,
-     {"hf_sec_rgy_acct_key_t ", "hf_sec_rgy_acct_key_t", FT_UINT32, BASE_DEC,
+     {"hf_sec_rgy_acct_key_t", "hf_sec_rgy_acct_key_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_domain_t,
-     {"hf_sec_rgy_domain_t ", "hf_sec_rgy_domain_t", FT_UINT32, BASE_DEC,
+     {"hf_sec_rgy_domain_t", "hf_sec_rgy_domain_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_name_t_principalName_string,
-     {"hf_sec_rgy_name_t_principalName_string ",
+     {"hf_sec_rgy_name_t_principalName_string",
       "hf_sec_rgy_name_t_principalName_string", FT_STRING, BASE_NONE, NULL,
       0x0, "", HFILL}},
     {&hf_sec_rgy_name_t_size,
-     {"hf_sec_rgy_name_t_size ", "hf_sec_rgy_name_t_size", FT_UINT32,
+     {"hf_sec_rgy_name_t_size", "hf_sec_rgy_name_t_size", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_pgo_flags_t,
-     {"hf_sec_rgy_pgo_flags_t ", "hf_sec_rgy_pgo_flags_t", FT_UINT32,
-      BASE_DEC, NULL, 0x0, "", HFILL}},
+     {"hf_sec_rgy_pgo_flags_t", "hf_sec_rgy_pgo_flags_t", FT_UINT32,
+      BASE_HEX, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_pgo_item_t,
-     {"hf_sec_rgy_pgo_item_t ", "hf_sec_rgy_pgo_item_t", FT_UINT32, BASE_DEC,
+     {"hf_sec_rgy_pgo_item_t", "hf_sec_rgy_pgo_item_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
+    {&hf_sec_rgy_pname_t_size,
+     {"hf_sec_rgy_pname_t_size",
+      "hf_sec_rgy_pname_t_size", FT_UINT32, BASE_DEC, NULL,
+      0x0, "", HFILL}},
     {&hf_sec_rgy_pname_t_principalName_string,
-     {"hf_sec_rgy_pname_t_principalName_string ",
+     {"hf_sec_rgy_pname_t_principalName_string",
       "hf_sec_rgy_pname_t_principalName_string", FT_STRING, BASE_NONE, NULL,
       0x0, "", HFILL}},
     {&hf_sec_rgy_unix_sid_t_group,
-     {"hf_sec_rgy_unix_sid_t_group ", "hf_sec_rgy_unix_sid_t_group",
+     {"hf_sec_rgy_unix_sid_t_group", "hf_sec_rgy_unix_sid_t_group",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_unix_sid_t_org,
-     {"hf_sec_rgy_unix_sid_t_org ", "hf_sec_rgy_unix_sid_t_org", FT_UINT32,
+     {"hf_sec_rgy_unix_sid_t_org", "hf_sec_rgy_unix_sid_t_org", FT_UINT32,
       BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_rgy_unix_sid_t_person,
-     {"hf_sec_rgy_unix_sid_t_person ", "hf_sec_rgy_unix_sid_t_person",
+     {"hf_sec_rgy_unix_sid_t_person", "hf_sec_rgy_unix_sid_t_person",
       FT_UINT32, BASE_DEC, NULL, 0x0, "", HFILL}},
     {&hf_sec_timeval_sec_t,
-     {"hf_sec_timeval_sec_t ", "hf_sec_timeval_sec_t", FT_UINT32, BASE_DEC,
+     {"hf_sec_timeval_sec_t", "hf_sec_timeval_sec_t", FT_UINT32, BASE_DEC,
       NULL, 0x0, "", HFILL}},
     {&hf_rs_pgo_unix_num_key_t,
      {"hf_rs_pgo_unix_num_key_t", "hf_rs_pgo_unix_num_key_t", FT_UINT32,
