@@ -1,8 +1,8 @@
-/* packet-DNP3.c
+/* packet-dnp3.c
  * Routines for DNP dissection
  * Copyright 2003, Graham Bloice <graham.bloice@trihedral.com>
  *
- * $Id: packet-dnp.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-dnp.c 13150 2005-01-20 19:37:05Z gerald $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -42,6 +42,16 @@
 #include <epan/prefs.h>
 #include "reassemble.h"
 
+/*
+ * See
+ *
+ *	http://www.dnp.org/
+ *
+ * although note that you have to join the DNP organization to get to
+ * see the protocol specs online - otherwise, you have to buy a
+ * dead-tree version.
+ */
+
 /* DNP 3.0 constants */
 #define DNP_HDR_LEN     10
 #define TCP_PORT_DNP    20000
@@ -390,6 +400,7 @@ dissect_dnp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     guint16       dl_dst, dl_src, dl_crc, calc_dl_crc;
     guint8       *tmp = NULL, *tmp_ptr;
     guint8        data_len;
+    int           data_offset;
     gboolean      crc_OK = FALSE;
     tvbuff_t     *al_tvb = NULL;
     guint         i;
@@ -522,18 +533,23 @@ dissect_dnp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
   /* extract the application layer data, validating the CRCs */
 
-  data_len = dl_len - 5;
+  /* XXX - check for dl_len <= 5 */
+  data_len = dl_len - 5;	/* XXX - dl_len - 6, as we're no longer including the transport layer byte? */
   tmp = g_malloc(data_len);
   tmp_ptr = tmp;
   i = 0;
+  data_offset = 1;	/* skip the transport layer byte when assembling chunks */
   while(data_len > 0) {
     guint8 chk_size;
+    const guint8 *chk_ptr;
     guint16 calc_crc, act_crc;
+
     chk_size = MIN(data_len, AL_MAX_CHUNK_SIZE);
-    tvb_memcpy(tvb, tmp_ptr, offset, chk_size);
-    calc_crc = calculateCRC(tmp_ptr, chk_size);
+    chk_ptr = tvb_get_ptr(tvb, offset, chk_size);
+    memcpy(tmp_ptr, chk_ptr + data_offset, chk_size - data_offset);
+    calc_crc = calculateCRC(chk_ptr, chk_size);
     offset += chk_size;
-    tmp_ptr += chk_size;
+    tmp_ptr += chk_size - data_offset;
     act_crc = tvb_get_letohs(tvb, offset);
     offset += 2;
     crc_OK = calc_crc == act_crc;
@@ -555,11 +571,12 @@ dissect_dnp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       break;
     }
     i++;
+    data_offset = 0;	/* copy all of the rest of the chunks */
   }
 
   /* if all crc OK, set up new tvb */
   if (crc_OK) {
-    al_tvb = tvb_new_real_data(&tmp[1], tmp_ptr-tmp, tmp_ptr-tmp);
+    al_tvb = tvb_new_real_data(tmp, tmp_ptr-tmp, tmp_ptr-tmp);
     tvb_set_free_cb(al_tvb, g_free);
     tvb_set_child_real_data_tvbuff(tvb, al_tvb);
 
@@ -607,11 +624,13 @@ dissect_dnp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       add_new_data_source(pinfo, al_tvb, "DNP 3.0 Application Layer message");
     }
   }
-  else if (tree)
+  else {
+    /* CRC error - throw away the data. */
+    g_free(tmp);
+    if (tree)
       proto_tree_add_text(dnp3_tree, tvb, 11, -1,
-              "Application tvb allocation failed %d chunks", i);
-
-  if (!al_tvb && tmp) g_free(tmp);
+              "CRC failed, %d chunks", i);
+  }
 
   if (al_tvb)
     dissect_dnp3_al(al_tvb, pinfo, dnp3_tree);
