@@ -1,7 +1,10 @@
 /* packet-dns.c
  * Routines for DNS packet disassembly
  *
- * $Id: packet-dns.c 12130 2004-09-29 00:52:45Z guy $
+ * RFC 1034, RFC 1035
+ * RFC 2136 for dynamic DNS
+ *
+ * $Id: packet-dns.c 13016 2005-01-13 07:51:08Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -58,9 +61,20 @@ static int hf_dns_flags_checkdisable = -1;
 static int hf_dns_flags_rcode = -1;
 static int hf_dns_transaction_id = -1;
 static int hf_dns_count_questions = -1;
+static int hf_dns_count_zones = -1;
 static int hf_dns_count_answers = -1;
+static int hf_dns_count_prerequisites = -1;
+static int hf_dns_count_updates = -1;
 static int hf_dns_count_auth_rr = -1;
 static int hf_dns_count_add_rr = -1;
+static int hf_dns_qry_name = -1;
+static int hf_dns_qry_type = -1;
+static int hf_dns_qry_class = -1;
+static int hf_dns_rr_name = -1;
+static int hf_dns_rr_type = -1;
+static int hf_dns_rr_class = -1;
+static int hf_dns_rr_ttl = -1;
+static int hf_dns_rr_len = -1;
 
 static gint ett_dns = -1;
 static gint ett_dns_qd = -1;
@@ -76,6 +90,7 @@ static gboolean dns_desegment = TRUE;
 
 /* Dissector handle for GSSAPI */
 static dissector_handle_t gssapi_handle;
+static dissector_handle_t ntlmssp_handle;
 
 /* DNS structs and definitions */
 
@@ -138,10 +153,10 @@ static dissector_handle_t gssapi_handle;
 #define T_DNAME         39              /* Non-terminal DNS name redirection (RFC 2672) */
 #define T_OPT		41		/* OPT pseudo-RR (RFC 2671) */
 #define T_DS            43		/* Delegation Signature(RFC 3658) */
+#define T_IPSECKEY      45              /* draft-ietf-ipseckey-rr */
 #define T_RRSIG         46              /* future RFC 2535bis */
 #define T_NSEC          47              /* future RFC 2535bis */
 #define T_DNSKEY        48              /* future RFC 2535bis */
-#define T_IPSECKEY      49              /* still TBD draft-ietf-ipseckey-rr */
 #define T_TKEY		249		/* Transaction Key (RFC 2930) */
 #define T_TSIG		250		/* Transaction Signature (RFC 2845) */
 #define T_WINS		65281		/* Microsoft's WINS RR */
@@ -288,110 +303,88 @@ http://www.windows.com/windows2000/en/server/help/sag_DNS_imp_UsingWinsLookup.ht
 http://www.microsoft.com/windows2000/library/resources/reskit/samplechapters/cncf/cncf_imp_wwaw.asp
 
    which discuss them to some extent. */
+
+static const value_string dns_types[] = {
+	{ 0,		"Unused" },
+	{ T_A,		"A" },
+	{ T_NS,		"NS" },
+	{ T_MD,		"MD" },
+	{ T_MF,		"MF" },
+	{ T_CNAME,	"CNAME" },
+	{ T_SOA,	"SOA" },
+	{ T_MB,		"MB" },
+	{ T_MG,		"MG" },
+	{ T_MR,		"MR" },
+	{ T_NULL,	"NULL" },
+	{ T_WKS,	"WKS" },
+	{ T_PTR,	"PTR" },
+	{ T_HINFO,	"HINFO" },
+	{ T_MINFO,	"MINFO" },
+	{ T_MX,		"MX" },
+	{ T_TXT,	"TXT" },
+	{ T_RP,		"RP" }, /* RFC 1183 */
+	{ T_AFSDB,	"AFSDB" }, /* RFC 1183 */
+	{ T_X25,	"X25" }, /* RFC 1183 */
+	{ T_ISDN,	"ISDN" }, /* RFC 1183 */
+	{ T_RT,		"RT" }, /* RFC 1183 */
+	{ T_NSAP,	"NSAP" }, /* RFC 1706 */
+	{ T_NSAP_PTR,	"NSAP-PTR" }, /* RFC 1348 */
+	{ T_SIG,	"SIG" }, /* RFC 2535 */
+	{ T_KEY,	"KEY" }, /* RFC 2535 */
+	{ T_PX,		"PX" }, /* RFC 1664 */
+	{ T_GPOS,	"GPOS" }, /* RFC 1712 */
+	{ T_AAAA,	"AAAA" }, /* RFC 1886 */
+	{ T_LOC,	"LOC" }, /* RFC 1886 */
+	{ T_NXT,	"NXT" }, /* RFC 1876 */
+	{ T_EID,	"EID" },
+	{ T_NIMLOC,	"NIMLOC" },
+	{ T_SRV,	"SRV" }, /* RFC 2052 */
+	{ T_ATMA,	"ATMA" },
+	{ T_NAPTR,	"NAPTR" }, /* RFC 2168 */
+	{ T_KX,		"KX" }, /* RFC 2230 */
+	{ T_CERT,	"CERT" }, /* RFC 2538 */
+	{ T_A6,		"A6" }, /* RFC 2874 */
+	{ T_DNAME,	"DNAME" }, /* RFC 2672 */
+
+	{ T_OPT,	"OPT" }, /* RFC 2671 */
+
+	{ T_DS,		"DS" }, /* RFC 3658 */
+
+	{ T_IPSECKEY,	"IPSECKEY" }, /* draft-ietf-ipseckey-rr */
+	{ T_RRSIG,	"RRSIG" }, /* future RFC 2535bis */
+	{ T_NSEC,	"NSEC" }, /* future RFC 2535bis */
+	{ T_DNSKEY,	"DNSKEY" }, /* future RFC 2535bis */
+
+	{ 100,		"UINFO" },
+	{ 101,		"UID" },
+	{ 102,		"GID" },
+	{ 103,		"UNSPEC" },
+
+	{ T_TKEY,	"TKEY"},
+	{ T_TSIG,	"TSIG"},
+
+	{ T_WINS,	"WINS"},
+	{ T_WINS_R,	"WINS-R"},
+
+	{ 251,		"IXFR"},
+	{ 252,		"AXFR"},
+	{ 253,		"MAILB"},
+	{ 254,		"MAILA"},
+	{ 255,		"ANY"},
+
+	{0,		NULL}
+};
+
 static char *
 dns_type_name (guint type)
 {
-  char *type_names[] = {
-    "unused",
-    "A",
-    "NS",
-    "MD",
-    "MF",
-    "CNAME",
-    "SOA",
-    "MB",
-    "MG",
-    "MR",
-    "NULL",
-    "WKS",
-    "PTR",
-    "HINFO",
-    "MINFO",
-    "MX",
-    "TXT",
-    "RP",				/* RFC 1183 */
-    "AFSDB",				/* RFC 1183 */
-    "X25",				/* RFC 1183 */
-    "ISDN",				/* RFC 1183 */
-    "RT",				/* RFC 1183 */
-    "NSAP",				/* RFC 1706 */
-    "NSAP-PTR",				/* RFC 1348 */
-    "SIG",				/* RFC 2535 */
-    "KEY",				/* RFC 2535 */
-    "PX",				/* RFC 1664 */
-    "GPOS",				/* RFC 1712 */
-    "AAAA",				/* RFC 1886 */
-    "LOC",				/* RFC 1876 */
-    "NXT",				/* RFC 2535 */
-    "EID",
-    "NIMLOC",
-    "SRV",				/* RFC 2052 */
-    "ATMA",
-    "NAPTR",				/* RFC 2168 */
-    "KX",				/* RFC 2230 */
-    "CERT",				/* RFC 2538 */
-    "A6",				/* RFC 2874 */
-    "DNAME",				/* RFC 2672 */
-    NULL,
-    "OPT",				/* RFC 2671 */
-    NULL,
-    "DS",				/* RFC 3658 */
-    NULL,
-    NULL,
-    "RRSIG",                            /* future RFC 2535bis */
-    "NSEC",                             /* future RFC 2535bis */
-    "DNSKEY",                           /* future RFC 2535bis */
-    "IPSECKEY"                          /* draft-ietf-ipseckey-rr */
-  };
-
-  if (type < sizeof(type_names)/sizeof(type_names[0]))
-    return type_names[type] ? type_names[type] : "unknown";
-
-  /* special cases */
-  switch (type)
-    {
-      /* non standard  */
-    case 100:
-      return "UINFO";
-    case 101:
-      return "UID";
-    case 102:
-      return "GID";
-    case 103:
-      return "UNSPEC";
-    case T_WINS:
-      return "WINS";
-    case T_WINS_R:
-      return "WINS-R";
-
-      /* meta */
-    case T_TKEY:
-      return "TKEY";
-    case T_TSIG:
-      return "TSIG";
-
-      /* queries  */
-    case 251:
-      return "IXFR";	/* RFC 1995 */
-    case 252:
-      return "AXFR";
-    case 253:
-      return "MAILB";
-    case 254:
-      return "MAILA";
-    case 255:
-      return "ANY";
-
-    }
-
-  return "unknown";
+  return val_to_str(type, dns_types, "Unknown (%u)");
 }
 
-
 static char *
-dns_long_type_name (guint type)
+dns_type_description (guint type)
 {
-  char *type_names[] = {
+  static const char *type_names[] = {
     "unused",
     "Host address",
     "Authoritative name server",
@@ -437,90 +430,77 @@ dns_long_type_name (guint type)
     NULL,
     "Delegation Signer",                /* RFC 3658 */
     NULL,
-    NULL,
+    "key to use with IPSEC",            /* draft-ietf-ipseckey-rr */
     "RR signature",                     /* future RFC 2535bis */
     "Next secured",                     /* future RFC 2535bis */
-    "DNS public key",                   /* future RFC 2535bis */
-    "key to use with IPSEC"             /* draft-ietf-ipseckey-rr */
+    "DNS public key"                    /* future RFC 2535bis */
   };
-  static char unkbuf[7+1+2+1+4+1+1+10+1+1];	/* "Unknown RR type (%u)" */
+  char *short_name;
+  const char *long_name;
+  static char strbuf[1024+1];
 
+  short_name = dns_type_name(type);
+  if (short_name == NULL) {
+    snprintf(strbuf, sizeof strbuf, "Unknown (%u)", type);
+    return strbuf;
+  }
   if (type < sizeof(type_names)/sizeof(type_names[0]))
-    return type_names[type] ? type_names[type] : "unknown";
+    long_name = type_names[type];
+  else {
+    /* special cases */
+    switch (type) {
+        /* meta */
+      case T_TKEY:
+        long_name = "Transaction Key";
+        break;
+      case T_TSIG:
+        long_name = "Transaction Signature";
+        break;
 
-  /* special cases */
-  switch (type)
-    {
-      /* non standard  */
-    case 100:
-      return "UINFO";
-    case 101:
-      return "UID";
-    case 102:
-      return "GID";
-    case 103:
-      return "UNSPEC";
-    case T_WINS:
-      return "WINS";
-    case T_WINS_R:
-      return "WINS-R";
+        /* queries  */
+      case 251:
+        long_name = "Request for incremental zone transfer";	/* RFC 1995 */
+        break;
+      case 252:
+        long_name = "Request for full zone transfer";
+        break;
+      case 253:
+        long_name = "Request for mailbox-related records";
+        break;
+      case 254:
+        long_name = "Request for mail agent resource records";
+        break;
+      case 255:
+        long_name = "Request for all records";
+        break;
+      default:
+        long_name = NULL;
+        break;
+      }
+  }
 
-      /* meta */
-    case T_TKEY:
-      return "Transaction Key";
-    case T_TSIG:
-      return "Transaction Signature";
-
-      /* queries  */
-    case 251:
-      return "Request for incremental zone transfer";	/* RFC 1995 */
-    case 252:
-      return "Request for full zone transfer";
-    case 253:
-      return "Request for mailbox-related records";
-    case 254:
-      return "Request for mail agent resource records";
-    case 255:
-      return "Request for all records";
-    }
-
-  sprintf(unkbuf, "Unknown RR type (%u)", type);
-  return unkbuf;
+  if (long_name != NULL)
+    snprintf(strbuf, sizeof strbuf, "%s (%s)", short_name, long_name);
+  else
+    snprintf(strbuf, sizeof strbuf, "%s", short_name);
+  return strbuf;
 }
 
+static const value_string dns_classes[] = {
+	{C_IN, "IN"},
+	{C_CS, "CS"},
+	{C_CH, "CH"},
+	{C_HS, "HS"},
+	{C_NONE, "NONE"},
+	{C_ANY, "ANY"},
+	{C_IN | C_FLUSH, "FLUSH"},
+	{0,NULL}
+};
 
 char *
 dns_class_name(int class)
 {
-  char *class_name;
-
-  switch (class) {
-  case C_IN:
-    class_name = "inet";
-    break;
-  case ( C_IN | C_FLUSH ):
-    class_name = "inet (data flush)";
-    break;
-  case C_CS:
-    class_name = "csnet";
-    break;
-  case C_CH:
-    class_name = "chaos";
-    break;
-  case C_HS:
-    class_name = "hesiod";
-    break;
-  case C_NONE:
-    class_name = "none";
-    break;
-  case C_ANY:
-    class_name = "any";
-    break;
-  default:
-    class_name = "unknown";
-  }
-
-  return class_name;
+  return val_to_str(class, dns_classes, "Unknown (%u)");
 }
 
 int
@@ -770,9 +750,7 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
   int name_len;
   int type;
   int class;
-  char *class_name;
   char *type_name;
-  char *long_type_name;
   int data_offset;
   int data_start;
   proto_tree *q_tree;
@@ -785,23 +763,22 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
   data_offset += len;
 
   type_name = dns_type_name(type);
-  class_name = dns_class_name(class);
-  long_type_name = dns_long_type_name(type);
 
   if (cinfo != NULL)
     col_append_fstr(cinfo, COL_INFO, " %s %s", type_name, name);
   if (dns_tree != NULL) {
     tq = proto_tree_add_text(dns_tree, tvb, offset, len, "%s: type %s, class %s",
-		   name, type_name, class_name);
+		   name, type_name, dns_class_name(class));
     q_tree = proto_item_add_subtree(tq, ett_dns_qd);
 
-    proto_tree_add_text(q_tree, tvb, offset, name_len, "Name: %s", name);
+    proto_tree_add_string(q_tree, hf_dns_qry_name, tvb, offset, name_len, name);
     offset += name_len;
 
-    proto_tree_add_text(q_tree, tvb, offset, 2, "Type: %s", long_type_name);
+    proto_tree_add_uint_format(q_tree, hf_dns_qry_type, tvb, offset, 2, type,
+		"Type: %s", dns_type_description(type));
     offset += 2;
 
-    proto_tree_add_text(q_tree, tvb, offset, 2, "Class: %s", class_name);
+    proto_tree_add_uint(q_tree, hf_dns_qry_class, tvb, offset, 2, class);
     offset += 2;
   }
 
@@ -809,39 +786,42 @@ dissect_dns_query(tvbuff_t *tvb, int offset, int dns_data_offset,
 }
 
 
-proto_tree *
+static proto_tree *
 add_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
-  const char *name, int namelen, const char *type_name, const char *class_name,
+  const char *name, int namelen, int type, int class,
   guint ttl, gushort data_len)
 {
   proto_tree *rr_tree;
 
   rr_tree = proto_item_add_subtree(trr, rr_type);
-  proto_tree_add_text(rr_tree, tvb, offset, namelen, "Name: %s", name);
+  proto_tree_add_string(rr_tree, hf_dns_rr_name, tvb, offset, namelen, name);
   offset += namelen;
-  proto_tree_add_text(rr_tree, tvb, offset, 2, "Type: %s", type_name);
+  proto_tree_add_uint_format(rr_tree, hf_dns_rr_type, tvb, offset, 2, type,
+		"Type: %s", dns_type_description(type));
   offset += 2;
-  proto_tree_add_text(rr_tree, tvb, offset, 2, "Class: %s", class_name);
+  proto_tree_add_uint(rr_tree, hf_dns_rr_class, tvb, offset, 2, class);
   offset += 2;
-  proto_tree_add_text(rr_tree, tvb, offset, 4, "Time to live: %s",
-						time_secs_to_str(ttl));
+  proto_tree_add_uint_format(rr_tree, hf_dns_rr_ttl, tvb, offset, 4, ttl,
+		"Time to live: %s", time_secs_to_str(ttl));
   offset += 4;
-  proto_tree_add_text(rr_tree, tvb, offset, 2, "Data length: %u", data_len);
+  proto_tree_add_uint(rr_tree, hf_dns_rr_len, tvb, offset, 2, data_len);
   return rr_tree;
 }
 
+
 static proto_tree *
 add_opt_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
-  const char *name, int namelen, const char *type_name, int class,
+  const char *name, int namelen, int type, int class,
   guint ttl, gushort data_len)
 {
   proto_tree *rr_tree, *Z_tree;
   proto_item *Z_item = NULL;
 
   rr_tree = proto_item_add_subtree(trr, rr_type);
-  proto_tree_add_text(rr_tree, tvb, offset, namelen, "Name: %s", name);
+  proto_tree_add_string(rr_tree, hf_dns_rr_name, tvb, offset, namelen, name);
   offset += namelen;
-  proto_tree_add_text(rr_tree, tvb, offset, 2, "Type: %s", type_name);
+  proto_tree_add_uint_format(rr_tree, hf_dns_rr_type, tvb, offset, 2, type,
+		"Type: %s", dns_type_description(type));
   offset += 2;
   proto_tree_add_text(rr_tree, tvb, offset, 2, "UDP payload size: %u",
       class & 0xffff);
@@ -859,7 +839,7 @@ add_opt_rr_to_tree(proto_item *trr, int rr_type, tvbuff_t *tvb, int offset,
      proto_tree_add_text(Z_tree, tvb, offset, 2, "Bits 1-15: 0x%x (reserved)", (ttl >> 17) & 0xff);
   }
   offset += 2;
-  proto_tree_add_text(rr_tree, tvb, offset, 2, "Data length: %u", data_len);
+  proto_tree_add_uint(rr_tree, hf_dns_rr_len, tvb, offset, 2, data_len);
   return rr_tree;
 }
 
@@ -945,7 +925,6 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
   int class;
   char *class_name;
   char *type_name;
-  char *long_type_name;
   int data_offset;
   int cur_offset;
   int data_start;
@@ -964,7 +943,6 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 
   type_name = dns_type_name(type);
   class_name = dns_class_name(class);
-  long_type_name = dns_long_type_name(type);
 
   ttl = tvb_get_ntohl(tvb, data_offset);
   data_offset += 4;
@@ -977,19 +955,25 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
   if (cinfo != NULL)
     col_append_fstr(cinfo, COL_INFO, " %s", type_name);
   if (dns_tree != NULL) {
-    trr = proto_tree_add_text(dns_tree, tvb, offset,
-				(data_offset - data_start) + data_len,
-				"%s: type %s, class %s",
-				name, type_name, class_name);
     if (type != T_OPT) {
+      trr = proto_tree_add_text(dns_tree, tvb, offset,
+		    (data_offset - data_start) + data_len,
+		    "%s: type %s, class %s",
+		    name, type_name, class_name);
       rr_tree = add_rr_to_tree(trr, ett_dns_rr, tvb, offset, name, name_len,
-		     long_type_name, class_name, ttl, data_len);
+		     type, class, ttl, data_len);
     } else  {
+      trr = proto_tree_add_text(dns_tree, tvb, offset,
+		    (data_offset - data_start) + data_len,
+		    "%s: type %s", name, type_name);
       rr_tree = add_opt_rr_to_tree(trr, ett_dns_rr, tvb, offset, name, name_len,
-		     long_type_name, class, ttl, data_len);
+		     type, class, ttl, data_len);
     }
   }
 
+  if (data_len == 0)
+    return data_offset - data_start;
+
   switch (type) {
 
   case T_A:
@@ -1007,7 +991,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
       }
       if ((class & 0x7f) == C_IN) {
 	memcpy(&addr_int, addr, sizeof(addr_int));
-	add_host_name(addr_int, name);
+	add_ipv4_name(addr_int, name);
       }
     }
     break;
@@ -1272,9 +1256,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 	if (rr_len < 2)
 	  goto bad_rr;
 	type_covered = tvb_get_ntohs(tvb, cur_offset);
-	proto_tree_add_text(rr_tree, tvb, cur_offset, 2, "Type covered: %s (%s)",
-		dns_type_name(type_covered),
-		dns_long_type_name(type_covered));
+	proto_tree_add_text(rr_tree, tvb, cur_offset, 2, "Type covered: %s",
+		dns_type_description(type_covered));
 	cur_offset += 2;
 	rr_len -= 2;
 
@@ -1494,6 +1477,7 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
   case T_AAAA:
     {
       const guint8 *addr6;
+      struct e_in6_addr addr_in6;
 
       addr6 = tvb_get_ptr(tvb, cur_offset, 16);
       if (cinfo != NULL) {
@@ -1506,6 +1490,10 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 	proto_tree_add_text(rr_tree, tvb, cur_offset, 16, "Addr: %s",
 		     ip6_to_str((const struct e_in6_addr *)addr6));
       }
+      if ((class & 0x7f) == C_IN) {
+	memcpy(&addr_in6, addr6, sizeof(addr_in6));
+	add_ipv6_name(&addr_in6, name);
+      }
     }
     break;
 
@@ -1660,9 +1648,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 	       for (i = 0; i < 8; i++) {
 		 if (bits & mask) {
 		   proto_tree_add_text(rr_tree, tvb, cur_offset, 1,
-			"RR type in bit map: %s (%s)",
-			dns_type_name(rr_type),
-			dns_long_type_name(rr_type));
+			"RR type in bit map: %s",
+			dns_type_description(rr_type));
 		 }
 		 mask >>= 1;
 		 rr_type++;
@@ -1703,9 +1690,8 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 	  for (i = 0; i < 8; i++) {
 	    if (bits & mask) {
 	      proto_tree_add_text(rr_tree, tvb, cur_offset, 1,
-			"RR type in bit map: %s (%s)",
-			dns_type_name(rr_type),
-			dns_long_type_name(rr_type));
+			"RR type in bit map: %s",
+			dns_type_description(rr_type));
 	    }
 	    mask >>= 1;
 	    rr_type++;
@@ -1872,20 +1858,20 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 	if (rr_len < 2)
 	  goto bad_rr;
 	tkey_mode = tvb_get_ntohs(tvb, cur_offset);
-	cur_offset += 2;
-	rr_len -= 2;
 	proto_tree_add_text(rr_tree, tvb, cur_offset, 2, "Mode: %s",
 		val_to_str(tkey_mode, tkey_modes,
 	            "Unknown (0x%04X)"));
+	cur_offset += 2;
+	rr_len -= 2;
 
 	if (rr_len < 2)
 	  goto bad_rr;
 	tkey_error = tvb_get_ntohs(tvb, cur_offset);
-	cur_offset += 2;
-	rr_len -= 2;
         proto_tree_add_text(rr_tree, tvb, cur_offset, 2, "Error: %s",
 		val_to_str(tkey_error, rcode_vals,
 		val_to_str(tkey_error, tsigerror_vals, "Unknown error (%x)")));
+	cur_offset += 2;
+	rr_len -= 2;
 
 	tkey_keylen = tvb_get_ntohs(tvb, cur_offset);
         proto_tree_add_text(rr_tree, tvb, cur_offset, 2, "Key Size: %u",
@@ -1915,14 +1901,16 @@ dissect_dns_answer(tvbuff_t *tvb, int offset, int dns_data_offset,
 			 * How the heck do we know what method is being
 			 * used, so we know how to decode the key?  Do we
 			 * have to look at the algorithm name, e.g.
-			 * "gss.microsoft.com"?  The SMB dissector
-			 * checks whether the security blob begins
-			 * with "NTLMSSP" in some cases.
+			 * "gss.microsoft.com"?  We currently do as the
+			 * the SMB dissector does in some cases, and check
+			 * whether the security blob begins with "NTLMSSP".
 			 */
 			gssapi_tvb = tvb_new_subset(
 				tvb, cur_offset, tkey_keylen, tkey_keylen);
-
-			call_dissector(gssapi_handle, gssapi_tvb, pinfo,
+			if(tvb_strneql(gssapi_tvb, 0, "NTLMSSP", 7) == 0)
+				call_dissector(ntlmssp_handle, gssapi_tvb, pinfo, key_tree);
+			else
+				call_dissector(gssapi_handle, gssapi_tvb, pinfo,
 				key_tree);
 
 			break;
@@ -2267,7 +2255,7 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   guint16    id, flags, opcode, rcode, quest, ans, auth, add;
   char buf[128+1];
   int cur_off;
-  int isupdate;
+  gboolean isupdate;
 
   dns_data_offset = offset;
 
@@ -2300,9 +2288,9 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     cinfo = NULL;
   }
   if (opcode == OPCODE_UPDATE)
-    isupdate = 1;
+    isupdate = TRUE;
   else
-    isupdate = 0;
+    isupdate = FALSE;
 
   if (tree) {
     ti = proto_tree_add_protocol_format(tree, proto_dns, tvb, 0, -1,
@@ -2361,18 +2349,33 @@ dissect_dns_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
   }
   quest = tvb_get_ntohs(tvb, offset + DNS_QUEST);
   if (tree) {
-    proto_tree_add_uint(dns_tree, hf_dns_count_questions, tvb,
-			offset + DNS_QUEST, 2, quest);
+    if (isupdate) {
+      proto_tree_add_uint(dns_tree, hf_dns_count_zones, tvb,
+			  offset + DNS_QUEST, 2, quest);
+    } else {
+      proto_tree_add_uint(dns_tree, hf_dns_count_questions, tvb,
+			  offset + DNS_QUEST, 2, quest);
+    }
   }
   ans = tvb_get_ntohs(tvb, offset + DNS_ANS);
   if (tree) {
-    proto_tree_add_uint(dns_tree, hf_dns_count_answers, tvb,
-			offset + DNS_ANS, 2, ans);
+    if (isupdate) {
+      proto_tree_add_uint(dns_tree, hf_dns_count_prerequisites, tvb,
+			  offset + DNS_ANS, 2, ans);
+    } else {
+      proto_tree_add_uint(dns_tree, hf_dns_count_answers, tvb,
+			  offset + DNS_ANS, 2, ans);
+    }
   }
   auth = tvb_get_ntohs(tvb, offset + DNS_AUTH);
   if (tree) {
-    proto_tree_add_uint(dns_tree, hf_dns_count_auth_rr, tvb,
-			offset + DNS_AUTH, 2, auth);
+    if (isupdate) {
+      proto_tree_add_uint(dns_tree, hf_dns_count_updates, tvb,
+			  offset + DNS_AUTH, 2, auth);
+    } else {
+      proto_tree_add_uint(dns_tree, hf_dns_count_auth_rr, tvb,
+			  offset + DNS_AUTH, 2, auth);
+    }
   }
   add = tvb_get_ntohs(tvb, offset + DNS_ADD);
   if (tree) {
@@ -2524,18 +2527,62 @@ proto_register_dns(void)
       { "Transaction ID",      	"dns.id",
 	FT_UINT16, BASE_HEX, NULL, 0x0,
 	"Identification of transaction", HFILL }},
+    { &hf_dns_qry_type,
+      { "Type",      	"dns.qry.type",
+	FT_UINT16, BASE_HEX, VALS(dns_types), 0x0,
+	"Query Type", HFILL }},
+    { &hf_dns_qry_class,
+      { "Class",      	"dns.qry.class",
+	FT_UINT16, BASE_HEX, VALS(dns_classes), 0x0,
+	"Query Class", HFILL }},
+    { &hf_dns_qry_name,
+      { "Name",      	"dns.qry.name",
+	FT_STRING, BASE_NONE, NULL, 0x0,
+	"Query Name", HFILL }},
+    { &hf_dns_rr_type,
+      { "Type",      	"dns.resp.type",
+	FT_UINT16, BASE_HEX, VALS(dns_types), 0x0,
+	"Response Type", HFILL }},
+    { &hf_dns_rr_class,
+      { "Class",      	"dns.resp.class",
+	FT_UINT16, BASE_HEX, VALS(dns_classes), 0x0,
+	"Response Class", HFILL }},
+    { &hf_dns_rr_name,
+      { "Name",      	"dns.resp.name",
+	FT_STRING, BASE_NONE, NULL, 0x0,
+	"Response Name", HFILL }},  
+    { &hf_dns_rr_ttl,
+      { "Time to live", "dns.resp.ttl",
+	FT_UINT32, BASE_DEC, NULL, 0x0,
+	"Response TTL", HFILL }},
+    { &hf_dns_rr_len,
+      { "Data length",  "dns.resp.len",
+	FT_UINT32, BASE_DEC, NULL, 0x0,
+	"Response Length", HFILL }},
     { &hf_dns_count_questions,
       { "Questions",		"dns.count.queries",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
 	"Number of queries in packet", HFILL }},
+    { &hf_dns_count_zones,
+      { "Zones",		"dns.count.zones",
+	FT_UINT16, BASE_DEC, NULL, 0x0,
+	"Number of zones in packet", HFILL }},
     { &hf_dns_count_answers,
       { "Answer RRs",		"dns.count.answers",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
 	"Number of answers in packet", HFILL }},
+    { &hf_dns_count_prerequisites,
+      { "Prerequisites",		"dns.count.prerequisites",
+	FT_UINT16, BASE_DEC, NULL, 0x0,
+	"Number of prerequisites in packet", HFILL }},
     { &hf_dns_count_auth_rr,
       { "Authority RRs",       	"dns.count.auth_rr",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
 	"Number of authoritative records in packet", HFILL }},
+    { &hf_dns_count_updates,
+      { "Updates",       	"dns.count.updates",
+	FT_UINT16, BASE_DEC, NULL, 0x0,
+	"Number of updates records in packet", HFILL }},
     { &hf_dns_count_add_rr,
       { "Additional RRs",      	"dns.count.add_rr",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
@@ -2582,4 +2629,5 @@ proto_reg_handoff_dns(void)
   dissector_add("tcp.port", TCP_PORT_MDNS, dns_tcp_handle);
 
   gssapi_handle = find_dissector("gssapi");
+  ntlmssp_handle = find_dissector("ntlmssp");
 }
