@@ -2,7 +2,7 @@
  * Routines for FC Fabric Zone Server
  * Copyright 2001, Dinesh G Dutt <ddutt@andiamo.com>
  *
- * $Id: packet-fcfzs.c 11410 2004-07-18 18:06:47Z gram $
+ * $Id: packet-fcfzs.c 12890 2004-12-31 02:08:01Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -108,8 +108,8 @@ static dissector_handle_t data_handle;
 static gint
 fcfzs_equal(gconstpointer v, gconstpointer w)
 {
-  fcfzs_conv_key_t *v1 = (fcfzs_conv_key_t *)v;
-  fcfzs_conv_key_t *v2 = (fcfzs_conv_key_t *)w;
+  const fcfzs_conv_key_t *v1 = v;
+  const fcfzs_conv_key_t *v2 = w;
 
   return (v1->conv_idx == v2->conv_idx);
 }
@@ -117,7 +117,7 @@ fcfzs_equal(gconstpointer v, gconstpointer w)
 static guint
 fcfzs_hash (gconstpointer v)
 {
-	fcfzs_conv_key_t *key = (fcfzs_conv_key_t *)v;
+	const fcfzs_conv_key_t *key = v;
 	guint val;
 
 	val = key->conv_idx;
