@@ -9,7 +9,7 @@
  * Copyright 2001, Michael Tuexen <tuexen [AT] fh-muenster.de>
  * Updated for ANSI and Chinese ITU support by Jeff Morriss <jeff.morriss[AT]ulticom.com>
  *
- * $Id: packet-mtp3.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: packet-mtp3.c 12891 2004-12-31 02:09:48Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -92,13 +92,13 @@ typedef enum {
   ITU_PC_STRUCTURE_4_3_4_3 = 3
 } ITU_PC_Structure_Type;
 
-ITU_PC_Structure_Type itu_pc_structure = ITU_PC_STRUCTURE_NONE;
+gint itu_pc_structure = ITU_PC_STRUCTURE_NONE;
 
 #include <packet-mtp3.h>
-Standard_Type mtp3_standard = ITU_STANDARD;
+gint mtp3_standard = ITU_STANDARD;
 
 static gboolean mtp3_use_ansi_5_bit_sls = FALSE;
-static mtp3_net_addr_fmt_e mtp3_net_addr_fmt = MTP3_NET_ADDR_FMT_DASHED;
+static gint mtp3_net_addr_fmt = MTP3_NET_ADDR_FMT_DASHED;
 static mtp3_addr_pc_t mtp3_addr_dpc, mtp3_addr_opc;
 
 #define SIO_LENGTH                1
@@ -147,8 +147,8 @@ static const value_string mtp3_service_indicator_code_vals[] = {
 	{ 0x6,	"DUP (call and circuit related messages)" },
 	{ 0x7,	"DUP (facility registration and cancellation message)" },
 	{ 0x8,	"MTP testing user part" },
-	{ 0x9,	"Spare" },
-	{ 0xa,	"Spare" },
+	{ 0x9,	"Broadband ISUP" },
+	{ 0xa,	"Satellite ISUP" },
 	{ 0xb,	"Spare" },
 	{ 0xc,	"Spare" },
 	{ 0xd,	"Spare" },
@@ -167,6 +167,8 @@ const value_string mtp3_service_indicator_code_short_vals[] = {
 	{ 0x6,	"DUP (CC)" },
 	{ 0x7,	"DUP (FAC/CANC)" },
 	{ 0x8,	"MTP Test" },
+	{ 0x9,	"ISUP-b" },
+	{ 0xa,	"ISUP-s" },
 	{ 0,	NULL }
 };
 
@@ -245,7 +247,7 @@ mtp3_addr_to_str_buf(
   const guint8		*data,
   gchar			*buf)
 {
-  mtp3_addr_pc_t	*addr_pc_p = (mtp3_addr_pc_t *) data;
+  const mtp3_addr_pc_t	*addr_pc_p = (const mtp3_addr_pc_t *)data;
 
   switch (mtp3_net_addr_fmt)
   {
@@ -339,7 +341,7 @@ dissect_mtp3_sio(tvbuff_t *tvb, packet_info *pinfo, proto_tree *mtp3_tree)
   proto_tree_add_uint(sio_tree, hf_mtp3_service_indicator, tvb, SIO_OFFSET, SIO_LENGTH, sio);
 
   /* Store the SI so that subidissectors know what SI this msg is */
-  pinfo->private_data = (void *)(sio & SERVICE_INDICATOR_MASK);
+  pinfo->private_data = GUINT_TO_POINTER(sio & SERVICE_INDICATOR_MASK);
 }
 
 static void
@@ -465,7 +467,7 @@ dissect_mtp3_payload(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 static void
 dissect_mtp3(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-  mtp3_tap_rec_t	tap_rec;
+  static mtp3_tap_rec_t	tap_rec;
 
   /* Set up structures needed to add the protocol subtree and manage it */
   proto_item *mtp3_item = NULL;
@@ -665,11 +667,11 @@ proto_register_mtp3(void)
 
   prefs_register_enum_preference(mtp3_module, "standard", "MTP3 standard",
 				 "The SS7 standard used in MTP3 packets",
-				 (gint *)&mtp3_standard, mtp3_options, FALSE);
+				 &mtp3_standard, mtp3_options, FALSE);
 
   prefs_register_enum_preference(mtp3_module, "itu_pc_structure", "ITU Pointcode structure",
 				 "The structure of the pointcodes in ITU networks",
-				 (gint *)&itu_pc_structure, itu_pc_structures, FALSE);
+				 &itu_pc_structure, itu_pc_structures, FALSE);
 
   prefs_register_bool_preference(mtp3_module, "ansi_5_bit_sls",
 				 "Use 5-bit SLS (ANSI only)",
@@ -678,7 +680,7 @@ proto_register_mtp3(void)
 
   prefs_register_enum_preference(mtp3_module, "net_addr_format", "Network Address Format",
 				 "Format for point code in the network address columns",
-				 (gint *)&mtp3_net_addr_fmt, mtp3_net_addr_fmt_str_e, FALSE);
+				 &mtp3_net_addr_fmt, mtp3_net_addr_fmt_str_e, FALSE);
 }
 
 void
