@@ -7,7 +7,7 @@ proper helper routines
  * Routines for dissection of ASN.1 Aligned PER
  * 2003  Ronnie Sahlberg
  *
- * $Id: packet-per.c 12281 2004-10-12 17:51:13Z guy $
+ * $Id: packet-per.c 13097 2005-01-17 22:25:36Z etxrab $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,6 +40,7 @@ proper helper routines
 
 #include <epan/prefs.h>
 #include "packet-per.h"
+#include "packet-ber.h"
 
 
 static int proto_per = -1;
@@ -92,8 +93,10 @@ static const true_false_string tfs_optional_field_bit = {
 	""
 };
 
-
-
+#define BYTE_ALIGN_OFFSET(offset)		\
+	if(offset&0x07){			\
+		offset=(offset&0xfffffff8)+8;	\
+	}
 
 /* 10.9 */
 /* this decodes and returns a length determinant according to 10.9 */
@@ -108,9 +111,7 @@ dissect_per_length_determinant(tvbuff_t *tvb, guint32 offset, packet_info *pinfo
 	}
 
 	/* byte aligned */
-	if(offset&0x07){
-		offset=(offset&0xfffffff8)+8;
-	}
+	BYTE_ALIGN_OFFSET(offset);
 	byte=tvb_get_guint8(tvb, offset>>3);
 	offset+=8;
 
@@ -355,13 +356,12 @@ DEBUG_ENTRY("dissect_per_restricted_character_string");
 
 	if(!length){
 		/* there is no string at all, so dont do any byte alignment */
-		byte_aligned=FALSE;
-	}
+		/* byte_aligned=FALSE; */
+		/* Advance offset to next 'element' */
+		offset = offset + 1;	}
 
 	if(byte_aligned){
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 	}
 
 
@@ -414,6 +414,13 @@ dissect_per_PrintableString(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, p
 	return offset;
 }
 guint32
+dissect_per_VisibleString(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, proto_tree *tree, int hf_index, int min_len, int max_len)
+{
+	offset=dissect_per_restricted_character_string(tvb, offset, pinfo, tree, hf_index, min_len, max_len,
+		" !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~", 95);
+	return offset;
+}
+guint32
 dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, proto_tree *tree, int hf_index, int min_len, int max_len)
 {
 	guint32 length;
@@ -445,9 +452,7 @@ dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, proto_t
 
 
 	/* align to byte boundary */
-	if(offset&0x07){
-		offset=(offset&0xfffffff8)+8;
-	}
+	BYTE_ALIGN_OFFSET(offset);
 
 	if(length>=1024){
 		PER_NOT_DECODED_YET("BMPString too long");
@@ -457,6 +462,7 @@ dissect_per_BMPString(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, proto_t
 	str = tvb_fake_unicode(tvb, offset>>3, length, FALSE);
 
 	proto_tree_add_string(tree, hf_index, tvb, offset>>3, length*2, str);
+	g_free(str);
 
 	offset+=(length<<3)*2;
 
@@ -486,12 +492,12 @@ DEBUG_ENTRY("dissect_per_constrained_sequence_of");
 
 	/* 19.6 ub>=64k or unset */
 	if(max_len>=65536){
-		guint32 old_offset=offset;
+		guint32 start_offset=offset;
 		/* semi-constrained whole number for number of elements */
 		/* each element encoded as 10.9 */
 		offset=dissect_per_length_determinant(tvb, offset, pinfo, tree, -1, &length);
 		length+=min_len;
-		proto_tree_add_uint(tree, hf_per_sequence_of_length, tvb, old_offset>>3, (offset>>3)!=(old_offset>>3)?(offset>>3)-(old_offset>>3):1, length);
+		proto_tree_add_uint(tree, hf_per_sequence_of_length, tvb, start_offset>>3, (offset>>3)!=(start_offset>>3)?(offset>>3)-(start_offset>>3):1, length);
 		goto call_sohelper;
 	}
 
@@ -543,10 +549,11 @@ guint32
 dissect_per_object_identifier(tvbuff_t *tvb, guint32 offset, packet_info *pinfo _U_, proto_tree *tree, int hf_index, char *value_string)
 {
 	int i,count;
-	char str[256],*strp;
+	char str[256],*strp,*name;
 	guint8 byte;
 	guint32 value;
 	proto_tree *etr=NULL;
+	proto_item *item;
 
 DEBUG_ENTRY("dissect_per_object_identifier");
 
@@ -555,9 +562,7 @@ DEBUG_ENTRY("dissect_per_object_identifier");
 	}
 
 	/* first byte is the count and it is byte aligned */
-	if(offset&0x07){
-		offset=(offset&0xfffffff8)+8;
-	}
+	BYTE_ALIGN_OFFSET(offset);
 	count=tvb_get_guint8(tvb, offset>>3);
 
 
@@ -597,7 +602,14 @@ PER_NOT_DECODED_YET("too long octet_string");
 	}
 	*strp=0;
 
-	proto_tree_add_string(tree, hf_index, tvb, (offset>>3)-count, count, str);
+	item=proto_tree_add_string(tree, hf_index, tvb, (offset>>3)-count, count, str);
+	/* see if we know the name of this oid */
+	if(item){
+		name = get_ber_oid_name(str);
+		if(name){
+			proto_item_append_text(item, " (%s)", name);
+		}
+	}
 
 	if (value_string) {
 		strcpy(value_string, str);
@@ -630,8 +642,7 @@ DEBUG_ENTRY("dissect_per_boolean");
 	if(hf_index!=-1){
 		char str[256];
 		hfi = proto_registrar_get_nth(hf_index);
-		sprintf(str,"%s: %c%c%c%c %c%c%c%c %s",
-			hfi->name,
+		sprintf(str,"%c%c%c%c %c%c%c%c %s: %s",
 			mask&0x80?'0'+value:'.',
 			mask&0x40?'0'+value:'.',
 			mask&0x20?'0'+value:'.',
@@ -640,6 +651,7 @@ DEBUG_ENTRY("dissect_per_boolean");
 			mask&0x04?'0'+value:'.',
 			mask&0x02?'0'+value:'.',
 			mask&0x01?'0'+value:'.',
+			hfi->name,
 			value?"True":"False"
 		);
 		it=proto_tree_add_boolean_format(tree, hf_index, tvb, offset>>3, 1, value, str);
@@ -828,9 +840,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 		pad=7-(offset&0x07);
 
 		/* in the aligned case, align to byte boundary */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		val=tvb_get_guint8(tvb, offset>>3);
 		offset+=8;
 
@@ -842,9 +852,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 		pad=7-(offset&0x07);
 
 		/* in the aligned case, align to byte boundary */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		val=tvb_get_guint8(tvb, offset>>3);
 		val<<=8;
 		offset+=8;
@@ -867,9 +875,7 @@ DEBUG_ENTRY("dissect_per_constrained_integer");
 		num_bytes++;  /* lower bound for length determinant is 1 */
 
 		/* byte aligned */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		val=0;
 		for(i=0;i<num_bytes;i++){
 			val=(val<<8)|tvb_get_guint8(tvb,offset>>3);
@@ -914,8 +920,8 @@ dissect_per_choice(tvbuff_t *tvb, guint32 offset, packet_info *pinfo, proto_tree
 	proto_item *it=NULL;
 	proto_tree *tr=NULL;
 	guint32 old_offset=offset;
-   int min_choice=INT_MAX;
-   int max_choice=-1;
+	int min_choice=INT_MAX;
+	int max_choice=-1;
 
 DEBUG_ENTRY("dissect_per_choice");
 
@@ -1338,9 +1344,7 @@ DEBUG_ENTRY("dissect_per_bit_string");
 	/* 15.10 if length is fixed and less than to 64kbits*/
 	if((min_len==max_len)&&(min_len<65536)){
 		/* align to byte */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		if (hfi) {
 			proto_tree_add_item(tree, hf_index, tvb, offset>>3, (min_len+7)/8, FALSE);
 		}
@@ -1363,9 +1367,7 @@ DEBUG_ENTRY("dissect_per_bit_string");
 	}
 	if(length){
 		/* align to byte */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		if (hfi) {
 			proto_tree_add_item(tree, hf_index, tvb, offset>>3, (length+7)/8, FALSE);
 		}
@@ -1437,9 +1439,7 @@ DEBUG_ENTRY("dissect_per_octet_string");
 
 	} else if ((min_len==max_len)&&(min_len<65536)) {  /* 16.7 if length is fixed and less than to 64k*/
 		/* align to byte */
-		if(offset&0x07){
-			offset=(offset&0xfffffff8)+8;
-		}
+		BYTE_ALIGN_OFFSET(offset);
 		val_start = offset>>3; 
 		val_length = min_len;
 		offset+=min_len*8;
@@ -1456,9 +1456,7 @@ DEBUG_ENTRY("dissect_per_octet_string");
 
 		if(length){
 			/* align to byte */
-			if(offset&0x07){
-				offset=(offset&0xfffffff8)+8;
-			}
+			BYTE_ALIGN_OFFSET(offset);
 		}
 		val_start = offset>>3; 
 		val_length = length;
