@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-sdp.c 11854 2004-08-30 10:03:54Z guy $
+ * $Id: packet-sdp.c 12963 2005-01-05 10:51:05Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -44,7 +44,15 @@
 # include <epan/inet_aton.h>
 #endif
 
-#include <glib.h>
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>		/* needed to define AF_ values on Windows */
+#endif
+
+#ifdef NEED_INET_V6DEFS_H
+# include "inet_v6defs.h"
+#endif
+
+#include <glib.h> 
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/strutil.h>
@@ -53,10 +61,13 @@
 #include "rtp_pt.h"
 #include "packet-rtcp.h"
 
+#include "packet-t38.h"
 
 static dissector_handle_t rtp_handle=NULL;
 static dissector_handle_t rtcp_handle=NULL;
 
+static dissector_handle_t t38_handle=NULL;
+
 static int proto_sdp = -1;
 
 /* Top level fields */
@@ -194,11 +205,12 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	transport_info_t transport_info;
 
-	guint32 	ipv4_address=0;
-	guint32 	ipv4_port=0;
+	guint32 	port=0;
 	gboolean 	is_rtp=FALSE;
+	gboolean        is_t38=FALSE;
 	gboolean 	is_ipv4_addr=FALSE;
-	struct in_addr	ipaddr;
+	gboolean	is_ipv6_addr=FALSE;
+    guint32 	ipaddr[4];
 	gint		n;
 
 	/* Initialise RTP channel info */
@@ -356,43 +368,58 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	for (n = 0; n < transport_info.media_count; n++)
 	{
 	    if(transport_info.media_port[n]!=NULL) {
-		    ipv4_port = atol(transport_info.media_port[n]);
+		    port = atol(transport_info.media_port[n]);
 		    g_free(transport_info.media_port[n]);
 	    }
 	    if(transport_info.media_proto[n]!=NULL) {
 		    /* Check if media protocol is RTP */
 		    is_rtp = (strcmp(transport_info.media_proto[n],"RTP/AVP")==0);
+		    /* Check if media protocol is T38 */
+		    is_t38 = ( (strcmp(transport_info.media_proto[n],"UDPTL")==0) || (strcmp(transport_info.media_proto[n],"udptl")==0) );
+
 		    g_free(transport_info.media_proto[n]);
 	    }
 	    if(transport_info.connection_address!=NULL) {
-		    if(transport_info.connection_type!=NULL &&
-			strcmp(transport_info.connection_type,"IP4")==0) {
-			    if(inet_aton(transport_info.connection_address, &ipaddr)
-				!=0 ) {
-				    /* connection_address could be converted to a valid ipv4 address*/
-				    is_ipv4_addr=TRUE;
-				    ipv4_address = ipaddr.s_addr;
-			    }
+		    if(transport_info.connection_type!=NULL) {
+		    	if (strcmp(transport_info.connection_type,"IP4")==0) {
+				    if(inet_pton(AF_INET,transport_info.connection_address, &ipaddr)==1 ) {
+					    /* connection_address could be converted to a valid ipv4 address*/
+					    is_ipv4_addr=TRUE;
+				    	src_addr.type=AT_IPv4;
+				    	src_addr.len=4;
+				    }
+				}
+				else if (strcmp(transport_info.connection_type,"IP6")==0){
+					if (inet_pton(AF_INET6, transport_info.connection_address, &ipaddr)==1){
+					    /* connection_address could be converted to a valid ipv6 address*/
+						is_ipv6_addr=TRUE;
+					    src_addr.type=AT_IPv6;
+					    src_addr.len=16;
+					}
+				}
 		    }
 	    }
-
 	    /* Add rtp and rtcp conversation, if available */
-	    if((!pinfo->fd->flags.visited) && ipv4_address!=0 && ipv4_port!=0 && is_rtp && is_ipv4_addr){
-		    src_addr.type=AT_IPv4;
-		    src_addr.len=4;
-		    src_addr.data=(char *)&ipv4_address;
-
+	    if((!pinfo->fd->flags.visited) && port!=0 && is_rtp && (is_ipv4_addr || is_ipv6_addr)){
+		    src_addr.data=(char *)&ipaddr;
 		    if(rtp_handle){
-				rtp_add_address(pinfo, &src_addr, ipv4_port, 0,
-				                "SDP", pinfo->fd->num);
+				rtp_add_address(pinfo, &src_addr, port, 0,
+	                "SDP", pinfo->fd->num);
 		    }
-
 		    if(rtcp_handle){
-				ipv4_port++;
-				rtcp_add_address(pinfo, &src_addr, ipv4_port, 0,
-				                 "SDP", pinfo->fd->num);
+				port++;
+				rtcp_add_address(pinfo, &src_addr, port, 0,
+	                 "SDP", pinfo->fd->num);
 		    }
 	    }
+			
+	    /* Add t38 conversation, if available */
+	    if((!pinfo->fd->flags.visited) && port!=0 && is_t38 && is_ipv4_addr){
+                    src_addr.data=(char *)&ipaddr;
+                    if(t38_handle){
+                                t38_add_address(pinfo, &src_addr, port, 0, "SDP", pinfo->fd->num);
+                    }
+	    }
 	}
 
 	/* Free up 'connection info' strings */
@@ -412,8 +439,7 @@ dissect_sdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 }
 
 static void
-call_sdp_subdissector(tvbuff_t *tvb, int hf, proto_tree* ti,
-		      transport_info_t *transport_info){
+call_sdp_subdissector(tvbuff_t *tvb, int hf, proto_tree* ti, transport_info_t *transport_info){
   if(hf == hf_owner){
     dissect_sdp_owner(tvb,ti);
   } else if ( hf == hf_connection_info) {
@@ -852,12 +878,14 @@ dissect_sdp_media(tvbuff_t *tvb, proto_item *ti,
     } else {
       tokenlen = next_offset - offset;
     }
-
-    media_format = tvb_get_string(tvb, offset, tokenlen);
-    if (!strcmp(transport_info->media_proto[transport_info->media_count], "RTP/AVP")) {
-		proto_tree_add_string(sdp_media_tree, hf_media_format, tvb,
-					offset, tokenlen, val_to_str(atol(media_format), rtp_payload_type_vals, "%u"));
-	} else {
+    
+    if (strcmp(transport_info->media_proto[transport_info->media_count],
+               "RTP/AVP") == 0) {
+      media_format = tvb_get_string(tvb, offset, tokenlen);
+      proto_tree_add_string(sdp_media_tree, hf_media_format, tvb, offset,
+                             tokenlen, val_to_str(atol(media_format), rtp_payload_type_vals, "%u"));
+      g_free(media_format);
+    } else {
       proto_tree_add_item(sdp_media_tree, hf_media_format, tvb,
 			  offset, tokenlen, FALSE);
     }
@@ -1149,6 +1177,8 @@ proto_reg_handoff_sdp(void)
   rtp_handle = find_dissector("rtp");
   rtcp_handle = find_dissector("rtcp");
 
+  t38_handle = find_dissector("t38");
+
   sdp_handle = find_dissector("sdp");
   dissector_add_string("media_type", "application/sdp", sdp_handle);
 }
