@@ -2,7 +2,7 @@
  * Routines for Signaling Compression (SigComp) dissection.
  * Copyright 2004, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-sigcomp.c 12239 2004-10-08 16:42:27Z guy $
+ * $Id: packet-sigcomp.c 12832 2004-12-25 13:49:30Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -45,7 +45,9 @@
 
 #include <epan/packet.h>
 #include "prefs.h"
-#include "sigcomp-udvm.h"
+#include "strutil.h"
+#include <epan/sigcomp-udvm.h>
+#include <epan/sigcomp_state_hdlr.h>
 
 /* Initialize the protocol and registered fields */
 static int proto_sigcomp							= -1;
@@ -118,7 +120,15 @@ static gboolean display_udvm_bytecode = FALSE;
 /* Default preference wether to dissect the UDVM code or not */
 static gboolean dissect_udvm_code = TRUE;
 static gboolean display_raw_txt = FALSE;
-/* Default preference wether to print debug info at execution of UDVM */
+/* Default preference wether to decompress the message or not */
+static gboolean decompress = TRUE;
+/* Default preference wether to print debug info at execution of UDVM 
+ * 0 = No printout
+ * 1 = details level 1
+ * 2 = details level 2
+ * 3 = details level 3
+ * 4 = details level 4
+ */
 static gint udvm_print_detail_level = 0;
 
 /* Value strings */
@@ -260,7 +270,14 @@ static int dissect_udvm_literal_operand(tvbuff_t *udvm_tvb, proto_tree *sigcomp_
 static int dissect_udvm_reference_operand(tvbuff_t *udvm_tvb, proto_tree *sigcomp_udvm_tree, 
 							   gint offset, gint *start_offset, guint16 *value);
 static void tvb_raw_text_add(tvbuff_t *tvb, proto_tree *tree);
-
+/* Initialize the state handler
+ *
+ */
+void
+sigcomp_init_protocol(void)
+{
+	sigcomp_init_udvm();
+} 
 
 /* Code to actually dissect the packets */
 static int
@@ -268,21 +285,30 @@ dissect_sigcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 
 /* Set up structures needed to add the protocol subtree and manage it */
-	tvbuff_t *udvm_tvb, *msg_tvb;
-	tvbuff_t *decomp_tvb = NULL;
+	tvbuff_t	 *udvm_tvb, *msg_tvb, *udvm2_tvb;
+	tvbuff_t	*decomp_tvb = NULL;
 	proto_item *ti, *udvm_bytecode_item, *udvm_exe_item;
 	proto_tree *sigcomp_tree, *sigcomp_udvm_tree, *sigcomp_udvm_exe_tree;
-	gint offset = 0;
-	gint bytecode_offset;
-	gint partial_state_len;
-	guint octet;
-	guint8 returned_feedback_field[128];
-	guint8 partial_state[12];
-	guint tbit;
-	guint16 len = 0;
-	guint16 bytecode_len = 0;
-	guint destination;
-	gint msg_len = 0;
+	gint		offset = 0;
+	gint		bytecode_offset;
+	guint16		partial_state_len;
+	guint		octet;
+	guint8		returned_feedback_field[128];
+	guint8		partial_state[12];
+	guint		tbit;
+	guint16		len = 0;
+	guint16		bytecode_len = 0;
+	guint		destination;
+	gint		msg_len = 0;
+	guint8		*buff;
+	guint16		p_id_start;
+	guint8		i;
+	guint16		state_begin;
+	guint16		state_length;
+	guint16		state_address;
+	guint16		state_instruction;
+	guint16		result_code;
+	gchar		*partial_state_str;
 
 /* Is this a SigComp message or not ? */
 	octet = tvb_get_guint8(tvb, offset);
@@ -296,9 +322,6 @@ dissect_sigcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	if (check_col(pinfo->cinfo, COL_INFO)) 
 		col_clear(pinfo->cinfo, COL_INFO);
 
-
-
-
 /* create display subtree for the protocol */
 	ti = proto_tree_add_item(tree, proto_sigcomp, tvb, 0, -1, FALSE);
 	sigcomp_tree = proto_item_add_subtree(ti, ett_sigcomp);
@@ -390,13 +413,87 @@ dissect_sigcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			offset = offset + len;
 		}
 		tvb_memcpy(tvb, partial_state, offset, partial_state_len);
-		proto_tree_add_bytes(sigcomp_tree,hf_sigcomp_partial_state,
-			tvb, offset, partial_state_len, partial_state);
+		partial_state_str = bytes_to_str(partial_state, partial_state_len);
+		proto_tree_add_string(sigcomp_tree,hf_sigcomp_partial_state,
+			tvb, offset, partial_state_len, partial_state_str);
 		offset = offset + partial_state_len;
-		proto_tree_add_text(sigcomp_tree, tvb, offset, -1, "Remaining SigComp message %u bytes",
-			tvb_reported_length_remaining(tvb, offset));
+		if(msg_len>0)
+			proto_tree_add_text(sigcomp_tree, tvb, offset, -1, "Remaining SigComp message %u bytes",
+				tvb_reported_length_remaining(tvb, offset));
+
+		if ( decompress ) {
+			msg_len = tvb_reported_length_remaining(tvb, offset);
+			msg_tvb = tvb_new_subset(tvb, offset, msg_len, msg_len);
+			/*
+			 * buff					= Where "state" will be stored
+			 * p_id_start			= Partial state identifier start pos in the buffer(buff)
+			 * partial_state_len	= Partial state identifier length
+			 * state_begin			= Where to start to read state from
+			 * state_length			= Lenght of state
+			 * state_address			= Address where to store the state in the buffer(buff)
+			 * state_instruction	=
+			 * TRUE					= Indicates that state_* is in the stored state 
+			 */
+			buff = g_malloc(UDVM_MEMORY_SIZE);
+			p_id_start = 0;
+			state_begin = 0;
+			/* These values will be loaded from the buffered state in sigcomp_state_hdlr 
+			 */
+			state_length = 0;
+			state_address = 0;
+			state_instruction =0;
+
+			i = 0;
+			while ( i < partial_state_len ){
+				buff[i] = partial_state[i];
+				i++;
+			}
+
+			result_code = udvm_state_access(tvb, sigcomp_tree, buff, p_id_start, partial_state_len, state_begin, &state_length, 
+				&state_address, state_instruction, FALSE, hf_sigcomp_partial_state);
+
+
+			if ( result_code != 0 ){
+				proto_tree_add_text(sigcomp_tree, tvb, 0, -1,"Failed to Access state Ethereal UDVM diagnostic: %s.",
+					    val_to_str(result_code, result_code_vals,"Unknown (%u)"));
+				g_free(buff);
+				return tvb_length(tvb);
+			}
+
+			udvm_tvb = tvb_new_real_data(buff,state_length+128,state_length+128);
+			/* Arrange that the allocated packet data copy be freed when the
+			 * tvbuff is freed. 
+			 */
+			tvb_set_free_cb( udvm_tvb, g_free );
+			/* Add the tvbuff to the list of tvbuffs to which the tvbuff we
+			 * were handed refers, so it'll get cleaned up when that tvbuff
+			 * is cleaned up. 
+			 */
+			tvb_set_child_real_data_tvbuff( tvb, udvm_tvb );
+
+
+			udvm2_tvb = tvb_new_subset(udvm_tvb, 128, state_length, state_length);
+			/* TODO Check if buff needs to be free'd */
+			udvm_exe_item = proto_tree_add_text(sigcomp_tree, udvm2_tvb, 0, state_length, 
+				"UDVM execution trace");
+			sigcomp_udvm_exe_tree = proto_item_add_subtree( udvm_exe_item, ett_sigcomp_udvm_exe);
+
+			decomp_tvb = decompress_sigcomp_message(udvm2_tvb, msg_tvb, pinfo,
+						   sigcomp_udvm_exe_tree, state_address, udvm_print_detail_level, hf_sigcomp_partial_state);
 		
 
+			if ( decomp_tvb ){
+				proto_tree_add_text(sigcomp_tree, decomp_tvb, 0, -1,"SigComp message Decompressed WOHO!!");
+				if ( display_raw_txt )
+					tvb_raw_text_add(decomp_tvb, tree);
+				if (check_col(pinfo->cinfo, COL_PROTOCOL)){
+					col_append_str(pinfo->cinfo, COL_PROTOCOL, "/");
+					col_set_fence(pinfo->cinfo,COL_PROTOCOL);
+				}
+				call_dissector(sip_handle, decomp_tvb, pinfo, tree);
+			}
+		}/* if decompress */
+
 	}
 	else{
 		/*
@@ -442,27 +539,29 @@ dissect_sigcomp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		offset = offset + len;
 		msg_len = tvb_reported_length_remaining(tvb, offset);
+		if(msg_len>0)
+			proto_tree_add_text(sigcomp_tree, tvb, offset, -1, "Remaining SigComp message %u bytes",
+				tvb_reported_length_remaining(tvb, offset));
+		if ( decompress ){
 
-		proto_tree_add_text(sigcomp_tree, tvb, offset, -1, "Remaining SigComp message %u bytes",
-			tvb_reported_length_remaining(tvb, offset));
-
-		msg_tvb = tvb_new_subset(tvb, offset, msg_len, msg_len);
-
-		udvm_exe_item = proto_tree_add_text(sigcomp_tree, tvb, bytecode_offset, bytecode_len, 
-			"UDVM execution trace");
-		sigcomp_udvm_exe_tree = proto_item_add_subtree( udvm_exe_item, ett_sigcomp_udvm_exe);
-		decomp_tvb = decompress_sigcomp_message(udvm_tvb, msg_tvb, pinfo,
-						   sigcomp_udvm_exe_tree, destination, udvm_print_detail_level);
-		if ( decomp_tvb ){
-			proto_tree_add_text(sigcomp_tree, decomp_tvb, 0, -1,"SigComp message Decompressed WOHO!!");
-			if ( display_raw_txt )
-				tvb_raw_text_add(decomp_tvb, tree);
-			if (check_col(pinfo->cinfo, COL_PROTOCOL)){
-				col_append_str(pinfo->cinfo, COL_PROTOCOL, "/");
-				col_set_fence(pinfo->cinfo,COL_PROTOCOL);
+			msg_tvb = tvb_new_subset(tvb, offset, msg_len, msg_len);
+	
+			udvm_exe_item = proto_tree_add_text(sigcomp_tree, tvb, bytecode_offset, bytecode_len, 
+				"UDVM execution trace");
+			sigcomp_udvm_exe_tree = proto_item_add_subtree( udvm_exe_item, ett_sigcomp_udvm_exe);
+			decomp_tvb = decompress_sigcomp_message(udvm_tvb, msg_tvb, pinfo,
+						   sigcomp_udvm_exe_tree, destination, udvm_print_detail_level, hf_sigcomp_partial_state);
+			if ( decomp_tvb ){
+				proto_tree_add_text(sigcomp_tree, decomp_tvb, 0, -1,"SigComp message Decompressed WOHO!!");
+				if ( display_raw_txt )
+					tvb_raw_text_add(decomp_tvb, tree);
+				if (check_col(pinfo->cinfo, COL_PROTOCOL)){
+					col_append_str(pinfo->cinfo, COL_PROTOCOL, "/");
+					col_set_fence(pinfo->cinfo,COL_PROTOCOL);
+				}
+				call_dissector(sip_handle, decomp_tvb, pinfo, tree);
 			}
-			call_dissector(sip_handle, decomp_tvb, pinfo, tree);
-		}
+		} /* if decompress */
 
 	}
 	return tvb_length(tvb);
@@ -519,10 +618,11 @@ dissect_udvm_bytecode(tvbuff_t *udvm_tvb, proto_tree *sigcomp_udvm_tree,guint st
 	guint16 value = 0;
 	proto_item *item, *item2;
 	guint UDVM_address = start_address;
-	gboolean is_memory_address; 
+	gboolean is_memory_address;
+	guint16 msg_length = tvb_reported_length_remaining(udvm_tvb, offset);
 
 
-	while (tvb_reported_length_remaining(udvm_tvb, offset) > 0) { 
+	while (msg_length > offset) { 
 		instruction = tvb_get_guint8(udvm_tvb, offset);
 		instruction_no ++;
 		UDVM_address = start_address + offset;
@@ -1343,11 +1443,23 @@ dissect_udvm_bytecode(tvbuff_t *udvm_tvb, proto_tree *sigcomp_udvm_tree,guint st
 			 * %state_retention_priority)
 			 */
 			/* %requested_feedback_location */
+			if ((msg_length-1) < offset){
+				item2 = proto_tree_add_text(sigcomp_udvm_tree, udvm_tvb, 0, -1,
+						"All remaining parameters = 0(Not in the uploaded code as UDVM buffer initalized to Zero");
+				PROTO_ITEM_SET_GENERATED(item2);
+				return;
+			}
 			offset = dissect_udvm_multitype_operand(udvm_tvb, sigcomp_udvm_tree, offset, TRUE, &start_offset, &value, &is_memory_address);
 			len = offset - start_offset;
 			proto_tree_add_uint(sigcomp_udvm_tree, hf_udvm_req_feedback_loc, 
 				udvm_tvb, start_offset, len, value);
 			/* returned_parameters_location */
+			if ((msg_length-1) < offset){
+				item2 = proto_tree_add_text(sigcomp_udvm_tree, udvm_tvb, offset-1, -1,
+						"All remaining parameters = 0(Not in the uploaded code as UDVM buffer initalized to Zero");
+				PROTO_ITEM_SET_GENERATED(item2);
+				return;
+			}
 			offset = dissect_udvm_multitype_operand(udvm_tvb, sigcomp_udvm_tree, offset, TRUE, &start_offset, &value, &is_memory_address);
 			len = offset - start_offset;
 			proto_tree_add_uint(sigcomp_udvm_tree, hf_udvm_ret_param_loc, 
@@ -1575,7 +1687,7 @@ dissect_udvm_reference_operand(tvbuff_t *udvm_tvb, proto_tree *sigcomp_udvm_tree
  */
 static int
 dissect_udvm_multitype_operand(tvbuff_t *udvm_tvb, proto_tree *sigcomp_udvm_tree, 
-							   gint offset, gboolean is_addr, gint *start_offset, guint16 *value, gboolean *is_memory_address )
+							   gint offset, gboolean is_addr _U_, gint *start_offset, guint16 *value, gboolean *is_memory_address )
 {
 	guint bytecode;
 	guint display_bytecode;
@@ -1833,7 +1945,7 @@ proto_register_sigcomp(void)
 		},
 		{ &hf_sigcomp_partial_state,
 			{ "Partial state identifier", "sigcomp.partial.state.identifier",
-			FT_BYTES, BASE_HEX, NULL, 0x0,          
+			FT_STRING, BASE_NONE, NULL, 0x0,          
 			"Partial state identifier", HFILL }
 		},
 		{ &hf_sigcomp_returned_feedback_item_len,
@@ -2131,6 +2243,10 @@ proto_register_sigcomp(void)
 								   "Display the bytecode of operands",
 								   "preference wether to display the bytecode in UDVM operands or not",
 								   &display_udvm_bytecode);
+	prefs_register_bool_preference(sigcomp_module, "decomp.msg",
+								   "Decompress message",
+								   "preference wether to decompress message or not",
+								   &decompress);
 	prefs_register_bool_preference(sigcomp_module, "display.decomp.msg.as.txt",
 								   "Displays the decompressed message as text",
 								   "preference wether to display the decompressed message as raw text or not",
@@ -2140,5 +2256,8 @@ proto_register_sigcomp(void)
       "0 = UDVM executes silently, then incrising detail about execution of UDVM instructions, Warning! CPU intense at high detail",
       &udvm_print_detail_level, udvm_detail_vals, FALSE);
 
+	register_init_routine(&sigcomp_init_protocol);
+
+
 
 }
