@@ -2,7 +2,7 @@
  * Routines for Token-Ring packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-tr.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: packet-tr.c 12914 2005-01-01 23:11:46Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -340,7 +340,7 @@ dissect_tr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	static tr_hdr trh_arr[4];
 	static int trh_current=0;
-	tr_hdr *trh;
+	tr_hdr *volatile trh;
 
 	/* non-source-routed version of source addr */
 	static guint8		trn_shost_nonsr[6];
