@@ -1,7 +1,7 @@
 /* packet-windows-common.c
  * Routines for dissecting various Windows data types
  *
- * $Id: packet-windows-common.c 11774 2004-08-19 09:00:20Z guy $
+ * $Id: packet-windows-common.c 12864 2004-12-30 02:21:33Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -133,7 +133,7 @@ const value_string DOS_errors[] = {
  *
  * From
  *
- *	http://www.wildpackets.com/elements/SMB_NT_Status_Codes.txt
+ *	http://www.wildpackets.com/elements/misc/SMB_NT_Status_Codes.txt
  */
 const value_string NT_errors[] = {
   { 0x00000000, "STATUS_SUCCESS" },
@@ -1773,12 +1773,21 @@ dissect_nt_v2_ace(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	type = tvb_get_guint8(tvb, offset);
 	proto_tree_add_uint(tree, hf_nt_ace_type, tvb, offset, 1, type);
 	offset += 1;
-
+          
 	/* flags */
 	offset = dissect_nt_v2_ace_flags(tvb, offset, tree, &flags);
 
 	/* size */
 	size = tvb_get_letohs(tvb, offset);
+	if (size < 4) {
+		/*
+		 * BOGUS - the size includes the ACE header length,
+		 * which is 4.
+		 */
+		proto_tree_add_uint_format(tree, hf_nt_ace_size, tvb, offset, 2,
+		    size, "Size: %u (bogus, must be >= 4)", size);
+		return old_offset;	/* our caller quits in this case */
+	}
 	proto_tree_add_uint(tree, hf_nt_ace_size, tvb, offset, 2, size);
 	offset += 2;
 
@@ -1814,7 +1823,8 @@ dissect_nt_acl(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_item *item = NULL;
 	proto_tree *tree = NULL;
 	int old_offset = offset;
-	guint8  revision;
+	int pre_ace_offset;
+	guint16 revision;
 	guint32 num_aces;
 
 	if(parent_tree){
@@ -1824,9 +1834,22 @@ dissect_nt_acl(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	}
 
 	/* revision */
-	revision = tvb_get_guint8(tvb, offset);
+	/*
+	 * XXX - is this *really* 2 bytes?  The page at
+	 *
+	 *	http://msdn.microsoft.com/library/default.asp?url=/library/en-us/secauthz/security/acl.asp
+	 *
+	 * indicates that it's one byte of revision and one byte of
+	 * zero padding, which means the code that used to be here
+	 * was correct - and this code would give the same results
+	 * as long as the padding is zero, so if this dissects it
+	 * correctly when the padding is zero, and the padding is
+	 * always zero, the old code would dissect it correctly
+	 * also.
+	 */
+	revision = tvb_get_letohs(tvb, offset);
 	proto_tree_add_uint(tree, hf_nt_acl_revision,
-		tvb, offset, 1, revision);
+		tvb, offset, 2, revision);
 	offset += 2;
 
 	switch(revision){
@@ -1837,14 +1860,25 @@ dissect_nt_acl(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	  offset += 2;
 
 	  /* number of ace structures */
+	  /*
+	   * XXX - is this *really* 4 bytes?  The page referred to above
+	   * says it's 2 bytes of count followed by two bytes of
+	   * zero padding.
+	   */
 	  num_aces = tvb_get_letohl(tvb, offset);
 	  proto_tree_add_uint(tree, hf_nt_acl_num_aces,
 			      tvb, offset, 4, num_aces);
 	  offset += 4;
 
 	  while(num_aces--){
-	    offset=dissect_nt_v2_ace(
-		    tvb, offset, pinfo, tree, drep, ami);
+		pre_ace_offset = offset;
+		offset = dissect_nt_v2_ace(tvb, offset, pinfo, tree, drep, ami);
+		if (pre_ace_offset == offset) {
+			/*
+			 * Bogus ACE, with a length < 4.
+			 */
+			break;
+		}
 	  }
 	}
 
@@ -1959,7 +1993,7 @@ dissect_nt_sec_desc(tvbuff_t *tvb, int offset, packet_info *pinfo,
 {
 	proto_item *item = NULL;
 	proto_tree *tree = NULL;
-	guint8 revision;
+	guint16 revision;
 	int old_offset = offset;
 	guint32 owner_sid_offset;
 	guint32 group_sid_offset;
@@ -1973,13 +2007,10 @@ dissect_nt_sec_desc(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	}
 
 	/* revision */
-	revision = tvb_get_guint8(tvb, offset);
+	revision = tvb_get_letohs(tvb, offset);
 	proto_tree_add_uint(tree, hf_nt_sec_desc_revision,
-		tvb, offset, 1, revision);
-	offset += 1;
-
-	/* next byte should be zero, for now just ignore it */
-	offset += 1;
+		tvb, offset, 2, revision);
+	offset += 2;
 
 
 	switch(revision){
@@ -2054,7 +2085,7 @@ proto_do_register_windows_common(int proto_smb)
 		/* Security descriptors */
 
 		{ &hf_nt_sec_desc_revision,
-		  { "Revision", "nt.sec_desc.revision", FT_UINT8, BASE_DEC,
+		  { "Revision", "nt.sec_desc.revision", FT_UINT16, BASE_DEC,
 		    NULL, 0, "Version of NT Security Descriptor structure", HFILL }},
 
 		{ &hf_nt_sec_desc_type_owner_defaulted,
@@ -2124,7 +2155,7 @@ proto_do_register_windows_common(int proto_smb)
 		    NULL, 0, "Number of authorities for this SID", HFILL }},
 
 		{ &hf_nt_acl_revision,
-		  { "Revision", "nt.acl.revision", FT_UINT8, BASE_DEC,
+		  { "Revision", "nt.acl.revision", FT_UINT16, BASE_DEC,
 		    NULL, 0, "Version of NT ACL structure", HFILL }},
 
 		/* ACLs */
