@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-string.c,v 1.20 2004/02/27 12:00:32 obiot Exp $
+ * $Id: ftype-string.c 11796 2004-08-22 00:31:58Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -34,6 +34,8 @@
 #define CMP_MATCHES NULL
 #endif
 
+#include <ctype.h>
+
 static void
 string_fvalue_new(fvalue_t *fv)
 {
@@ -76,12 +78,21 @@ string_repr_len(fvalue_t *fv, ftrepr_t rtype)
 		case FTREPR_DFILTER:
 			repr_len = 0;
 			for (p = fv->value.string; (c = *p) != '\0'; p++) {
+				/* Backslashes and double-quotes must
+				 * be escaped */
 				if (c == '\\' || c == '"') {
-					/* Backslashes and double-quotes
-					   must be escaped. */
+					repr_len += 2;
+				}
+				/* Values that can't nicely be represented
+				 * in ASCII need to be escaped. */
+				else if (!isprint((unsigned char)c)) {
+					/* c --> \xNN */
+					repr_len += 4;
+				}
+				/* Other characters are just passed through. */
+				else {
 					repr_len++;
 				}
-				repr_len++;
 			}
 			return repr_len + 2;	/* string plus leading and trailing quotes */
 	}
@@ -94,17 +105,32 @@ string_to_repr(fvalue_t *fv, ftrepr_t rtype, char *buf)
 {
 	gchar *p, c;
 	char *bufp;
+	char hex[2];
 
 	if (rtype == FTREPR_DFILTER) {
 		bufp = buf;
 		*bufp++ = '"';
 		for (p = fv->value.string; (c = *p) != '\0'; p++) {
+			/* Backslashes and double-quotes must
+			 * be escaped. */
 			if (c == '\\' || c == '"') {
-				/* Backslashes and double-quotes
-				   must be escaped. */
 				*bufp++ = '\\';
+				*bufp++ = c;
+			}
+			/* Values that can't nicely be represented
+			 * in ASCII need to be escaped. */
+			else if (!isprint((unsigned char)c)) {
+				/* c --> \xNN */
+				sprintf(hex, "%02x", (unsigned char) c);
+				*bufp++ = '\\';
+				*bufp++ = 'x';
+				*bufp++ = hex[0];
+				*bufp++ = hex[1];
+			}
+			/* Other characters are just passed through. */
+			else {
+				*bufp++ = c;
 			}
-			*bufp++ = c;
 		}
 		*bufp++ = '"';
 		*bufp = '\0';
@@ -148,7 +174,7 @@ val_from_unparsed(fvalue_t *fv, char *s, gboolean allow_partial_value _U_, LogFu
 		int num_bytes = fv_bytes->value.bytes->len;
 
 		fv->value.string = g_malloc(num_bytes + 1);
-		memcpy(fv->value.string, fv->value.bytes->data, num_bytes);
+		memcpy(fv->value.string, fv_bytes->value.bytes->data, num_bytes);
 		fv->value.string[num_bytes] = '\0';
 
 		FVALUE_FREE(fv_bytes);
@@ -286,10 +312,12 @@ ftype_register_string(void)
 
 		string_fvalue_set,		/* set_value */
 		NULL,				/* set_value_integer */
+		NULL,				/* set_value_integer64 */
 		NULL,				/* set_value_floating */
 
 		value_get,			/* get_value */
 		NULL,				/* get_value_integer */
+		NULL,				/* get_value_integer64 */
 		NULL,				/* get_value_floating */
 
 		cmp_eq,
@@ -306,23 +334,25 @@ ftype_register_string(void)
 		slice,
 	};
 	static ftype_t stringz_type = {
-		"FT_STRINGZ",
-		"character string",
-		0,
-		string_fvalue_new,
-		string_fvalue_free,
+		"FT_STRINGZ",			/* name */
+		"character string",		/* pretty name */
+		0,				/* wire_size */
+		string_fvalue_new,		/* new_value */
+		string_fvalue_free,		/* free_value */
 		val_from_unparsed,		/* val_from_unparsed */
 		val_from_string,		/* val_from_string */
 		NULL,				/* val_to_string_repr */
 		NULL,				/* len_string_repr */
 
-		string_fvalue_set,
-		NULL,
-		NULL,
+		string_fvalue_set,		/* set_value */
+		NULL,				/* set_value_integer */
+		NULL,				/* set_value_integer64 */
+		NULL,				/* set_value_floating */
 
-		value_get,
-		NULL,
-		NULL,
+		value_get,			/* get_value */
+		NULL,				/* get_value_integer */
+		NULL,				/* get_value_integer64 */
+		NULL,				/* get_value_floating */
 
 		cmp_eq,
 		cmp_ne,
@@ -338,23 +368,25 @@ ftype_register_string(void)
 		slice,
 	};
 	static ftype_t uint_string_type = {
-		"FT_UINT_STRING",
-		"character string",
-		0,
-		string_fvalue_new,
-		string_fvalue_free,
+		"FT_UINT_STRING",		/* name */
+		"character string",		/* pretty_name */
+		0,				/* wire_size */
+		string_fvalue_new,		/* new_value */
+		string_fvalue_free,		/* free_value */
 		val_from_unparsed,		/* val_from_unparsed */
 		val_from_string,		/* val_from_string */
 		NULL,				/* val_to_string_repr */
 		NULL,				/* len_string_repr */
 
-		string_fvalue_set,
-		NULL,
-		NULL,
+		string_fvalue_set,		/* set_value */
+		NULL,				/* set_value_integer */
+		NULL,				/* set_value_integer64 */
+		NULL,				/* set_value_floating */
 
-		value_get,
-		NULL,
-		NULL,
+		value_get,			/* get_value */
+		NULL,				/* get_value_integer */
+		NULL,				/* get_value_integer64 */
+		NULL,				/* get_value_floating */
 
 		cmp_eq,
 		cmp_ne,
