@@ -1,7 +1,7 @@
 /* packet.c
  * Routines for packet disassembly
  *
- * $Id: packet.c 11894 2004-09-04 11:35:26Z ulfl $
+ * $Id: packet.c 12914 2005-01-01 23:11:46Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -389,8 +389,9 @@ call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
  */
 static int
 call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo, proto_tree *tree)
+    packet_info *pinfo_arg, proto_tree *tree)
 {
+	packet_info *volatile pinfo = pinfo_arg;
 	const char *saved_proto;
 	guint16 saved_can_desegment;
 	volatile int ret;
@@ -496,7 +497,17 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 			RETHROW;
 		}
 		CATCH(ReportedBoundsError) {
-			; /* do nothing */
+			/*
+			 * "ret" wasn't set because an exception was thrown
+			 * before "call_dissector_through_handle()" returned.
+			 * As it called something, at least one dissector
+			 * accepted the packet, and, as an exception was
+			 * thrown, not only was all the tvbuff dissected,
+			 * a dissector tried dissecting past the end of
+			 * the data in some tvbuff, so we'll assume that
+			 * the entire tvbuff was dissected.
+			 */
+			ret = tvb_length(tvb);
 		}
 		ENDTRY;
 
