@@ -1,7 +1,7 @@
 /* to_str.c
  * Routines for utilities to convert various other types to strings.
  *
- * $Id: to_str.c,v 1.45 2004/06/16 23:09:43 guy Exp $
+ * $Id: to_str.c 12911 2005-01-01 12:29:26Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -59,12 +59,12 @@
 
 #include "to_str.h"
 #include "value_string.h"
-#include "resolv.h"
+#include "addr_resolv.h"
 #include "pint.h"
 #include "atalk-utils.h"
 #include "sna-utils.h"
 #include "osi-utils.h"
-#include "packet-mtp3.h"
+#include <epan/dissectors/packet-mtp3.h>
 #include <stdio.h>
 #include <time.h>
 
@@ -804,7 +804,7 @@ decode_numeric_bitfield(guint32 val, guint32 mask, int width,
    address types */
 /* convert an address struct into a printable string */
 gchar*	
-address_to_str(address *addr)
+address_to_str(const address *addr)
 {
 #ifndef INET6_ADDRSTRLEN
 #define INET6_ADDRSTRLEN 46
@@ -823,7 +823,7 @@ address_to_str(address *addr)
 }
 
 void
-address_to_str_buf(address *addr, gchar *buf)
+address_to_str_buf(const address *addr, gchar *buf)
 {
   struct atalk_ddp_addr ddp_addr;
 
