@@ -9,7 +9,7 @@
  * 		the data of a backing tvbuff, or can be a composite of
  * 		other tvbuffs.
  *
- * $Id: tvbuff.c,v 1.61 2004/03/23 18:06:29 guy Exp $
+ * $Id: tvbuff.c 12957 2005-01-05 10:19:36Z guy $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -41,6 +41,10 @@
 
 #include <string.h>
 
+#ifdef HAVE_LIBZ
+#include <zlib.h>
+#endif
+
 #include "pint.h"
 #include "tvbuff.h"
 #include "strutil.h"
@@ -1048,6 +1052,15 @@ tvb_get_ntohl(tvbuff_t *tvb, gint offset)
 	return pntohl(ptr);
 }
 
+guint64
+tvb_get_ntoh64(tvbuff_t *tvb, gint offset)
+{
+	const guint8* ptr;
+
+	ptr = ensure_contiguous(tvb, offset, sizeof(guint64));
+	return pntoh64(ptr);
+}
+
 /*
  * Stuff for IEEE float handling on platforms that don't have IEEE
  * format as the native floating-point format.
@@ -1278,6 +1291,15 @@ tvb_get_letohl(tvbuff_t *tvb, gint offset)
 	return pletohl(ptr);
 }
 
+guint64
+tvb_get_letoh64(tvbuff_t *tvb, gint offset)
+{
+	const guint8* ptr;
+
+	ptr = ensure_contiguous(tvb, offset, sizeof(guint64));
+	return pletoh64(ptr);
+}
+
 /*
  * Fetches an IEEE single-precision floating-point number, in
  * little-endian form, and returns a "float".
@@ -1602,9 +1624,9 @@ tvb_memeql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
 }
 
 /* Convert a string from Unicode to ASCII.  At the moment we fake it by
- * assuming all characters are ASCII  )-:  The caller must free the
- * result returned.  The len parameter is the number of guint16's to
- * convert from Unicode. */
+ * replacing all non-ASCII characters with a '.' )-:  The caller must
+ * free the result returned.  The len parameter is the number of guint16's
+ * to convert from Unicode. */
 char *
 tvb_fake_unicode(tvbuff_t *tvb, int offset, int len, gboolean little_endian)
 {
@@ -1623,7 +1645,7 @@ tvb_fake_unicode(tvbuff_t *tvb, int offset, int len, gboolean little_endian)
 	for (i = 0; i < len; i++) {
 		character = little_endian ? tvb_get_letohs(tvb, offset)
 					  : tvb_get_ntohs(tvb, offset);
-		buffer[i] = character & 0xff;
+		buffer[i] = character < 256 ? character : '.';
 		offset += 2;
 	}
 
@@ -2106,6 +2128,17 @@ tvb_find_line_end_unquoted(tvbuff_t *tvb, gint offset, int len,
 	return linelen;
 }
 
+/*
+ * Format a bunch of data from a tvbuff as bytes, returning a pointer
+ * to the string with the formatted data, with "punct" as a byte
+ * separator.
+ */
+gchar *
+tvb_bytes_to_str_punct(tvbuff_t *tvb, gint offset, gint len, gchar punct)
+{
+	return bytes_to_str_punct(tvb_get_ptr(tvb, offset, len), len, punct);
+}
+
 /*
  * Format a bunch of data from a tvbuff as bytes, returning a pointer
  * to the string with the formatted data.
@@ -2149,3 +2182,297 @@ tvb_find_tvb(tvbuff_t *haystack_tvb, tvbuff_t *needle_tvb, gint haystack_offset)
 
 	return -1;
 }
+
+#ifdef HAVE_LIBZ
+/*
+ * Uncompresses a zlib compressed packet inside a message of tvb at offset with
+ * length comprlen.  Returns an uncompressed tvbuffer if uncompression
+ * succeeded or NULL if uncompression failed.
+ */
+#define TVB_Z_MIN_BUFSIZ 32768
+#define TVB_Z_MAX_BUFSIZ 1048576 * 10
+/* #define TVB_Z_DEBUG 1 */
+#undef TVB_Z_DEBUG
+
+tvbuff_t *
+tvb_uncompress(tvbuff_t *tvb, int offset, int comprlen)
+{
+	
+
+	gint err = Z_OK;
+	guint bytes_out = 0;
+	guint8 *compr = NULL;
+	guint8 *uncompr = NULL;
+	tvbuff_t *uncompr_tvb = NULL;
+	z_streamp strm = NULL;
+	Bytef *strmbuf = NULL;
+	guint inits_done = 0;
+	gint wbits = MAX_WBITS;
+	guint8 *next = NULL;
+	guint bufsiz = TVB_Z_MIN_BUFSIZ;
+#ifdef TVB_Z_DEBUG
+	guint inflate_passes = 0;
+	guint bytes_in = tvb_length_remaining(tvb, offset);
+#endif
+
+	if (tvb == NULL) {
+		return NULL;
+	}
+
+	strm = g_malloc0(sizeof(z_stream));
+
+	if (strm == NULL) {
+		return NULL;
+	}
+
+	compr = tvb_memdup(tvb, offset, comprlen);
+
+	if (!compr) {
+		g_free(strm);
+		return NULL;
+	}
+
+	/* 
+	 * Assume that the uncompressed data is at least twice as big as
+	 * the compressed size.
+	 */
+	bufsiz = tvb_length_remaining(tvb, offset) * 2;
+
+	if (bufsiz < TVB_Z_MIN_BUFSIZ) {
+		bufsiz = TVB_Z_MIN_BUFSIZ;
+	} else if (bufsiz > TVB_Z_MAX_BUFSIZ) {
+		bufsiz = TVB_Z_MIN_BUFSIZ;
+	}
+
+#ifdef TVB_Z_DEBUG
+	printf("bufsiz: %u bytes\n", bufsiz);
+#endif
+
+	next = compr;
+
+	strm->next_in = next;
+	strm->avail_in = comprlen;
+
+
+	strmbuf = g_malloc0(bufsiz);
+
+	if(strmbuf == NULL) {
+		g_free(compr);
+		g_free(strm);
+		return NULL;
+	}
+
+	strm->next_out = strmbuf;
+	strm->avail_out = bufsiz;
+
+	err = inflateInit2(strm, wbits);
+	inits_done = 1;
+	if (err != Z_OK) {
+		g_free(strm);
+		g_free(compr);
+		g_free(strmbuf);
+		return NULL;
+	}
+
+	while (1) {
+		memset(strmbuf, '\0', bufsiz);
+		strm->next_out = strmbuf;
+		strm->avail_out = bufsiz;
+
+		err = inflate(strm, Z_SYNC_FLUSH);
+
+		if (err == Z_OK || err == Z_STREAM_END) {
+			guint bytes_pass = bufsiz - strm->avail_out;
+
+#ifdef TVB_Z_DEBUG
+			++inflate_passes;
+#endif
+
+			if (uncompr == NULL) {
+				uncompr = g_memdup(strmbuf, bytes_pass);
+			} else {
+				guint8 *new_data = g_malloc0(bytes_out +
+				    bytes_pass);
+
+				if (new_data == NULL) {
+					g_free(strm);
+					g_free(strmbuf);
+					g_free(compr);
+
+					if (uncompr != NULL) {
+						g_free(uncompr);
+					}
+					
+					return NULL;
+				}
+				
+				g_memmove(new_data, uncompr, bytes_out);
+				g_memmove((new_data + bytes_out), strmbuf,
+				    bytes_pass);
+
+				g_free(uncompr);
+				uncompr = new_data;
+			}
+
+			bytes_out += bytes_pass;
+
+			if ( err == Z_STREAM_END) {
+				inflateEnd(strm);
+				g_free(strm);
+				g_free(strmbuf);
+				break;
+			}
+		} else if (err == Z_BUF_ERROR) {
+			/*
+			 * It's possible that not enough frames were captured
+			 * to decompress this fully, so return what we've done
+			 * so far, if any.
+			 */
+
+			g_free(strm);
+			g_free(strmbuf);
+
+			if (uncompr != NULL) {
+				break;
+			} else {
+				g_free(compr);
+				return NULL;
+			}
+			
+		} else if (err == Z_DATA_ERROR && inits_done == 1
+		    && uncompr == NULL && (*compr  == 0x1f) &&
+		    (*(compr + 1) == 0x8b)) {
+			/*
+			 * inflate() is supposed to handle both gzip and deflate
+			 * streams automatically, but in reality it doesn't
+			 * seem to handle either (at least not within the
+			 * context of an HTTP response.)  We have to try
+			 * several tweaks, depending on the type of data and
+			 * version of the library installed.
+			 */
+
+			/*
+			 * Gzip file format.  Skip past the header, since the
+			 * fix to make it work (setting windowBits to 31)
+			 * doesn't work with all versions of the library.
+			 */
+			Bytef *c = compr + 2;
+			Bytef flags = 0;
+
+			if (*c == Z_DEFLATED) {
+				c++;
+			} else {
+				g_free(strm);
+				g_free(compr);
+				g_free(strmbuf);
+				return NULL;
+			}
+
+			flags = *c;
+
+			/* Skip past the MTIME, XFL, and OS fields. */
+			c += 7;
+
+			if (flags & (1 << 2)) {
+				/* An Extra field is present. */
+				gint xsize = (gint)(*c |
+				    (*(c + 1) << 8));
+
+				c += xsize;
+			}
+
+			if (flags & (1 << 3)) {
+				/* A null terminated filename */
+
+				while (*c != '\0') {
+					c++;
+				}
+
+				c++;
+			}
+
+			if (flags & (1 << 4)) {
+				/* A null terminated comment */
+				
+				while (*c != '\0') {
+					c++;
+				}
+
+				c++;
+			}
+
+
+			inflateReset(strm);
+			next = c;
+			strm->next_in = next;
+			comprlen -= (c - compr);
+			
+			err = inflateInit2(strm, wbits);
+			inits_done++;
+		} else if (err == Z_DATA_ERROR && uncompr == NULL &&
+		    inits_done <= 3) {
+			
+			/* 
+			 * Re-init the stream with a negative
+			 * MAX_WBITS. This is necessary due to
+			 * some servers (Apache) not sending
+			 * the deflate header with the
+			 * content-encoded response.
+			 */
+			wbits = -MAX_WBITS;
+
+			inflateReset(strm);
+
+			strm->next_in = next;
+			strm->avail_in = comprlen;
+
+			memset(strmbuf, '\0', bufsiz);
+			strm->next_out = strmbuf;
+			strm->avail_out = bufsiz;
+
+			err = inflateInit2(strm, wbits);
+				
+			inits_done++;
+			
+			if (err != Z_OK) {
+				g_free(strm);
+				g_free(strmbuf);
+				g_free(compr);
+				g_free(uncompr);
+
+				return NULL;
+			}
+		} else {
+			g_free(strm);
+			g_free(strmbuf);
+			g_free(compr);
+
+			if (uncompr == NULL) {
+				return NULL;
+			}
+
+			break;
+		}
+	}
+
+#ifdef TVB_Z_DEBUG
+	printf("inflate() total passes: %u\n", inflate_passes);
+	printf("bytes  in: %u\nbytes out: %u\n\n", bytes_in, bytes_out);
+#endif
+	
+	if (uncompr != NULL) {
+		uncompr_tvb =  tvb_new_real_data((guint8*) uncompr, bytes_out,
+		    bytes_out);
+		tvb_set_free_cb(uncompr_tvb, g_free);
+	}
+	g_free(compr);
+	return uncompr_tvb;
+}
+#else
+tvbuff_t *
+tvb_uncompress(tvbuff_t *tvb _U_, int offset _U_, int comprlen _U_)
+{
+	return NULL;
+}
+#endif
+
