@@ -1,6 +1,6 @@
 # -*- python -*-
 #
-# $Id: ethereal_gen.py 11400 2004-07-18 00:24:25Z guy $
+# $Id: ethereal_gen.py 13046 2005-01-15 10:39:49Z guy $
 #                           
 # ethereal_gen.py (part of idl2eth)           
 #
@@ -2230,7 +2230,7 @@ static gboolean dissect_@dissname@(tvbuff_t *tvb, packet_info *pinfo, proto_tree
  */
 
     if (ptree) {
-       ti = proto_tree_add_item(ptree, proto_@dissname@, tvb, *offset, tvb_length(tvb) - *offset, FALSE);
+       ti = proto_tree_add_item(ptree, proto_@dissname@, tvb, *offset, -1, FALSE);
        tree = proto_item_add_subtree(ti, ett_@dissname@);
     }  
 
