@@ -1,7 +1,7 @@
 /* etypes.h
  * Defines ethernet packet types, similar to tcpdump's ethertype.h
  *
- * $Id: etypes.h 11536 2004-07-27 06:05:20Z guy $
+ * $Id: etypes.h 12967 2005-01-06 08:37:43Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -43,6 +43,14 @@
  * tcpdump's ethertype.h
  * http://www.cavebear.com/CaveBear/Ethernet/
  * http://standards.ieee.org/regauth/ethertype/type-pub.html
+ * http://standards.ieee.org/regauth/ethertype/eth.txt
+ * (The first of the two IEEE URLs is the one that the "EtherType Field
+ * Public Assignments" link on the page at
+ *
+ *	http://standards.ieee.org/regauth/ethertype/index.shtml
+ *
+ * goes to, but it is redirected to the second of those - i.e., both
+ * of the IEEE URLs ultimately go to the same page.)
  */
 
 #ifndef ETHERTYPE_VINES_IP
@@ -117,7 +125,11 @@
 #endif
 
 #ifndef ETHERTYPE_ETHBRIDGE
-#define ETHERTYPE_ETHBRIDGE	0x6558	/* transparent Ethernet bridging */
+#define ETHERTYPE_ETHBRIDGE	0x6558	/* transparent Ethernet bridging [RFC1701]*/
+#endif
+
+#ifndef ETHERTYPE_RAW_FR
+#define ETHERTYPE_RAW_FR	0x6559	/* Raw Frame Relay        [RFC1701] */
 #endif
 
 #ifndef ETHERTYPE_REVARP
@@ -128,6 +140,10 @@
 #define ETHERTYPE_DEC_LB	0x8038
 #endif
 
+#ifndef ETHERTYPE_DEC_LAST
+#define ETHERTYPE_DEC_LAST	0x8041	/* DEC Local Area Systems Transport */
+#endif
+
 #ifndef ETHERTYPE_ATALK
 #define ETHERTYPE_ATALK		0x809b
 #endif
@@ -204,6 +220,10 @@
 #define ETHERTYPE_MS_NLB_HEARTBEAT	0x886f	/* MS Network Load Balancing heartbeat http://www.microsoft.com/technet/treeview/default.asp?url=/TechNet/prodtechnol/windows2000serv/deploy/confeat/nlbovw.asp */
 #endif
 
+#ifndef ETHERTYPE_CDMA2000_A10_UBS
+#define ETHERTYPE_CDMA2000_A10_UBS	0x8881	/* the byte stream protocol that is used for IP based micro-mobility bearer interfaces (A10) in CDMA2000(R)-based wireless networks */
+#endif
+
 #ifndef ETHERTYPE_EAPOL
 #define ETHERTYPE_EAPOL 	0x888e  /* 802.1x Authentication */
 #endif
@@ -216,10 +236,18 @@
 #define ETHERTYPE_HYPERSCSI     0x889A  /* HyperSCSI */
 #endif
 
+#ifndef ETHERTYPE_AOE
+#define ETHERTYPE_AOE           0x88A2
+#endif
+
 #ifndef ETHERTYPE_BRDWALK
 #define ETHERTYPE_BRDWALK       0x88AE
 #endif
 
+#ifndef ETHERTYPE_IEEE802_OUI_EXTENDED
+#define ETHERTYPE_IEEE802_OUI_EXTENDED 0x88B7	/* IEEE 802a OUI Extended Ethertype */
+#endif
+
 #ifndef ETHERTYPE_RSN_PREAUTH
 #define ETHERTYPE_RSN_PREAUTH	0x88c7  /* 802.11i Pre-Authentication */
 #endif
@@ -228,12 +256,12 @@
 #define ETHERTYPE_LOOP		0x9000 	/* used for layer 2 testing (do i see my own frames on the wire) */
 #endif
 
-#ifndef ETHERTYPE_RTNET
-#define ETHERTYPE_RTNET		0x9021 	/* RTNET protocol*/
+#ifndef ETHERTYPE_RTMAC
+#define ETHERTYPE_RTMAC		0x9021 	/* RTnet: Real-Time Media Access Control */
 #endif
 
 #ifndef ETHERTYPE_RTCFG
-#define ETHERTYPE_RTCFG		0x9022 	/* RTCFG protocol*/
+#define ETHERTYPE_RTCFG		0x9022 	/* RTnet: Real-Time Configuration Protocol */
 #endif
 
 #ifndef ETHERTYPE_FCFT
