@@ -1,7 +1,7 @@
 /* capture_info_dlg.c
  * Routines for packet capture info dialog
  *
- * $Id: capture_info_dlg.c,v 1.17 2004/05/27 17:26:46 ulfl Exp $
+ * $Id: capture_info_dlg.c 13061 2005-01-16 02:56:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -26,6 +26,8 @@
 # include "config.h"
 #endif
 
+#include <string.h>
+
 #ifdef HAVE_LIBPCAP
 
 #include <pcap.h>
@@ -37,9 +39,11 @@
 #include <epan/packet.h>
 #include "../capture.h"
 #include "globals.h"
-#include "capture_combo_utils.h"
+#include "capture_ui_utils.h"
 #include "dlg_utils.h"
 #include "ui_util.h"
+#include "main.h"
+#include "pcap-util.h"
 
 /* a single capture counter value (with title, pointer to value and GtkWidgets) */
 /* as the packet_counts is a struct, not an array, keep a pointer to the */
@@ -54,7 +58,7 @@ typedef struct {
 typedef struct {
     GtkWidget               *cap_w;
     GtkWidget               *running_time_lb;
-    capture_info_counts_t   counts[CAPTURE_PACKET_COUNTS];
+    capture_info_counts_t   counts[PACKET_COUNTS_SIZE];
 } capture_info_ui_t;
 
 
@@ -71,7 +75,7 @@ pct(gint num, gint denom) {
 
 static void
 capture_info_delete_cb(GtkWidget *w _U_, GdkEvent *event _U_, gpointer data _U_) {
-  capture_stop();
+  capture_stop(capture_opts->sync_mode);
 }
 
 
@@ -86,6 +90,8 @@ gchar           *iface)
   GtkWidget         *counts_fr, *running_tb, *running_label, *bbox;
   capture_info_ui_t *info;
   gchar             *cap_w_title;
+  gchar             *title_iface;
+  gchar             *descr;
 
   info = g_malloc0(sizeof(capture_info_ui_t));
   info->counts[0].title = "Total";
@@ -113,10 +119,24 @@ gchar           *iface)
   info->counts[11].title = "Other";
   info->counts[11].value_ptr = &(cinfo->counts->other);
 
-  cap_w_title = g_strdup_printf("Ethereal: Capture - Interface %s", iface);
-
+  /*
+   * Create the dialog window, with a title that includes the interface.
+   *
+   * If we have a descriptive name for the interface, show that,
+   * rather than its raw name.  On NT 5.x (2K/XP/Server2K3), the
+   * interface name is something like "\Device\NPF_{242423..." 
+   * which is pretty useless to the normal user.  On other platforms,
+   * it might be less cryptic, but if a more descriptive name is
+   * available, we should still use that.
+   */
+  descr = get_interface_descriptive_name(iface);
+  title_iface = g_strdup_printf("Ethereal: Capture from %s", descr);
+  g_free(descr);
+  cap_w_title = create_user_window_title(title_iface);
+  g_free(title_iface);
   info->cap_w = dlg_window_new(cap_w_title);
   g_free(cap_w_title);
+
   gtk_window_set_modal(GTK_WINDOW(info->cap_w), TRUE);
 
   /* Container for capture display widgets */
@@ -130,7 +150,7 @@ gchar           *iface)
   gtk_widget_show(counts_fr);
 
   /* Individual statistic elements */
-  counts_tb = gtk_table_new(CAPTURE_PACKET_COUNTS, 4, TRUE);
+  counts_tb = gtk_table_new(PACKET_COUNTS_SIZE, 4, TRUE);
   gtk_container_add(GTK_CONTAINER(counts_fr), counts_tb);
   gtk_container_border_width(GTK_CONTAINER(counts_tb), 5);
   gtk_widget_show(counts_tb);
@@ -138,7 +158,7 @@ gchar           *iface)
   gtk_table_set_row_spacings(GTK_TABLE(counts_tb), 0);
   gtk_table_set_col_spacings(GTK_TABLE(counts_tb), 5);
 
-  for (i = 0; i < CAPTURE_PACKET_COUNTS; i++) {
+  for (i = 0; i < PACKET_COUNTS_SIZE; i++) {
       info->counts[i].label = gtk_label_new(info->counts[i].title);
       gtk_misc_set_alignment(GTK_MISC(info->counts[i].label), 0.0f, 0.5f);
 
@@ -238,7 +258,7 @@ capture_info    *cinfo)
 
   if (cinfo->new_packets) {
 
-    for (i = 0; i < CAPTURE_PACKET_COUNTS; i++) {
+    for (i = 0; i < PACKET_COUNTS_SIZE; i++) {
         g_snprintf(label_str, sizeof(label_str), "%d",
                  *info->counts[i].value_ptr);
         gtk_label_set(GTK_LABEL(info->counts[i].value_lb), label_str);
