@@ -1,7 +1,7 @@
 /* capture_prefs.c
  * Dialog box for capture preferences
  *
- * $Id: capture_prefs.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: capture_prefs.c 13061 2005-01-16 02:56:28Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -41,7 +41,7 @@
 #include "dlg_utils.h"
 #include "simple_dialog.h"
 #include "pcap-util.h"
-#include "capture_combo_utils.h"
+#include "capture_ui_utils.h"
 #include "main.h"
 #include "compat_macros.h"
 
