@@ -1,7 +1,7 @@
 /* color_dlg.c
  * Definitions for dialog boxes for color filters
  *
- * $Id: color_dlg.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: color_dlg.c 12852 2004-12-29 01:08:20Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -1417,7 +1417,7 @@ edit_color_filter_ok_cb                (GtkButton       *button,
 
     if(!dfilter_compile(filter_text, &compiled_filter)) {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                      "Filter \"%s\" did not compile correctly.\n"
+                      "Filter \"%s\" didn't compile correctly.\n"
                       " Please try again. Filter unchanged.\n%s\n", filter_name,
                       dfilter_error_msg);
     } else {
