@@ -4,7 +4,7 @@
  * conversations_table   2003 Ronnie Sahlberg
  * Helper routines common to all endpoint conversations tap.
  *
- * $Id: conversations_table.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: conversations_table.c 12913 2005-01-01 12:49:54Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -36,17 +36,18 @@
 
 #include <gtk/gtk.h>
 
+#include <epan/packet_info.h>
+#include <epan/to_str.h>
+#include <epan/addr_resolv.h>
+#include <epan/tap.h>
+
 #include "compat_macros.h"
-#include "epan/packet_info.h"
-#include "epan/to_str.h"
-#include "epan/addr_resolv.h"
 #include "sat.h"
 #include "conversations_table.h"
 #include "image/clist_ascend.xpm"
 #include "image/clist_descend.xpm"
 #include "simple_dialog.h"
 #include "globals.h"
-#include <epan/tap.h>
 #include "gtk/find_dlg.h"
 #include "color.h"
 #include "gtk/color_dlg.h"
@@ -240,6 +241,11 @@ reset_ct_table_data(conversations_table *ct)
     ct->num_conversations=0;
 }
 
+static void
+reset_ct_table_data_cb(void *arg)
+{
+    reset_ct_table_data(arg);
+}
 
 void protect_thread_critical_region(void);
 void unprotect_thread_critical_region(void);
@@ -265,8 +271,8 @@ ct_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 	char *text2 = NULL;
 	int i1, i2;
 
-	GtkCListRow *row1 = (GtkCListRow *) ptr1;
-	GtkCListRow *row2 = (GtkCListRow *) ptr2;
+	const GtkCListRow *row1 = ptr1;
+	const GtkCListRow *row2 = ptr2;
 
 	text1 = GTK_CELL_TEXT (row1->cell[clist->sort_column])->text;
 	text2 = GTK_CELL_TEXT (row2->cell[clist->sort_column])->text;
@@ -944,25 +950,19 @@ ct_create_popup_menu(conversations_table *ct)
 static void
 draw_ct_table_address(conversations_table *ct, int conversation_idx)
 {
-    char *entry;
+    const char *entry;
     char *port;
-    address_type  at;
     guint32 pt;
     int rownum;
 
     rownum=gtk_clist_find_row_from_data(ct->table, (gpointer)conversation_idx);
 
-    at = ct->conversations[conversation_idx].src_address.type;
-    if(!ct->resolve_names) at = AT_NONE;
-    switch(at) {
-    case(AT_IPv4):
-        entry=get_hostname((*(guint *)ct->conversations[conversation_idx].src_address.data));
-        break;
-    case(AT_ETHER):
-        entry=get_ether_name(ct->conversations[conversation_idx].src_address.data);
-        break;
-    default:
+    if(!ct->resolve_names)
         entry=address_to_str(&ct->conversations[conversation_idx].src_address);
+    else {
+        entry=get_addr_name(&ct->conversations[conversation_idx].src_address);
+        if(!entry)
+            entry=address_to_str(&ct->conversations[conversation_idx].src_address);
     }
     gtk_clist_set_text(ct->table, rownum, 0, entry);
 
@@ -981,17 +981,12 @@ draw_ct_table_address(conversations_table *ct, int conversation_idx)
     }
     gtk_clist_set_text(ct->table, rownum, 1, entry);
 
-    at = ct->conversations[conversation_idx].dst_address.type;
-    if(!ct->resolve_names) at = AT_NONE;
-    switch(at) {
-    case(AT_IPv4):
-        entry=get_hostname((*(guint *)ct->conversations[conversation_idx].dst_address.data));
-        break;
-    case(AT_ETHER):
-        entry=get_ether_name(ct->conversations[conversation_idx].dst_address.data);
-        break;
-    default:
+    if(!ct->resolve_names)
         entry=address_to_str(&ct->conversations[conversation_idx].dst_address);
+    else {
+        entry=get_addr_name(&ct->conversations[conversation_idx].dst_address);
+        if(!entry)
+            entry=address_to_str(&ct->conversations[conversation_idx].dst_address);
     }
     gtk_clist_set_text(ct->table, rownum, 2, entry);
 
@@ -1062,15 +1057,20 @@ draw_ct_table_data(conversations_table *ct)
 
     }
 	
-	draw_ct_table_addresses(ct);
+    draw_ct_table_addresses(ct);
 	
     gtk_clist_sort(ct->table);
 
-	/* Allow table to redraw */
+    /* Allow table to redraw */
     gtk_clist_thaw(ct->table);
-	gtk_clist_freeze(ct->table);
+    gtk_clist_freeze(ct->table);
 }
 
+static void
+draw_ct_table_data_cb(void *arg)
+{
+    draw_ct_table_data(arg);
+}
 
 #if (GTK_MAJOR_VERSION >= 2)
 static void
@@ -1112,8 +1112,8 @@ copy_as_csv_cb(GtkWindow *win _U_, gpointer data)
 #endif
 
 
-gboolean
-init_ct_table_page(conversations_table *conversations, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+static gboolean
+init_ct_table_page(conversations_table *conversations, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     int i;
     column_arrows *col_arrows;
@@ -1220,7 +1220,7 @@ init_ct_table_page(conversations_table *conversations, GtkWidget *vbox, gboolean
 #endif                 
 
     /* register the tap and rerun the taps on the packet list */
-    error_string=register_tap_listener(tap_name, conversations, filter, (void *)reset_ct_table_data, packet_func, (void *)draw_ct_table_data);
+    error_string=register_tap_listener(tap_name, conversations, filter, reset_ct_table_data_cb, packet_func, draw_ct_table_data_cb);
     if(error_string){
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
         g_string_free(error_string, TRUE);
@@ -1232,7 +1232,7 @@ init_ct_table_page(conversations_table *conversations, GtkWidget *vbox, gboolean
 
 
 void
-init_conversation_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_conversation_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     conversations_table *conversations;
     char title[256];
@@ -1302,7 +1302,7 @@ ct_win_destroy_notebook_cb(GtkWindow *win _U_, gpointer data)
 
 
 static conversations_table *
-init_ct_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_ct_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     gboolean ret;
     GtkWidget *page_vbox;
@@ -1327,18 +1327,18 @@ init_ct_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name,
 
 
 typedef struct {
-    gboolean hide_ports;    /* hide TCP / UDP port columns */
-    char *table_name;       /* GUI output name */
-    char *tap_name;         /* internal name */
-    char *filter;           /* display filter string (unused) */
-    void *packet_func;      /* function to be called for new incoming packets */
+    gboolean hide_ports;       /* hide TCP / UDP port columns */
+    char *table_name;          /* GUI output name */
+    char *tap_name;            /* internal name */
+    char *filter;              /* display filter string (unused) */
+    tap_packet_cb packet_func; /* function to be called for new incoming packets */
 } register_ct_t;
 
 
 static GSList *registered_ct_tables = NULL;
 
 void
-register_conversation_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+register_conversation_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     register_ct_t *table;
 
@@ -1462,9 +1462,9 @@ init_conversation_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
 
 
 void
-add_conversation_table_data(conversations_table *ct, address *src, address *dst, guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, SAT_E sat, int port_type)
+add_conversation_table_data(conversations_table *ct, const address *src, const address *dst, guint32 src_port, guint32 dst_port, int num_frames, int num_bytes, SAT_E sat, int port_type)
 {
-    address *addr1, *addr2;
+    const address *addr1, *addr2;
     guint32 port1, port2;
     conversation_t *conversation=NULL;
     int conversation_idx=0;
@@ -1587,5 +1587,3 @@ add_conversation_table_data(conversations_table *ct, address *src, address *dst,
         draw_ct_table_address(ct, conversation_idx);
     }
 }
-
-
