@@ -1,7 +1,7 @@
 /* dcerpc_stat.c
  * dcerpc_stat   2002 Ronnie Sahlberg
  *
- * $Id: dcerpc_stat.c,v 1.58 2004/06/02 07:12:09 ulfl Exp $
+ * $Id: dcerpc_stat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -44,11 +44,11 @@
 #include "simple_dialog.h"
 #include "dlg_utils.h"
 #include "ui_util.h"
-#include "tap.h"
+#include <epan/tap.h>
 #include "../register.h"
-#include "packet-dcerpc.h"
+#include <epan/dissectors/packet-dcerpc.h>
 #include "../globals.h"
-#include "filter_prefs.h"
+#include "filter_dlg.h"
 #include "compat_macros.h"
 #include "service_response_time_table.h"
 #include "gtkglobals.h"
@@ -114,10 +114,10 @@ dcerpcstat_reset(void *rs_arg)
 
 
 static int
-dcerpcstat_packet(void *rs_arg, packet_info *pinfo, epan_dissect_t *edt _U_, void *ri_arg)
+dcerpcstat_packet(void *rs_arg, packet_info *pinfo, epan_dissect_t *edt _U_, const void *ri_arg)
 {
 	rpcstat_t *rs = rs_arg;
-	dcerpc_info *ri = ri_arg;
+	const dcerpc_info *ri = ri_arg;
 
 	if(!ri->call_data){
 		return 0;
@@ -352,7 +352,7 @@ static void
 dcerpcstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 {
 	GString *str;
-	char *filter;
+	const char *filter;
 
 	str = g_string_new("dcerpc,srt");
 	g_string_sprintfa(str,
@@ -364,7 +364,7 @@ dcerpcstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 	    dcerpc_uuid_program->Data4[4], dcerpc_uuid_program->Data4[5],
 	    dcerpc_uuid_program->Data4[6], dcerpc_uuid_program->Data4[7],
 	    dcerpc_version, 0);
-	filter=(char *)gtk_entry_get_text(GTK_ENTRY(filter_entry));
+	filter=gtk_entry_get_text(GTK_ENTRY(filter_entry));
 	if(filter[0]!=0){
 		g_string_sprintfa(str, ",%s", filter);
 	}
