@@ -1,7 +1,7 @@
 /* dlg_utils.c
  * Utilities to use when constructing dialogs
  *
- * $Id: dlg_utils.c,v 1.39 2004/06/20 19:35:04 ulfl Exp $
+ * $Id: dlg_utils.c 12146 2004-09-30 02:02:35Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -100,6 +100,7 @@ dlg_button_row_new(gchar *stock_id_first, ...)
     gchar *ok           = NULL;
     gchar *apply        = NULL;
     gchar *save         = NULL;
+    gchar *dont_save	= NULL;
     gchar *cancel       = NULL;
     gchar *close        = NULL;
     gchar *clear        = NULL;
@@ -125,6 +126,8 @@ dlg_button_row_new(gchar *stock_id_first, ...)
             apply = stock_id;
         } else if (strcmp(stock_id, GTK_STOCK_SAVE) == 0) {
             save = stock_id;
+        } else if (strcmp(stock_id, ETHEREAL_STOCK_DONT_SAVE) == 0) {
+        	dont_save = stock_id;  
         } else if (strcmp(stock_id, GTK_STOCK_CANCEL) == 0) {
             cancel = stock_id;
         } else if (strcmp(stock_id, GTK_STOCK_CLOSE) == 0) {
@@ -190,7 +193,8 @@ dlg_button_row_new(gchar *stock_id_first, ...)
     gtk_button_box_set_layout (GTK_BUTTON_BOX(button_hbox), GTK_BUTTONBOX_END);
     gtk_button_box_set_spacing(GTK_BUTTON_BOX(button_hbox), 5);
 
-#if !WIN32 && GTK_MAJOR_VERSION >= 2
+/* GTK+ 1.3 and later - on Win32, we use 1.3[.x] or 2.x, not 1.2[.x] */
+#if !defined(_WIN32) && GTK_MAJOR_VERSION >= 2
     /* beware: sequence of buttons are important! */
 
     /* XXX: this can be implemented more elegant of course, but it works as it should */
@@ -256,11 +260,17 @@ dlg_button_row_new(gchar *stock_id_first, ...)
             return hbox;
         }
         if (yes && no && cancel) {
-            dlg_button_new(hbox, button_hbox, yes);
             dlg_button_new(hbox, button_hbox, no);
             dlg_button_new(hbox, button_hbox, cancel);
+            dlg_button_new(hbox, button_hbox, yes);
             return hbox;
         }
+        if (save && dont_save && cancel) {
+        	dlg_button_new(hbox, button_hbox, dont_save);
+        	dlg_button_new(hbox, button_hbox, cancel);
+        	dlg_button_new(hbox, button_hbox, save);
+        	return hbox;
+        }
     }
     if (buttons == 4) {
         if (ok && apply && save && cancel) {
@@ -290,6 +300,7 @@ dlg_button_row_new(gchar *stock_id_first, ...)
     if (yes     != NULL) dlg_button_new(hbox, button_hbox, yes);
     if (no      != NULL) dlg_button_new(hbox, button_hbox, no);
     if (save    != NULL) dlg_button_new(hbox, button_hbox, save);
+    if (dont_save != NULL) dlg_button_new(hbox, button_hbox, dont_save);
     if (stop    != NULL) dlg_button_new(hbox, button_hbox, stop);
     if (close   != NULL) dlg_button_new(hbox, button_hbox, close);
     if (clear   != NULL) dlg_button_new(hbox, button_hbox, clear);
@@ -304,7 +315,7 @@ dlg_button_row_new(gchar *stock_id_first, ...)
 /* this is called, when a dialog was closed */
 static void dlg_destroy_cb(GtkWidget *dialog _U_, gpointer data	_U_)
 {
-#if GTK_MAJOR_VERSION >= 2
+#if GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 4
     if(top_level) {
         /* bring main window back to front (workaround for a bug in win32 GTK2.x)
            XXX - do this only on Windows? */
@@ -367,11 +378,21 @@ file_selection_new(const gchar *title, file_selection_action_t action)
     ok_button_text = GTK_STOCK_OPEN;
     break;
 
+  case FILE_SELECTION_READ_BROWSE:
+    gtk_action = GTK_FILE_CHOOSER_ACTION_OPEN;
+    ok_button_text = GTK_STOCK_OK;
+    break;
+
   case FILE_SELECTION_SAVE:
     gtk_action = GTK_FILE_CHOOSER_ACTION_SAVE;
     ok_button_text = GTK_STOCK_SAVE;
     break;
 
+  case FILE_SELECTION_WRITE_BROWSE:
+    gtk_action = GTK_FILE_CHOOSER_ACTION_SAVE;
+    ok_button_text = GTK_STOCK_OK;
+    break;
+
   default:
     g_assert_not_reached();
     gtk_action = -1;
@@ -379,8 +400,13 @@ file_selection_new(const gchar *title, file_selection_action_t action)
     break;
   }
   win = gtk_file_chooser_dialog_new(title, GTK_WINDOW(top_level), gtk_action,
+#ifndef _WIN32
+                                    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                    ok_button_text, GTK_RESPONSE_ACCEPT,
+#else
                                     ok_button_text, GTK_RESPONSE_ACCEPT,
                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#endif
                                     NULL);
 
   /* If we've opened a file before, start out by showing the files in the directory
@@ -425,10 +451,16 @@ file_selection_set_current_folder(GtkWidget *fs, const gchar *filename)
     int filename_len = strlen(filename);
     gchar *new_filename;
 
-    /* trim filename, so gtk_file_chooser_set_current_folder() likes it */
-    if (filename[filename_len -1] == G_DIR_SEPARATOR && filename[1] != ':') {
+    /* trim filename, so gtk_file_chooser_set_current_folder() likes it, see below */
+    if (filename[filename_len -1] == G_DIR_SEPARATOR 
+#ifdef _WIN32
+        && filename_len > 3)    /* e.g. "D:\" */
+#else
+        && filename_len > 1)    /* e.g. "/" */
+#endif
+    {
         new_filename = g_strdup(filename);
-	    new_filename[filename_len-1] = '\0';
+        new_filename[filename_len-1] = '\0';
     } else {
         new_filename = g_strdup(filename);
     }
