@@ -1,7 +1,7 @@
 /* dlg_utils.h
  * Declarations of utilities to use when constructing dialogs
  *
- * $Id: dlg_utils.h,v 1.21 2004/06/05 12:12:13 ulfl Exp $
+ * $Id: dlg_utils.h 12146 2004-09-30 02:02:35Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -99,8 +99,10 @@ extern GtkWidget *dlg_window_new(const gchar *title);
 
 /** the action a file selection is designed for */
 typedef enum {
-	FILE_SELECTION_OPEN,    /**< open a file */
-	FILE_SELECTION_SAVE     /**< save/export a file */
+	FILE_SELECTION_OPEN,            /**< open a file */
+	FILE_SELECTION_READ_BROWSE,     /**< browse for a file to read */
+	FILE_SELECTION_SAVE,            /**< save/export a file */
+	FILE_SELECTION_WRITE_BROWSE     /**< browse for a file to write to */
 } file_selection_action_t;
 
 /** Create a file selection dialog box window that belongs to Ethereal's
