@@ -2,7 +2,7 @@
  * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball, Josh MacDonald
  * Copyright (C) 1997-1998 Jay Painter <jpaint@serv.net><jpaint@gimp.org>
  *
- * $Id: ethclist.h,v 1.4 2004/06/01 21:56:03 ulfl Exp $
+ * $Id: ethclist.h 12653 2004-12-02 03:12:24Z sahlberg $
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -89,7 +89,10 @@ typedef enum
   ETH_BUTTON_EXPANDS = 1 << 2
 } EthButtonAction;
 
-#define ETH_TYPE_CLIST            (eth_clist_get_type ())
+extern GtkType eth_clist_type;
+void init_eth_clist_type (void);
+
+#define ETH_TYPE_CLIST            (eth_clist_type)
 #define ETH_CLIST(obj)            (GTK_CHECK_CAST ((obj), ETH_TYPE_CLIST, EthCList))
 #define ETH_CLIST_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), ETH_TYPE_CLIST, EthCListClass))
 #define ETH_IS_CLIST(obj)         (GTK_CHECK_TYPE ((obj), ETH_TYPE_CLIST))
@@ -442,8 +445,6 @@ struct _EthCell
   } u;
 };
 
-GtkType eth_clist_get_type (void);
-
 /* constructors useful for gtk-- wrappers */
 void eth_clist_construct (EthCList *clist,
 			  gint      columns,
