@@ -1,7 +1,7 @@
 /* file_dlg.c
  * Dialog boxes for handling files
  *
- * $Id: file_dlg.c 12341 2004-10-18 15:14:13Z gerald $
+ * $Id: file_dlg.c 12915 2005-01-01 23:19:11Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -157,16 +157,16 @@ preview_set_filename(GtkWidget *prev, const gchar *cf_name)
     gtk_label_set_text(GTK_LABEL(label), "-");
 
     if(!cf_name) {
-        return FALSE;
+        return NULL;
     }
 
     label = OBJECT_GET_DATA(prev, PREVIEW_FILENAME_KEY);
-    gtk_label_set_text(GTK_LABEL(label), get_basename((char *)cf_name));
+    gtk_label_set_text(GTK_LABEL(label), get_basename(cf_name));
 
     if (test_for_directory(cf_name) == EISDIR) {
         label = OBJECT_GET_DATA(prev, PREVIEW_FORMAT_KEY);
         gtk_label_set_text(GTK_LABEL(label), "directory");
-        return FALSE;
+        return NULL;
     }
 
     wth = wtap_open_offline(cf_name, &err, &err_info, TRUE);
@@ -177,13 +177,13 @@ preview_set_filename(GtkWidget *prev, const gchar *cf_name)
         } else {
             gtk_label_set_text(GTK_LABEL(label), "error opening file");
         }
-        return FALSE;
+        return NULL;
     }
 
     /* Find the size of the file. */
     if (fstat(wtap_fd(wth), &cf_stat) < 0) {
         wtap_close(wth);
-        return FALSE;
+        return NULL;
     }
 
     /* size */
@@ -339,7 +339,7 @@ file_open_entry_changed(GtkWidget *w _U_, gpointer file_sel)
 
     /* set the filename to the preview */
     wth = preview_set_filename(prev, cf_name);
-    have_preview = (gboolean) wth;
+    have_preview = (wth != NULL);
 
     /* make the preview widget sensitive */
     gtk_widget_set_sensitive(prev, have_preview);
@@ -645,10 +645,11 @@ file_open_cmd_cb(GtkWidget *widget, gpointer data _U_) {
 /* user pressed "open" button */
 static void
 file_open_ok_cb(GtkWidget *w, gpointer fs) {
-  gchar     *cf_name, *rfilter, *s;
-  GtkWidget *filter_te, *m_resolv_cb, *n_resolv_cb, *t_resolv_cb;
-  dfilter_t *rfcode = NULL;
-  int        err;
+  gchar       *cf_name, *s;
+  const gchar *rfilter;
+  GtkWidget   *filter_te, *m_resolv_cb, *n_resolv_cb, *t_resolv_cb;
+  dfilter_t   *rfcode = NULL;
+  int          err;
 
 #if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 4) || GTK_MAJOR_VERSION > 2
   cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
@@ -656,7 +657,7 @@ file_open_ok_cb(GtkWidget *w, gpointer fs) {
   cf_name = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
 #endif
   filter_te = OBJECT_GET_DATA(w, E_RFILTER_TE_KEY);
-  rfilter = (gchar *)gtk_entry_get_text(GTK_ENTRY(filter_te));
+  rfilter = gtk_entry_get_text(GTK_ENTRY(filter_te));
   if (!dfilter_compile(rfilter, &rfcode)) {
     bad_dfilter_alert_box(rfilter);
     g_free(cf_name);
@@ -692,13 +693,22 @@ file_open_ok_cb(GtkWidget *w, gpointer fs) {
   cfile.rfcode = rfcode;
 
   /* Set the global resolving variable */
-  g_resolv_flags = prefs.name_resolve & RESOLV_CONCURRENT;
+  g_resolv_flags = prefs.name_resolve;
   m_resolv_cb = OBJECT_GET_DATA(w, E_FILE_M_RESOLVE_KEY);
-  g_resolv_flags |= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (m_resolv_cb)) ? RESOLV_MAC : RESOLV_NONE;
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (m_resolv_cb)))
+    g_resolv_flags |= RESOLV_MAC;
+  else
+    g_resolv_flags &= ~RESOLV_MAC;
   n_resolv_cb = OBJECT_GET_DATA(w, E_FILE_N_RESOLVE_KEY);
-  g_resolv_flags |= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (n_resolv_cb)) ? RESOLV_NETWORK : RESOLV_NONE;
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (n_resolv_cb)))
+    g_resolv_flags |= RESOLV_NETWORK;
+  else
+    g_resolv_flags &= ~RESOLV_NETWORK;
   t_resolv_cb = OBJECT_GET_DATA(w, E_FILE_T_RESOLVE_KEY);
-  g_resolv_flags |= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (t_resolv_cb)) ? RESOLV_TRANSPORT : RESOLV_NONE;
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (t_resolv_cb)))
+    g_resolv_flags |= RESOLV_TRANSPORT;
+  else
+    g_resolv_flags &= ~RESOLV_TRANSPORT;
 
   /* We've crossed the Rubicon; get rid of the file selection box. */
   window_destroy(GTK_WIDGET (fs));
@@ -972,7 +982,7 @@ file_merge_cmd_cb(GtkWidget *widget, gpointer data _U_) {
     /* user didn't saved his current file, ask him */
     dialog = simple_dialog(ESD_TYPE_CONFIRMATION, ESD_BTNS_OK_CANCEL,
                 PRIMARY_TEXT_START "Save the capture file before merging to another one?" PRIMARY_TEXT_END "\n\n"
-                "A temporary capture file cannot be merged.");
+                "A temporary capture file can't be merged.");
     simple_dialog_set_cb(dialog, file_merge_answered_cb, widget);
   } else {
     /* unchanged file, just start to merge */
@@ -983,14 +993,15 @@ file_merge_cmd_cb(GtkWidget *widget, gpointer data _U_) {
 
 static void
 file_merge_ok_cb(GtkWidget *w, gpointer fs) {
-  gchar     *cf_name, *rfilter, *s;
-  GtkWidget *filter_te, *rb;
-  dfilter_t *rfcode = NULL;
-  int        err;
-  gboolean   merge_ok;
-  char      *in_filenames[2];
-  int       out_fd;
-  char      tmpname[128+1];
+  gchar       *cf_name, *s;
+  const gchar *rfilter;
+  GtkWidget   *filter_te, *rb;
+  dfilter_t   *rfcode = NULL;
+  int          err;
+  gboolean     merge_ok;
+  char        *in_filenames[2];
+  int          out_fd;
+  char         tmpname[128+1];
 
 #if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 4) || GTK_MAJOR_VERSION > 2
   cf_name = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fs)));
@@ -998,7 +1009,7 @@ file_merge_ok_cb(GtkWidget *w, gpointer fs) {
   cf_name = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(fs)));
 #endif
   filter_te = OBJECT_GET_DATA(w, E_RFILTER_TE_KEY);
-  rfilter = (gchar *)gtk_entry_get_text(GTK_ENTRY(filter_te));
+  rfilter = gtk_entry_get_text(GTK_ENTRY(filter_te));
   if (!dfilter_compile(rfilter, &rfcode)) {
     bad_dfilter_alert_box(rfilter);
     g_free(cf_name);
@@ -1021,33 +1032,32 @@ file_merge_ok_cb(GtkWidget *w, gpointer fs) {
   /* merge or append the two files */
   rb = OBJECT_GET_DATA(w, E_MERGE_CHRONO_KEY);
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (rb))) {
-      /* chonological order */
+      /* chronological order */
       in_filenames[0] = cfile.filename;
       in_filenames[1] = cf_name;
-      merge_ok = merge_n_files(out_fd, 2, in_filenames, filetype, FALSE, &err);
+      merge_ok = cf_merge_files(tmpname, out_fd, 2, in_filenames,
+                                filetype, FALSE);
   } else {
       rb = OBJECT_GET_DATA(w, E_MERGE_PREPEND_KEY);
       if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (rb))) {
           /* prepend file */
           in_filenames[0] = cfile.filename;
           in_filenames[1] = cf_name;
-          merge_ok = merge_n_files(out_fd, 2, in_filenames, filetype, TRUE, &err);
+          merge_ok = cf_merge_files(tmpname, out_fd, 2, in_filenames,
+                                    filetype, TRUE);
       } else {
           /* append file */
           in_filenames[0] = cf_name;
           in_filenames[1] = cfile.filename;
-          merge_ok = merge_n_files(out_fd, 2, in_filenames, filetype, TRUE, &err);
+          merge_ok = cf_merge_files(tmpname, out_fd, 2, in_filenames,
+                                    filetype, TRUE);
       }
   }
 
   g_free(cf_name);
   
-  if(!merge_ok) {
-    /* merge failed */
-    simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-		  "An error occurred while merging the files: %s.",
-		  wtap_strerror(err));
-    close(out_fd);
+  if (!merge_ok) {
+    close(out_fd);	/* XXX - it's already closed, right? */
     if (rfcode != NULL)
       dfilter_free(rfcode);
     return;
