@@ -1,7 +1,7 @@
 /* font_utils.c
  * Utilities to use for font manipulation
  *
- * $Id: font_utils.c,v 1.1 2004/06/17 16:35:24 ulfl Exp $
+ * $Id: font_utils.c 12855 2004-12-29 12:37:06Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,12 +31,14 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#ifdef WIN32
+#include <epan/packet.h>
+
+#ifdef _WIN32
 #include <windows.h>
 #endif
 
 #include "recent.h"
-#include "prefs.h"
+#include <epan/prefs.h>
 
 #include "gtkglobals.h"
 
@@ -49,11 +51,6 @@
 #include "follow_dlg.h"
 
 
-/* XXX - use capture.h instead */
-/*#include "capture.h"*/
-extern gboolean capture_child;	
-
-
 
 #if GTK_MAJOR_VERSION < 2
 guint	     m_font_height, m_font_width;
@@ -298,7 +295,7 @@ user_font_test(gchar *font_name)
 		   Tell the user, but don't tear down the font selection
 		   dialog, so that they can try again. */
 		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-		   "The font you selected cannot be loaded.");
+		   "The font you selected can't be loaded.");
 
 #if GTK_MAJOR_VERSION < 2
 		g_free(bold_font_name);
@@ -570,7 +567,7 @@ user_font_apply(void) {
 }
 
 
-#ifdef WIN32
+#ifdef _WIN32
 
 #define NAME_BUFFER_LEN 32
 
@@ -710,16 +707,16 @@ static void try_to_get_windows_font_gtk2(void)
 }
 #endif /* GTK_MAJOR_VERSION */
 
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
 
-void font_init(void)
+void font_init(gboolean capture_child)
 {
 #if GTK_MAJOR_VERSION < 2
   gchar *bold_font_name;
 #endif
 
-#ifdef WIN32
+#ifdef _WIN32
 #if GTK_MAJOR_VERSION >= 2
   /* try to load the application font for GTK2 */
   try_to_get_windows_font_gtk2();
