@@ -2,7 +2,7 @@
  * h225 message counter for ethereal
  * Copyright 2003 Lars Roland
  *
- * $Id: h225_counter.c,v 1.22 2004/06/02 07:12:10 ulfl Exp $
+ * $Id: h225_counter.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,9 +40,9 @@
 #include <epan/value_string.h>
 
 #include "tap_menu.h"
-#include "../tap.h"
+#include <epan/tap.h>
 #include "../register.h"
-#include "../packet-h225.h"
+#include <epan/dissectors/packet-h225.h>
 #include "gtk_stat_util.h"
 #include "compat_macros.h"
 #include "../simple_dialog.h"
@@ -157,10 +157,10 @@ h225counter_reset(void *phs)
 }
 
 static int
-h225counter_packet(void *phs, packet_info *pinfo _U_, epan_dissect_t *edt _U_, void *phi)
+h225counter_packet(void *phs, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *phi)
 {
 	h225counter_t *hs=(h225counter_t *)phs;
-	h225_packet_info *pi=phi;
+	const h225_packet_info *pi=phi;
 
 	switch (pi->msg_type) {
 
@@ -439,7 +439,7 @@ h225counter_draw(void *phs)
 	for(i=0;i<=CS_MSG_TYPES;i++) {
 		if(hs->cs_msg[i]!=0) {
 			g_snprintf(str[0], sizeof(char[256]),
-                "%s", val_to_str(i,h323_message_body_vals,"unknown cs-messages   "));
+                "%s", val_to_str(i,T_h323_message_body_vals,"unknown cs-messages   "));
 			g_snprintf(str[1], sizeof(char[256]),
                 "%d", hs->cs_msg[i]);
 			gtk_clist_append(hs->table, str);
@@ -527,7 +527,7 @@ gtk_h225counter_init(char *optarg)
 	hs->vbox=gtk_vbox_new(FALSE, 3);
 	gtk_container_set_border_width(GTK_CONTAINER(hs->vbox), 12);
 
-	init_main_stat_window(hs->win, hs->vbox, "ITU-T H.225 Message and Message Reason Counter", filter);
+	init_main_stat_window(hs->win, hs->vbox, "H.225 Message and Message Reason Counter", filter);
 
         /* init a scrolled window*/
 	hs->scrolled_window = scrolled_window_new(NULL, NULL);
@@ -556,8 +556,7 @@ gtk_h225counter_init(char *optarg)
 	gtk_widget_show_all(hs->win);
     window_present(hs->win);
 
-    /* XXX - shouldn't this be retap_packets? */
-	redissect_packets(&cfile);
+	retap_packets(&cfile);
 }
 
 void
@@ -565,6 +564,6 @@ register_tap_listener_gtk_h225counter(void)
 {
 	register_ethereal_tap("h225,counter", gtk_h225counter_init);
 
-	register_tap_menu_item("ITU-T H.225...", REGISTER_TAP_GROUP_NONE,
+	register_tap_menu_item("H.225...", REGISTER_TAP_GROUP_NONE,
 	    gtk_tap_dfilter_dlg_cb, NULL, NULL, &(h225_counter_dlg));
 }
