@@ -2,7 +2,7 @@
  * h225 RAS Service Response Time statistics for ethereal
  * Copyright 2003 Lars Roland
  *
- * $Id: h225_ras_srt.c,v 1.19 2004/06/02 07:12:10 ulfl Exp $
+ * $Id: h225_ras_srt.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,9 +40,9 @@
 #include <epan/value_string.h>
 
 #include "tap_menu.h"
-#include "../tap.h"
+#include <epan/tap.h>
 #include "../register.h"
-#include "../packet-h225.h"
+#include <epan/dissectors/packet-h225.h>
 #include "../timestats.h"
 #include "gtk_stat_util.h"
 #include "compat_macros.h"
@@ -142,10 +142,10 @@ h225rassrt_reset(void *phs)
 
 
 static int
-h225rassrt_packet(void *phs, packet_info *pinfo _U_, epan_dissect_t *edt _U_, void *phi)
+h225rassrt_packet(void *phs, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *phi)
 {
 	h225rassrt_t *hs=(h225rassrt_t *)phs;
-	h225_packet_info *pi=phi;
+	const h225_packet_info *pi=phi;
 
 	ras_type rasmsg_type = RAS_OTHER;
 	ras_category rascategory = RAS_OTHERS;
@@ -307,7 +307,7 @@ gtk_h225rassrt_init(char *optarg)
 	hs->vbox=gtk_vbox_new(FALSE, 3);
 	gtk_container_set_border_width(GTK_CONTAINER(hs->vbox), 12);
 
-	init_main_stat_window(hs->win, hs->vbox, "ITU-T H.225 RAS Service Response Time", filter);
+	init_main_stat_window(hs->win, hs->vbox, "H.225 RAS Service Response Time", filter);
 
         /* init a scrolled window*/
 	hs->scrolled_window = scrolled_window_new(NULL, NULL);
@@ -336,8 +336,7 @@ gtk_h225rassrt_init(char *optarg)
 	gtk_widget_show_all(hs->win);
     window_present(hs->win);
 
-    /* XXX - shouldn't this be retap_packets? */
-    redissect_packets(&cfile);
+    retap_packets(&cfile);
 }
 
 void
@@ -345,6 +344,6 @@ register_tap_listener_gtk_h225rassrt(void)
 {
 	register_ethereal_tap("h225,srt", gtk_h225rassrt_init);
 
-	register_tap_menu_item("ITU-T H.225 RAS...", REGISTER_TAP_GROUP_RESPONSE_TIME,
+	register_tap_menu_item("H.225 RAS...", REGISTER_TAP_GROUP_RESPONSE_TIME,
 	    gtk_tap_dfilter_dlg_cb, NULL, NULL, &(h225_rassrt_dlg));
 }
