@@ -2,7 +2,7 @@
  * modified from endpoint_talkers_table.c   2003 Ronnie Sahlberg
  * Helper routines common to all host list taps.
  *
- * $Id: hostlist_table.c,v 1.17 2004/06/03 21:46:27 guy Exp $
+ * $Id: hostlist_table.c 12913 2005-01-01 12:49:54Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -31,17 +31,20 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
+
 #include <gtk/gtk.h>
+
+#include <epan/packet_info.h>
+#include <epan/to_str.h>
+#include <epan/addr_resolv.h>
+#include <epan/tap.h>
+
 #include "compat_macros.h"
-#include "epan/packet_info.h"
-#include "epan/to_str.h"
-#include "epan/resolv.h"
 #include "hostlist_table.h"
 #include "image/clist_ascend.xpm"
 #include "image/clist_descend.xpm"
 #include "simple_dialog.h"
 #include "globals.h"
-#include "tap.h"
 #include "gtk/find_dlg.h"
 #include "color.h"
 #include "gtk/color_dlg.h"
@@ -143,6 +146,9 @@ reset_hostlist_table_data(hostlist_table *hosts)
 {
     guint32 i;
     char title[256];
+	
+	/* Allow clist to update */
+    gtk_clist_thaw(hosts->table);
 
     if(hosts->page_lb) {
         g_snprintf(title, 255, "Endpoints: %s", cf_get_display_name(&cfile));
@@ -156,9 +162,7 @@ reset_hostlist_table_data(hostlist_table *hosts)
     }
 
     /* remove all entries from the clist */
-    for(i=0;i<hosts->num_hosts;i++){
-        gtk_clist_remove(hosts->table, hosts->num_hosts-i-1);
-    }
+    gtk_clist_clear(hosts->table);
 
     /* delete all hosts */
     for(i=0;i<hosts->num_hosts;i++){
@@ -169,7 +173,11 @@ reset_hostlist_table_data(hostlist_table *hosts)
     hosts->num_hosts=0;
 }
 
-
+static void
+reset_hostlist_table_data_cb(void *arg)
+{
+    reset_hostlist_table_data(arg);
+}
 
 void protect_thread_critical_region(void);
 void unprotect_thread_critical_region(void);
@@ -193,8 +201,8 @@ hostlist_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 	char *text2 = NULL;
 	int i1, i2;
 
-	GtkCListRow *row1 = (GtkCListRow *) ptr1;
-	GtkCListRow *row2 = (GtkCListRow *) ptr2;
+	const GtkCListRow *row1 = ptr1;
+	const GtkCListRow *row2 = ptr2;
 
 	text1 = GTK_CELL_TEXT (row1->cell[clist->sort_column])->text;
 	text2 = GTK_CELL_TEXT (row2->cell[clist->sort_column])->text;
@@ -214,6 +222,12 @@ hostlist_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 		return i1-i2;
 	}
 	g_assert_not_reached();
+	
+	/* Allow clist to redraw */
+	
+	gtk_clist_thaw(clist);
+	gtk_clist_freeze(clist);
+	
 	return 0;
 }
 
@@ -223,8 +237,6 @@ hostlist_click_column_cb(GtkCList *clist, gint column, gpointer data)
 	column_arrows *col_arrows = (column_arrows *) data;
 	int i;
 
-	gtk_clist_freeze(clist);
-
 	for (i = 0; i < NUM_COLS; i++) {
 		gtk_widget_hide(col_arrows[i].ascend_pm);
 		gtk_widget_hide(col_arrows[i].descend_pm);
@@ -243,9 +255,12 @@ hostlist_click_column_cb(GtkCList *clist, gint column, gpointer data)
 		gtk_widget_show(col_arrows[column].descend_pm);
 		gtk_clist_set_sort_column(clist, column);
 	}
-	gtk_clist_thaw(clist);
 
 	gtk_clist_sort(clist);
+
+	/* Allow update of clist */
+	gtk_clist_thaw(clist);
+	gtk_clist_freeze(clist);
 }
 
 
@@ -445,55 +460,54 @@ hostlist_create_popup_menu(hostlist_table *hl)
 }
 
 
-/* XXX should freeze/thaw table here and in the srt thingy? */
+/* Draw/refresh the address field of a single entry at the specified index */
+static void
+draw_hostlist_table_address(hostlist_table *hl, int hostlist_idx)
+{
+    const char *entry;
+    char *port;
+    guint32 pt;
+    int rownum;
+
+    rownum=gtk_clist_find_row_from_data(hl->table, (gpointer)hostlist_idx);
+
+    if(!hl->resolve_names)
+        entry=address_to_str(&hl->hosts[hostlist_idx].address);
+    else {
+        entry=get_addr_name(&hl->hosts[hostlist_idx].address);
+        if(!entry)
+            entry=address_to_str(&hl->hosts[hostlist_idx].address);
+    }
+    gtk_clist_set_text(hl->table, rownum, 0, entry);
+
+    pt = hl->hosts[hostlist_idx].port_type;
+    if(!hl->resolve_names) pt = PT_NONE;
+    switch(pt) {
+    case(PT_TCP):
+        entry=get_tcp_port(hl->hosts[hostlist_idx].port);
+        break;
+    case(PT_UDP):
+        entry=get_udp_port(hl->hosts[hostlist_idx].port);
+        break;
+    default:
+        port=hostlist_port_to_str(hl->hosts[hostlist_idx].port_type, hl->hosts[hostlist_idx].port);
+        entry=port?port:"";
+    }
+    gtk_clist_set_text(hl->table, rownum, 1, entry);
+}
+
+/* Refresh the address fields of all entries in the list */
 static void
 draw_hostlist_table_addresses(hostlist_table *hl)
 {
     guint32 i;
-    int j;
-
 
     for(i=0;i<hl->num_hosts;i++){
-        char *entry;
-        char *port;
-        address_type  at;
-        guint32 pt;
-
-        j=gtk_clist_find_row_from_data(hl->table, (gpointer)i);
-
-        at = hl->hosts[i].address.type;
-        if(!hl->resolve_names) at = AT_NONE;
-        switch(at) {
-        case(AT_IPv4):
-            entry=get_hostname((*(guint *)hl->hosts[i].address.data));
-            break;
-        case(AT_ETHER):
-            entry=get_ether_name(hl->hosts[i].address.data);
-            break;
-        default:
-            entry=address_to_str(&hl->hosts[i].address);
-        }
-        gtk_clist_set_text(hl->table, j, 0, entry);
-
-        pt = hl->hosts[i].port_type;
-        if(!hl->resolve_names) pt = PT_NONE;
-        switch(pt) {
-        case(PT_TCP):
-            entry=get_tcp_port(hl->hosts[i].port);
-            break;
-        case(PT_UDP):
-            entry=get_udp_port(hl->hosts[i].port);
-            break;
-        default:
-            port=hostlist_port_to_str(hl->hosts[i].port_type, hl->hosts[i].port);
-            entry=port?port:"";
-        }
-        gtk_clist_set_text(hl->table, j, 1, entry);
+        draw_hostlist_table_address(hl, i);
     }
 }
 
 
-/* XXX should freeze/thaw table here and in the srt thingy? */
 static void
 draw_hostlist_table_data(hostlist_table *hl)
 {
@@ -534,29 +548,93 @@ draw_hostlist_table_data(hostlist_table *hl)
         gtk_clist_set_text(hl->table, j, 7, str);
 
     }
+	
+    draw_hostlist_table_addresses(hl);
+	
     gtk_clist_sort(hl->table);
 
-    /* update table, so resolved addresses will be shown now */
-    draw_hostlist_table_addresses(hl);
+    /* Allow table to redraw. */
+    gtk_clist_thaw(hl->table);
+    gtk_clist_freeze(hl->table);
 }
 
+static void
+draw_hostlist_table_data_cb(void *arg)
+{
+    draw_hostlist_table_data(arg);
+}
+
+#if (GTK_MAJOR_VERSION >= 2)
+static void
+copy_as_csv_cb(GtkWindow *win _U_, gpointer data)
+{
+   guint32         i,j;
+   gchar           *table_entry;
+   GtkClipboard    *cb;  
+   GString         *CSV_str = g_string_new("");
+   
+   hostlist_table *hosts=(hostlist_table *)data;
+   
+   /* Add the column headers to the CSV data */
+   for(i=0;i<hosts->num_columns;i++){                  /* all columns         */
+    if(i==1 && !hosts->has_ports) continue;            /* Don't add the port column if it's empty */
+     g_string_append(CSV_str,hosts->default_titles[i]);/* add the column heading to the CSV string */
+    if(i!=hosts->num_columns-1)
+     g_string_append(CSV_str,",");
+   }
+   g_string_append(CSV_str,"\n");                      /* new row */
+ 
+   /* Add the column values to the CSV data */
+   for(i=0;i<hosts->num_hosts;i++){                    /* all rows            */
+    for(j=0;j<hosts->num_columns;j++){                 /* all columns         */
+     if(j==1 && !hosts->has_ports) continue;           /* Don't add the port column if it's empty */
+     gtk_clist_get_text(hosts->table,i,j,&table_entry);/* copy table item into string */
+     g_string_append(CSV_str,table_entry);             /* add the table entry to the CSV string */
+    if(j!=hosts->num_columns-1)
+     g_string_append(CSV_str,",");
+    } 
+    g_string_append(CSV_str,"\n");                     /* new row */  
+   }
+
+   /* Now that we have the CSV data, copy it into the default clipboard */
+   cb = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);    /* Get the default clipboard */
+   gtk_clipboard_set_text(cb, CSV_str->str, -1);       /* Copy the CSV data into the clipboard */
+   g_string_free(CSV_str, TRUE);                       /* Free the memory */
+} 
+#endif
+
+
 static gboolean
-init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     int i;
     column_arrows *col_arrows;
     GtkStyle *win_style;
     GtkWidget *column_lb;
     GString *error_string;
-    GtkWidget *label;
     char title[256];
-    char *default_titles[] = { "Address", "Port", "Frames", "Bytes", "Tx Frames", "Tx Bytes", "Rx Frames", "Rx Bytes" };
+#if (GTK_MAJOR_VERSION >= 2)
+    GtkWidget *copy_bt;
+    GtkTooltips *tooltips = gtk_tooltips_new();
+#endif           
 
 
-    g_snprintf(title, 255, "%s Endpoints", table_name);
-    label=gtk_label_new(title);
-    gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+    hosttable->num_columns=NUM_COLS; 
+    hosttable->default_titles[0] = "Address";
+    hosttable->default_titles[1] = "Port";
+    hosttable->default_titles[2] = "Packets";
+    hosttable->default_titles[3] = "Bytes";
+    hosttable->default_titles[4] = "Tx Packets";
+    hosttable->default_titles[5] = "Tx Bytes";
+    hosttable->default_titles[6] = "Rx Packets";
+    hosttable->default_titles[7] = "Rx Bytes";
+    hosttable->has_ports=!hide_ports;
+    hosttable->num_hosts = 0;
+    hosttable->resolve_names=TRUE;
 
+    g_snprintf(title, 255, "%s Endpoints", table_name); 
+    hosttable->page_lb = gtk_label_new(title);                                                 
+    gtk_box_pack_start(GTK_BOX(vbox), hosttable->page_lb, FALSE, FALSE, 0);
 
     hosttable->scrolled_window=scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(vbox), hosttable->scrolled_window, TRUE, TRUE, 0);
@@ -568,7 +646,7 @@ init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hi
     for (i = 0; i < NUM_COLS; i++) {
         col_arrows[i].table = gtk_table_new(2, 2, FALSE);
         gtk_table_set_col_spacings(GTK_TABLE(col_arrows[i].table), 5);
-        column_lb = gtk_label_new(default_titles[i]);
+        column_lb = gtk_label_new(hosttable->default_titles[i]);
         gtk_table_attach(GTK_TABLE(col_arrows[i].table), column_lb, 0, 1, 0, 2, GTK_SHRINK, GTK_SHRINK, 0, 0);
         gtk_widget_show(column_lb);
 
@@ -598,19 +676,6 @@ init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hi
     gtk_clist_set_column_auto_resize(hosttable->table, 6, TRUE);
     gtk_clist_set_column_auto_resize(hosttable->table, 7, TRUE);
 
-#if 0
-    /*XXX instead of this we should probably have some code to
-        dynamically adjust the width of the columns */
-    gtk_clist_set_column_width(hosttable->table, 0, 100);
-    gtk_clist_set_column_width(hosttable->table, 1, 40);
-    gtk_clist_set_column_width(hosttable->table, 2, 70);
-    gtk_clist_set_column_width(hosttable->table, 3, 60);
-    gtk_clist_set_column_width(hosttable->table, 4, 70);
-    gtk_clist_set_column_width(hosttable->table, 5, 60);
-    gtk_clist_set_column_width(hosttable->table, 6, 70);
-    gtk_clist_set_column_width(hosttable->table, 7, 60);
-#endif
-
     gtk_clist_set_shadow_type(hosttable->table, GTK_SHADOW_IN);
     gtk_clist_column_titles_show(hosttable->table);
     gtk_container_add(GTK_CONTAINER(hosttable->scrolled_window), (GtkWidget *)hosttable->table);
@@ -628,9 +693,18 @@ init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hi
     /* create popup menu for this table */
     hostlist_create_popup_menu(hosttable);
 
+#if (GTK_MAJOR_VERSION >= 2)
+    /* XXX - maybe we want to have a "Copy as CSV" stock button here? */
+    /*copy_bt = gtk_button_new_with_label ("Copy content to clipboard as CSV");*/
+    copy_bt = BUTTON_NEW_FROM_STOCK(GTK_STOCK_COPY);
+    gtk_tooltips_set_tip(tooltips, copy_bt, 
+        "Copy all statistical values of this page to the clipboard in CSV (Comma Seperated Values) format.", NULL);
+    SIGNAL_CONNECT(copy_bt, "clicked", copy_as_csv_cb,(gpointer *) hosttable);
+    gtk_box_pack_start(GTK_BOX(vbox), copy_bt, FALSE, FALSE, 0);
+#endif
 
     /* register the tap and rerun the taps on the packet list */
-    error_string=register_tap_listener(tap_name, hosttable, filter, (void *)reset_hostlist_table_data, packet_func, (void *)draw_hostlist_table_data);
+    error_string=register_tap_listener(tap_name, hosttable, filter, reset_hostlist_table_data_cb, packet_func, draw_hostlist_table_data_cb);
     if(error_string){
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
         g_string_free(error_string, TRUE);
@@ -643,7 +717,7 @@ init_hostlist_table_page(hostlist_table *hosttable, GtkWidget *vbox, gboolean hi
 
 
 void
-init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     hostlist_table *hosttable;
     char title[256];
@@ -658,8 +732,7 @@ init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char
     hosttable->name=table_name;
     g_snprintf(title, 255, "%s Endpoints: %s", table_name, cf_get_display_name(&cfile));
     hosttable->win=window_new(GTK_WINDOW_TOPLEVEL, title);
-    hosttable->page_lb=NULL;
-    hosttable->resolve_names=TRUE;
+    
     gtk_window_set_default_size(GTK_WINDOW(hosttable->win), 750, 400);
 
     vbox=gtk_vbox_new(FALSE, 3);
@@ -686,6 +759,11 @@ init_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char
     window_present(hosttable->win);
 
     retap_packets(&cfile);
+	
+    /* Keep clist frozen to cause modifications to the clist (inserts, appends, others that are extremely slow
+	   in GTK2) to not be drawn, allow refreshes to occur at strategic points for performance */
+  	gtk_clist_freeze(hosttable->table);
+
 
     /* after retapping, redraw table */
     draw_hostlist_table_data(hosttable);
@@ -708,7 +786,7 @@ hostlist_win_destroy_notebook_cb(GtkWindow *win _U_, gpointer data)
 
 
 static hostlist_table *
-init_hostlist_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+init_hostlist_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     gboolean ret;
     GtkWidget *page_vbox;
@@ -733,18 +811,18 @@ init_hostlist_notebook_page_cb(gboolean hide_ports, char *table_name, char *tap_
 
 
 typedef struct {
-    gboolean hide_ports;    /* hide TCP / UDP port columns */
-    char *table_name;       /* GUI output name */
-    char *tap_name;         /* internal name */
-    char *filter;           /* display filter string (unused) */
-    void *packet_func;      /* function to be called for new incoming packets */
+    gboolean hide_ports;       /* hide TCP / UDP port columns */
+    char *table_name;          /* GUI output name */
+    char *tap_name;            /* internal name */
+    char *filter;              /* display filter string (unused) */
+    tap_packet_cb packet_func; /* function to be called for new incoming packets */
 } register_hostlist_t;
 
 
 static GSList *registered_hostlist_tables = NULL;
 
 void
-register_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, void *packet_func)
+register_hostlist_table(gboolean hide_ports, char *table_name, char *tap_name, char *filter, tap_packet_cb packet_func)
 {
     register_hostlist_t *table;
 
@@ -776,6 +854,9 @@ hostlist_resolve_toggle_dest(GtkWidget *widget, gpointer data)
         hosttable->resolve_names = resolve_names;
 
         draw_hostlist_table_addresses(hosttable);
+
+        gtk_clist_thaw(hosttable->table);
+        gtk_clist_freeze(hosttable->table);
     }
 }
 
@@ -867,7 +948,7 @@ init_hostlist_notebook_cb(GtkWidget *w _U_, gpointer d _U_)
 
 
 void
-add_hostlist_table_data(hostlist_table *hl, address *addr, guint32 port, gboolean sender, int num_frames, int num_bytes, SAT_E sat, int port_type)
+add_hostlist_table_data(hostlist_table *hl, const address *addr, guint32 port, gboolean sender, int num_frames, int num_bytes, SAT_E sat, int port_type)
 {
     hostlist_talker_t *talker=NULL;
     int talker_idx=0;
@@ -933,7 +1014,6 @@ add_hostlist_table_data(hostlist_table *hl, address *addr, guint32 port, gboolea
         char *entries[NUM_COLS];
         char frames[16],bytes[16],txframes[16],txbytes[16],rxframes[16],rxbytes[16];
 
-
         /* these values will be filled by call to draw_hostlist_table_addresses() below */
         entries[0]="";
         entries[1]="";
@@ -956,7 +1036,6 @@ add_hostlist_table_data(hostlist_table *hl, address *addr, guint32 port, gboolea
         gtk_clist_insert(hl->table, talker_idx, entries);
         gtk_clist_set_row_data(hl->table, talker_idx, (gpointer) talker_idx);
 
-        draw_hostlist_table_addresses(hl);
+		draw_hostlist_table_address(hl, talker_idx);
     }
 }
-
