@@ -1,7 +1,7 @@
 /* hostlist_tr.c   2004 Ian Schorr
  * modified from endpoint_talkers_tr.c   2003 Ronnie Sahlberg
  *
- * $Id: hostlist_tr.c,v 1.6 2004/05/02 21:16:09 ulfl Exp $
+ * $Id: hostlist_tr.c 12913 2005-01-01 12:49:54Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -34,17 +34,17 @@
 #include <string.h>
 #include "epan/packet.h"
 #include "tap_menu.h"
-#include "../tap.h"
+#include <epan/tap.h>
 #include "../register.h"
 #include "hostlist_table.h"
-#include "packet-tr.h"
+#include <epan/dissectors/packet-tr.h>
 
 
 static int
-tr_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, void *vip)
+tr_hostlist_packet(void *pit, packet_info *pinfo, epan_dissect_t *edt _U_, const void *vip)
 {
 	hostlist_table *hosts=(hostlist_table *)pit;
-	tr_hdr *trhdr=vip;
+	const tr_hdr *trhdr=vip;
 
 	/* Take two "add" passes per packet, adding for each direction, ensures that all
 	packets are counted properly (even if address is sending to itself) 
@@ -68,7 +68,7 @@ gtk_tr_hostlist_init(char *optarg)
 		filter=NULL;
 	}
 
-	init_hostlist_table(TRUE, "Token Ring Hosts", "tr", filter, (void *)tr_hostlist_packet);
+	init_hostlist_table(TRUE, "Token Ring Hosts", "tr", filter, tr_hostlist_packet);
 
 }
 
@@ -88,6 +88,5 @@ register_tap_listener_tr_hostlist(void)
 	register_tap_menu_item("Token Ring", REGISTER_TAP_GROUP_ENDPOINT_LIST,
 	    gtk_tr_hostlist_cb, NULL, NULL, NULL);
 
-    register_hostlist_table(TRUE, "Token Ring", "tr", NULL /*filter*/, (void *)tr_hostlist_packet);
+    register_hostlist_table(TRUE, "Token Ring", "tr", NULL /*filter*/, tr_hostlist_packet);
 }
-
