@@ -1,7 +1,7 @@
 /* io_stat.c
  * io_stat   2002 Ronnie Sahlberg
  *
- * $Id: io_stat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: io_stat.c 12921 2005-01-01 23:54:32Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -218,7 +218,7 @@ gtk_iostat_reset(void *g)
 }
 
 static int
-gtk_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, void *dummy _U_)
+gtk_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, const void *dummy _U_)
 {
 	io_stat_graph_t *git=g;
 	io_item_t *it;
@@ -979,7 +979,7 @@ gtk_iostat_draw(void *g)
    pruned 
 */
 static GString *
-enable_graph(io_stat_graph_t *gio, char *filter, char *field)
+enable_graph(io_stat_graph_t *gio, const char *filter, const char *field)
 {
 	char real_filter[260];
 
@@ -1307,11 +1307,11 @@ create_pixels_per_tick_menu_items(io_stat_t *io, GtkWidget *menu)
 	int i;
 
 	for(i=0;i<MAX_PIXELS_PER_TICK;i++){
-		g_snprintf(str, 5, "%d", pixels_per_tick[i]);
+		g_snprintf(str, 5, "%u", pixels_per_tick[i]);
 		menu_item=gtk_menu_item_new_with_label(str);
 
 		OBJECT_SET_DATA(menu_item, "pixels_per_tick",
-                                pixels_per_tick[i]);
+                                GUINT_TO_POINTER(pixels_per_tick[i]));
 		SIGNAL_CONNECT(menu_item, "activate", pixels_per_tick_select, io);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -1343,18 +1343,18 @@ create_tick_interval_menu_items(io_stat_t *io, GtkWidget *menu)
 
 	for(i=0;i<MAX_TICK_VALUES;i++){
 		if(tick_interval_values[i]>=1000){
-			g_snprintf(str, 15, "%d sec", tick_interval_values[i]/1000);
+			g_snprintf(str, 15, "%u sec", tick_interval_values[i]/1000);
 		} else if(tick_interval_values[i]>=100){
-			g_snprintf(str, 15, "0.%1d sec", (tick_interval_values[i]/100)%10);
+			g_snprintf(str, 15, "0.%1u sec", (tick_interval_values[i]/100)%10);
 		} else if(tick_interval_values[i]>=10){
-			g_snprintf(str, 15, "0.%02d sec", (tick_interval_values[i]/10)%10);
+			g_snprintf(str, 15, "0.%02u sec", (tick_interval_values[i]/10)%10);
 		} else {
-			g_snprintf(str, 15, "0.%03d sec", (tick_interval_values[i])%10);
+			g_snprintf(str, 15, "0.%03u sec", (tick_interval_values[i])%10);
 		}
 
 		menu_item=gtk_menu_item_new_with_label(str);
 		OBJECT_SET_DATA(menu_item, "tick_interval",
-                                tick_interval_values[i]);
+                                GUINT_TO_POINTER(tick_interval_values[i]));
 		SIGNAL_CONNECT(menu_item, "activate", tick_interval_select, (gpointer)io);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -1374,10 +1374,11 @@ create_yscale_max_menu_items(io_stat_t *io, GtkWidget *menu)
 		if(yscale_max[i]==AUTO_MAX_YSCALE){
 			strcpy(str,"Auto");
 		} else {
-			g_snprintf(str, 15, "%d", yscale_max[i]);
+			g_snprintf(str, 15, "%u", yscale_max[i]);
 		}
 		menu_item=gtk_menu_item_new_with_label(str);
-		OBJECT_SET_DATA(menu_item, "yscale_max", yscale_max[i]);
+		OBJECT_SET_DATA(menu_item, "yscale_max",
+		                GUINT_TO_POINTER(yscale_max[i]));
 		SIGNAL_CONNECT(menu_item, "activate", yscale_select, io);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -1428,7 +1429,7 @@ create_frames_or_bytes_menu_items(io_stat_t *io, GtkWidget *menu)
 
 	for(i=0;i<MAX_COUNT_TYPES;i++){
 		menu_item=gtk_menu_item_new_with_label(count_type_names[i]);
-		OBJECT_SET_DATA(menu_item, "count_type", i);
+		OBJECT_SET_DATA(menu_item, "count_type", GINT_TO_POINTER(i));
 		SIGNAL_CONNECT(menu_item, "activate", count_type_select, io);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
@@ -1505,12 +1506,12 @@ create_ctrl_area(io_stat_t *io, GtkWidget *box)
 static gint
 filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 {
-	char *filter;
-	char *field;
+	const char *filter;
+	const char *field;
 	header_field_info *hfi;
 	dfilter_t *dfilter;
 
-	field=(char *)gtk_entry_get_text(GTK_ENTRY(gio->calc_field));
+	field=gtk_entry_get_text(GTK_ENTRY(gio->calc_field));
 
 	/* this graph is not active, just update display and redraw */
 	if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(gio->display_button))){
@@ -1523,7 +1524,7 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 	if(gio->io->count_type==COUNT_TYPE_ADVANCED){
 		/* warn and bail out if there was no field specified */
 		if(field==NULL || field[0]==0){
-			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "You did not specify a field name.");
+			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "You didn't specify a field name.");
 			disable_graph(gio);
 			io_stat_redraw(gio->io);
 			return 0;
@@ -1531,7 +1532,7 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 		/* warn and bail out if the field could not be found */
 		hfi=proto_registrar_get_byname(field);
 		if(hfi==NULL){
-			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "'%s' is not a valid field name.", field);
+			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "'%s' isn't a valid field name.", field);
 			disable_graph(gio);
 			io_stat_redraw(gio->io);
 			return 0;
@@ -1612,7 +1613,7 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 	}
 
 	/* first check if the filter string is valid. */
-	filter=(char *)gtk_entry_get_text(GTK_ENTRY(gio->filter_field));
+	filter=gtk_entry_get_text(GTK_ENTRY(gio->filter_field));
 	if(!dfilter_compile(filter, &dfilter)) {
 		bad_dfilter_alert_box(filter);
 		disable_graph(gio);
@@ -1825,7 +1826,7 @@ create_filter_box(io_stat_graph_t *gio, GtkWidget *box, int num)
 	menu=gtk_menu_new();
 	for(i=0;i<MAX_PLOT_STYLES;i++){
 		menu_item=gtk_menu_item_new_with_label(plot_style_name[i]);
-		OBJECT_SET_DATA(menu_item, "plot_style", i);
+		OBJECT_SET_DATA(menu_item, "plot_style", GINT_TO_POINTER(i));
 		SIGNAL_CONNECT(menu_item, "activate", plot_style_select, &gio->io->graphs[num-1]);
 		gtk_widget_show(menu_item);
 		gtk_menu_append(GTK_MENU(menu), menu_item);
