@@ -1,7 +1,7 @@
 /* ldap_stat.c
  * ldap_stat   2003 Ronnie Sahlberg
  *
- * $Id: ldap_stat.c,v 1.22 2004/06/02 07:12:10 ulfl Exp $
+ * $Id: ldap_stat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -39,8 +39,8 @@
 #include <epan/value_string.h>
 
 #include "tap_menu.h"
-#include "../tap.h"
-#include "../packet-ldap.h"
+#include <epan/tap.h>
+#include <epan/dissectors/packet-ldap.h>
 #include "../register.h"
 #include "../timestats.h"
 #include "compat_macros.h"
@@ -49,7 +49,7 @@
 #include "dlg_utils.h"
 #include "../file.h"
 #include "../globals.h"
-#include "filter_prefs.h"
+#include "filter_dlg.h"
 #include "service_response_time_table.h"
 #include "gtkglobals.h"
 
@@ -81,9 +81,9 @@ ldapstat_reset(void *pldap)
 }
 
 static int
-ldapstat_packet(void *pldap, packet_info *pinfo, epan_dissect_t *edt _U_, void *psi)
+ldapstat_packet(void *pldap, packet_info *pinfo, epan_dissect_t *edt _U_, const void *psi)
 {
-	ldap_call_response_t *ldap=(ldap_call_response_t *)psi;
+	const ldap_call_response_t *ldap=psi;
 	ldapstat_t *fs=(ldapstat_t *)pldap;
 
 	/* we are only interested in reply packets */
@@ -249,10 +249,10 @@ static void
 ldapstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 {
 	GString *str;
-	char *filter;
+	const char *filter;
 
 	str = g_string_new("ldap,srt");
-	filter=(char *)gtk_entry_get_text(GTK_ENTRY(filter_entry));
+	filter=gtk_entry_get_text(GTK_ENTRY(filter_entry));
 	if(filter[0]!=0){
 		g_string_sprintfa(str,",%s", filter);
 	}
