@@ -1,7 +1,7 @@
 /* main.h
  * Global defines, etc.
  *
- * $Id: main.h,v 1.56 2004/06/23 01:38:39 guy Exp $
+ * $Id: main.h 13091 2005-01-17 21:48:51Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -57,6 +57,9 @@
  *  @ingroup windows_group
  */
 
+/** Global capture options. */
+typedef struct capture_options_tag * p_capture_options_t;
+extern p_capture_options_t capture_opts;
 
 /** User requested "Zoom In" by menu or toolbar.
  *
@@ -79,6 +82,13 @@ extern void view_zoom_out_cb(GtkWidget *widget, gpointer data);
  */
 extern void view_zoom_100_cb(GtkWidget *widget, gpointer data);
 
+/** User requested "Protocol Info" by ptree context menu.
+ *
+ * @param widget parent widget (unused)
+ * @param data unused
+ */
+extern void selected_ptree_info_cb(GtkWidget *widget, gpointer data);
+
 /** "Apply as Filter" / "Prepare a Filter" action type. */
 typedef enum {
     MATCH_SELECTED_REPLACE, /**< "Selected" */
@@ -238,7 +248,7 @@ extern gboolean main_filter_packets(capture_file *cf, const gchar *dftext,
     gboolean force);
 
 /** Open a new file coming from drag and drop.
- * @param cf_name the new capture filename
+ * @param selection_data the selection data reported from GTK
  */
 extern void dnd_open_file_cmd(GtkSelectionData *selection_data);
 
