@@ -1,7 +1,7 @@
 /* menu.c
  * Menu routines
  *
- * $Id: menu.c,v 1.208 2004/07/07 16:26:52 ulfl Exp $
+ * $Id: menu.c 13091 2005-01-17 21:48:51Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -34,12 +34,16 @@
 #include "menu.h"
 #include "tap_menu.h"
 #include <epan/packet.h>
-#include <epan/resolv.h>
-#include "prefs.h"
+#include <epan/addr_resolv.h>
+#include <epan/prefs.h>
+#include <epan/tap.h>
+#include <epan/timestamp.h>
+#include <epan/ipproto.h>
+
 #include "about_dlg.h"
 #include "capture_dlg.h"
 #include "color_dlg.h"
-#include "filter_prefs.h"
+#include "filter_dlg.h"
 #include "dlg_utils.h"
 #include "file_dlg.h"
 #include "find_dlg.h"
@@ -61,18 +65,16 @@
 #include "toolbar.h"
 #include "gtkglobals.h"
 #include "register.h"
-#include "../tap.h"
 #include "../menu.h"
-#include "../ipproto.h"
 #include "packet_list.h"
 #include "ethclist.h"
 #include "recent.h"
 #include "../ui_util.h"
 #include "proto_draw.h"
-#include "endpoint_talkers_table.h"
+#include "conversations_table.h"
 #include "hostlist_table.h"
 #include "simple_dialog.h"
-#include <epan/timestamp.h>
+#include "packet_history.h"
 
 GtkWidget *popup_menu_object;
 
@@ -143,6 +145,22 @@ static void auto_scroll_live_cb(GtkWidget *w _U_, gpointer d _U_);
        Item 6: extra data needed for ImageItem and StockItem (gtk2)
     */
 
+/*  As a general GUI guideline, we try to follow the Gnome Human Interface Guidelines, which can be found at:
+    http://developer.gnome.org/projects/gup/hig/1.0/index.html
+    
+Please note: there are some differences between the Gnome HIG menu suggestions and our implementation:
+
+File/Open Recent:   the Gnome HIG suggests putting the list of recently used files as elements into the File menuitem.
+                    As this is ok for only a few items, this will become unhandy for 10 or even more list entries.
+                    For this reason, we use a submenu for this.
+
+File/Close:         the Gnome HIG suggests putting this item just above the Quit item.
+                    This results in unintuitive behaviour as both Close and Quit items are very near together.
+                    By putting the Close item near the open item(s), it better suggests that it will close the 
+                    currently opened/captured file only.
+*/
+
+
 /* main menu */
 static GtkItemFactoryEntry menu_items[] =
 {
@@ -190,10 +208,8 @@ static GtkItemFactoryEntry menu_items[] =
 #endif
     ITEM_FACTORY_STOCK_ENTRY("/Edit/_Find Packet...", "<control>F",
                              find_frame_cb, 0, GTK_STOCK_FIND),
-    ITEM_FACTORY_STOCK_ENTRY("/Edit/Find Ne_xt", "<control>N", find_next_cb,
-                             0, GTK_STOCK_GO_FORWARD),
-    ITEM_FACTORY_STOCK_ENTRY("/Edit/Find Pre_vious", "<control>B",
-                             find_previous_cb, 0, GTK_STOCK_GO_BACK),
+    ITEM_FACTORY_ENTRY("/Edit/Find Ne_xt", "<control>N", find_next_cb, 0, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Edit/Find Pre_vious", "<control>B", find_previous_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Edit/<separator>", NULL, NULL, 0, "<Separator>", NULL),
     ITEM_FACTORY_ENTRY("/Edit/_Time Reference", NULL, NULL, 0, "<Branch>", NULL),
     ITEM_FACTORY_ENTRY("/Edit/Time Reference/Set Time Reference (toggle)", "<control>T", reftime_frame_cb, REFTIME_TOGGLE, NULL, NULL),
@@ -257,12 +273,16 @@ static GtkItemFactoryEntry menu_items[] =
     ITEM_FACTORY_STOCK_ENTRY("/View/_Reload", "<control>R", file_reload_cmd_cb,
                              0, GTK_STOCK_REFRESH),
     ITEM_FACTORY_ENTRY("/_Go", NULL, NULL, 0, "<Branch>", NULL),
+    ITEM_FACTORY_STOCK_ENTRY("/Go/_Back", "<alt>Left",
+                             history_back_cb, 0, GTK_STOCK_GO_BACK),
+    ITEM_FACTORY_STOCK_ENTRY("/Go/_Forward", "<alt>Right",
+                             history_forward_cb, 0, GTK_STOCK_GO_FORWARD),
     ITEM_FACTORY_STOCK_ENTRY("/Go/_Go to Packet...", "<control>G",
                              goto_frame_cb, 0, GTK_STOCK_JUMP_TO),
     ITEM_FACTORY_ENTRY("/Go/Go to _Corresponding Packet", NULL, goto_framenum_cb,
                        0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Go/<separator>", NULL, NULL, 0, "<Separator>", NULL),
-    ITEM_FACTORY_STOCK_ENTRY("/Go/_First Packet", NULL,
+    ITEM_FACTORY_STOCK_ENTRY("/Go/F_irst Packet", NULL,
                              goto_top_frame_cb, 0, GTK_STOCK_GOTO_TOP),
     ITEM_FACTORY_STOCK_ENTRY("/Go/_Last Packet", NULL,
                              goto_bottom_frame_cb, 0, GTK_STOCK_GOTO_BOTTOM),
@@ -272,6 +292,8 @@ static GtkItemFactoryEntry menu_items[] =
                              capture_prep_cb, 0, ETHEREAL_STOCK_CAPTURE_START),
     ITEM_FACTORY_STOCK_ENTRY("/Capture/S_top", "<control>E", capture_stop_cb,
                              0, GTK_STOCK_STOP),
+    ITEM_FACTORY_ENTRY("/Capture/_Interfaces...", NULL,
+                             capture_if_cb, 0, NULL, NULL),
     ITEM_FACTORY_STOCK_ENTRY("/Capture/_Capture Filters...", NULL, cfilter_dialog_cb,
                        0, ETHEREAL_STOCK_CAPTURE_FILTER),
 #endif /* HAVE_LIBPCAP */
@@ -318,28 +340,31 @@ static GtkItemFactoryEntry menu_items[] =
     ITEM_FACTORY_ENTRY("/Statistics/_Protocol Hierarchy", NULL,
                        proto_hier_stats_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Statistics/Conversations", NULL,
-                       init_ett_notebook_cb, 0, NULL, NULL),
+                       init_conversation_notebook_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Statistics/Endpoints", NULL,
                        init_hostlist_notebook_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/_Help", NULL, NULL, 0, "<Branch>", NULL),
     ITEM_FACTORY_STOCK_ENTRY("/Help/_Contents", "F1", help_cb, 0, GTK_STOCK_HELP),
     ITEM_FACTORY_ENTRY("/Help/_Supported Protocols", NULL, supported_cb, 0, NULL, NULL),
 #if (GLIB_MAJOR_VERSION >= 2)
-    /* currently, glib1.x can't start a webbrowser, see webbrowser.c for details */
+#ifdef ETHEREAL_EUG_DIR
+    ITEM_FACTORY_ENTRY("/Help/User's Guide", NULL, url_page_menu_cb, HELP_CONTENT, NULL, NULL),
+#endif
     ITEM_FACTORY_ENTRY("/Help/Manual Pages", NULL, NULL, 0, "<Branch>", NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Ethereal", NULL, url_localpage_cb, LOCALPAGE_MAN_ETHEREAL, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Ethereal Filter", NULL, url_localpage_cb, LOCALPAGE_MAN_ETHEREAL_FILTER, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Ethereal", NULL, url_page_menu_cb, LOCALPAGE_MAN_ETHEREAL, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Ethereal Filter", NULL, url_page_menu_cb, LOCALPAGE_MAN_ETHEREAL_FILTER, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Help/Manual Pages/<separator>", NULL, NULL, 0, "<Separator>", NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Tethereal", NULL, url_localpage_cb, LOCALPAGE_MAN_TETHEREAL, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Mergecap", NULL, url_localpage_cb, LOCALPAGE_MAN_MERGECAP, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Editcap", NULL, url_localpage_cb, LOCALPAGE_MAN_EDITCAP, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Text2pcap", NULL, url_localpage_cb, LOCALPAGE_MAN_TEXT2PCAP, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Tethereal", NULL, url_page_menu_cb, LOCALPAGE_MAN_TETHEREAL, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Mergecap", NULL, url_page_menu_cb, LOCALPAGE_MAN_MERGECAP, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Editcap", NULL, url_page_menu_cb, LOCALPAGE_MAN_EDITCAP, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Manual Pages/Text2pcap", NULL, url_page_menu_cb, LOCALPAGE_MAN_TEXT2PCAP, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Help/Ethereal Online", NULL, NULL, 0, "<Branch>", NULL),
-    ITEM_FACTORY_STOCK_ENTRY("/Help/Ethereal Online/Home Page", NULL, url_onlinepage_cb, ONLINEPAGE_HOME, GTK_STOCK_HOME),
-    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/User's Guide", NULL, url_onlinepage_cb, ONLINEPAGE_USERGUIDE, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/FAQ's", NULL, url_onlinepage_cb, ONLINEPAGE_FAQ, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/Downloads", NULL, url_onlinepage_cb, ONLINEPAGE_DOWNLOAD, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/Example Files", NULL, url_onlinepage_cb, ONLINEPAGE_SAMPLE, NULL, NULL),
+    ITEM_FACTORY_STOCK_ENTRY("/Help/Ethereal Online/Home Page", NULL, url_page_menu_cb, ONLINEPAGE_HOME, GTK_STOCK_HOME),
+    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/Wiki", NULL, url_page_menu_cb, ONLINEPAGE_WIKI, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/User's Guide", NULL, url_page_menu_cb, ONLINEPAGE_USERGUIDE, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/FAQ's", NULL, url_page_menu_cb, ONLINEPAGE_FAQ, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/Downloads", NULL, url_page_menu_cb, ONLINEPAGE_DOWNLOAD, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Help/Ethereal Online/Example Files", NULL, url_page_menu_cb, ONLINEPAGE_SAMPLE_FILES, NULL, NULL),
 #endif
     ITEM_FACTORY_ENTRY("/Help/<separator>", NULL, NULL, 0, "<Separator>", NULL),
     ITEM_FACTORY_ENTRY("/Help/_About Ethereal", NULL, about_ethereal_cb,
@@ -356,8 +381,8 @@ static GtkItemFactoryEntry packet_list_menu_items[] =
     ITEM_FACTORY_ENTRY("/Follow TCP Stream", NULL, follow_stream_cb,
                        0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Decode As...", NULL, decode_as_cb, 0, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Display Filters...", NULL, dfilter_dialog_cb,
-                       0, NULL, NULL),
+    ITEM_FACTORY_STOCK_ENTRY("/Display Filters...", NULL, dfilter_dialog_cb,
+                       0, ETHEREAL_STOCK_DISPLAY_FILTER),
     ITEM_FACTORY_ENTRY("/<separator>", NULL, NULL, 0, "<Separator>", NULL),
     ITEM_FACTORY_ENTRY("/Mark Packet", NULL, mark_frame_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Time Reference", NULL, NULL, 0, "<Branch>", NULL),
@@ -402,11 +427,14 @@ static GtkItemFactoryEntry packet_list_menu_items[] =
 
 static GtkItemFactoryEntry tree_view_menu_items[] =
 {
+/*    ITEM_FACTORY_STOCK_ENTRY("/Online Protocol Info", NULL, selected_ptree_info_cb,
+                       0, GTK_STOCK_DIALOG_QUESTION),
+    ITEM_FACTORY_ENTRY("/<separator>", NULL, NULL, 0, "<Separator>", NULL),*/
     ITEM_FACTORY_ENTRY("/Follow TCP Stream", NULL, follow_stream_cb,
                        0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Decode As...", NULL, decode_as_cb, 0, NULL, NULL),
-    ITEM_FACTORY_ENTRY("/Display Filters...", NULL, dfilter_dialog_cb,
-                       0, NULL, NULL),
+    ITEM_FACTORY_STOCK_ENTRY("/Display Filters...", NULL, dfilter_dialog_cb,
+                       0, ETHEREAL_STOCK_DISPLAY_FILTER),
     ITEM_FACTORY_ENTRY("/<separator>", NULL, NULL, 0, "<Separator>", NULL),
     ITEM_FACTORY_ENTRY("/_Resolve Name", NULL, resolve_name_cb, 0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/_Go to Corresponding Packet", NULL, goto_framenum_cb, 0, NULL, NULL),
@@ -455,6 +483,8 @@ static GtkItemFactoryEntry hexdump_menu_items[] =
     ITEM_FACTORY_ENTRY("/Display Filters...", NULL, dfilter_dialog_cb,
                        0, NULL, NULL),
     ITEM_FACTORY_ENTRY("/Export Selected Packet Bytes...", NULL, savehex_cb,
+                       0, NULL, NULL),
+    ITEM_FACTORY_ENTRY("/Copy Packet Bytes into Clipboard", NULL, copy_hex_cb,
                        0, NULL, NULL)
 };
 
@@ -1021,9 +1051,9 @@ add_menu_recent_capture_file_absolute(gchar *cf_name) {
 
 
 	normalized_cf_name = g_strdup(cf_name);
-#ifdef WIN32
-    /* replace all slashes by backslashes */
-    g_strdelimit(normalized_cf_name, "/", '\\');
+#ifdef _WIN32
+	/* replace all slashes by backslashes */
+	g_strdelimit(normalized_cf_name, "/", '\\');
 #endif
 
 	/* get the submenu container item */
@@ -1044,15 +1074,15 @@ add_menu_recent_capture_file_absolute(gchar *cf_name) {
 		 * already in the list or 
 		 * this element is above maximum count (too old), remove it */
 		if (!widget_cf_name ||
-#ifdef WIN32
-            /* do a case insensitive compare on win32 */
+#ifdef _WIN32
+		    /* do a case insensitive compare on win32 */
 #if GLIB_MAJOR_VERSION < 2
-            g_strncasecmp(widget_cf_name, normalized_cf_name, 1000) == 0 ||
+		    g_strncasecmp(widget_cf_name, normalized_cf_name, 1000) == 0 ||
 #else
-            g_ascii_strncasecmp(widget_cf_name, normalized_cf_name, 1000) == 0 ||
+		    g_ascii_strncasecmp(widget_cf_name, normalized_cf_name, 1000) == 0 ||
 #endif
-#else   /* WIN32 */
-            /* do a case sensitive compare on unix */
+#else   /* _WIN32 */
+		    /* do a case sensitive compare on unix */
 		    strncmp(widget_cf_name, normalized_cf_name, 1000) == 0 ||
 #endif
 		    cnt >= prefs.gui_recent_files_count_max) {
@@ -1491,8 +1521,10 @@ set_menus_for_capture_in_progress(gboolean capture_in_progress)
       !capture_in_progress);
   set_menu_sensitivity(main_menu_factory, "/Capture/Stop",
       capture_in_progress);
-#endif /* HAVE_LIBPCAP */
   set_toolbar_for_capture_in_progress(capture_in_progress);
+
+  set_capture_if_dialog_for_capture_in_progress(capture_in_progress);
+#endif /* HAVE_LIBPCAP */
 }
 
 /* Enable or disable menu items based on whether you have some captured
@@ -1805,6 +1837,8 @@ set_menus_for_selected_tree_row(capture_file *cf)
 	  properties);
 	set_menu_sensitivity(main_menu_factory, "/View/Expand Tree", cf->finfo_selected->tree_type != -1);
 	set_menu_sensitivity(tree_view_menu_factory, "/Expand Tree", cf->finfo_selected->tree_type != -1);
+/*	set_menu_sensitivity(tree_view_menu_factory, "/Online Protocol Info",
+	  TRUE);*/
   } else {
 	set_menu_sensitivity(main_menu_factory,
 	    "/Go/Go to Corresponding Packet", FALSE);
@@ -1818,7 +1852,18 @@ set_menus_for_selected_tree_row(capture_file *cf)
 	  FALSE);
 	set_menu_sensitivity(main_menu_factory, "/View/Expand Tree", FALSE);
 	set_menu_sensitivity(tree_view_menu_factory, "/Expand Tree", FALSE);
+/*	set_menu_sensitivity(tree_view_menu_factory, "/Online Protocol Info",
+	  FALSE);*/
   }
 
   walk_menu_tree_for_selected_tree_row(tap_menu_tree_root, cf->finfo_selected);
 }
+
+void set_menus_for_packet_history(gboolean back_history, gboolean forward_history) {
+
+  set_menu_sensitivity(main_menu_factory, "/Go/Back", back_history);
+  set_menu_sensitivity(main_menu_factory, "/Go/Forward", forward_history);
+
+  set_toolbar_for_packet_history(back_history, forward_history);
+}
+
