@@ -2,7 +2,7 @@
  * mgcp-statistics for ethereal
  * Copyright 2003 Lars Roland
  *
- * $Id: mgcp_stat.c,v 1.37 2004/06/02 07:12:10 ulfl Exp $
+ * $Id: mgcp_stat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -40,7 +40,7 @@
 #include <epan/value_string.h>
 
 #include "tap_menu.h"
-#include "../tap.h"
+#include <epan/tap.h>
 #include "../register.h"
 #include "../plugins/mgcp/packet-mgcp.h"
 #include "../timestats.h"
@@ -110,10 +110,10 @@ mgcpstat_reset(void *pms)
 
 
 static int
-mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, void *pmi)
+mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, const void *pmi)
 {
 	mgcpstat_t *ms=(mgcpstat_t *)pms;
-	mgcp_info_t *mi=pmi;
+	const mgcp_info_t *mi=pmi;
 	nstime_t delta;
 
 	switch (mi->mgcp_type) {
