@@ -1,7 +1,7 @@
 /* packet_list.c
  * packet list related functions   2002 Olivier Abad
  *
- * $Id: packet_list.c,v 1.21 2004/06/17 16:35:25 ulfl Exp $
+ * $Id: packet_list.c 13020 2005-01-13 17:31:33Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -33,19 +33,21 @@
 #include "gtkglobals.h"
 #include "epan/epan.h"
 #include "color.h"
+#include "color_filters.h"
 #include "../ui_util.h"
 #include "ui_util.h"
 #include "main.h"
 #include "menu.h"
-#include "color_utils.h"
-#include "column.h"
+#include "colors.h"
+#include <epan/column.h>
 #include "epan/column_info.h"
 #include "compat_macros.h"
-#include "../prefs.h"
+#include <epan/prefs.h>
 #include "file_dlg.h"
 #include "packet_list.h"
 #include "keys.h"
 #include "font_utils.h"
+#include "packet_history.h"
 
 #include <epan/timestamp.h>
 
@@ -166,6 +168,7 @@ packet_list_compare(EthCList *clist, gconstpointer  ptr1, gconstpointer  ptr2)
     return 0;
 
   case COL_ABS_TIME:
+  case COL_ABS_DATE_TIME:
     return COMPARE_TS(abs_secs, abs_usecs);
 
   case COL_REL_TIME:
@@ -262,6 +265,7 @@ packet_list_select_cb(GtkWidget *w _U_, gint row, gint col _U_, gpointer evt _U_
 
   select_packet(&cfile, row);
   gtk_widget_grab_focus(packet_list);
+  packet_history_add(row);
 }
 
 static void
@@ -321,7 +325,6 @@ static void mark_all_frames(gboolean set) {
   frame_data *fdata;
   
   /* XXX: we might need a progressbar here */
-  cfile.marked_count = 0;	
   for (fdata = cfile.plist; fdata != NULL; fdata = fdata->next) {
     set_frame_mark(set,
 		   fdata,
@@ -576,6 +579,8 @@ packet_list_set_column_titles(void)
 void
 packet_list_clear(void)
 {
+    packet_history_clear();
+
     eth_clist_clear(ETH_CLIST(packet_list));
 }
 
@@ -606,11 +611,11 @@ packet_list_moveto_end(void)
 }
 
 gint
-packet_list_append(gchar *text[], gpointer data)
+packet_list_append(const gchar *text[], gpointer data)
 {
     gint row;
 
-    row = eth_clist_append(ETH_CLIST(packet_list), text);
+    row = eth_clist_append(ETH_CLIST(packet_list), (gchar **)text);
     eth_clist_set_row_data(ETH_CLIST(packet_list), row, data);
     return row;
 }
