@@ -3,7 +3,7 @@
  *
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet_win.c 12131 2004-09-29 02:54:22Z guy $
+ * $Id: packet_win.c 12875 2004-12-30 23:42:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -95,7 +95,7 @@ void new_window_cb(GtkWidget *w _U_)
 {
 #define NewWinTitleLen 1000
   char Title[NewWinTitleLen] = "";
-  char *TextPtr;
+  const char *TextPtr;
   gint tv_size = 95, bv_size = 75;
   GtkWidget *main_w, *main_vbox, *pane,
                       *tree_view, *tv_scrollw,
