@@ -1,6 +1,6 @@
 /* proto_dlg.c
  *
- * $Id: proto_dlg.c,v 1.35 2004/06/10 10:09:58 guy Exp $
+ * $Id: proto_dlg.c 12115 2004-09-27 22:55:15Z guy $
  *
  * Laurent Deniel <laurent.deniel@free.fr>
  *
@@ -31,7 +31,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
-#include "prefs.h"
+#include <epan/prefs.h>
 #include "globals.h"
 #include "main.h"
 #include "util.h"
