@@ -1,7 +1,7 @@
 /* rpc_progs.c
  * rpc_progs   2002 Ronnie Sahlberg
  *
- * $Id: rpc_progs.c,v 1.25 2004/05/23 23:24:06 ulfl Exp $
+ * $Id: rpc_progs.c 12913 2005-01-01 12:49:54Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -38,9 +38,9 @@
 #include <epan/epan.h>
 
 #include "tap_menu.h"
-#include "tap.h"
+#include <epan/tap.h>
 #include "../register.h"
-#include "packet-rpc.h"
+#include <epan/dissectors/packet-rpc.h>
 #include "../globals.h"
 #include "ui_util.h"
 #include "dlg_utils.h"
@@ -81,6 +81,16 @@ typedef struct _rpc_program_t {
 static rpc_program_t *prog_list=NULL;
 
 
+static char *
+rpcprogs_gen_title(void)
+{
+	char *title;
+
+	title = g_strdup_printf("ONC-RPC Program Statistics: %s",
+	    cf_get_display_name(&cfile));
+	return title;
+}
+
 static void
 rpcprogs_reset(void *dummy _U_)
 {
@@ -144,8 +154,9 @@ add_new_program(rpc_program_t *rp)
 
 
 static int
-rpcprogs_packet(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt _U_, rpc_call_info_value *ri)
+rpcprogs_packet(void *dummy _U_, packet_info *pinfo, epan_dissect_t *edt _U_, const void *arg)
 {
+	const rpc_call_info_value *ri = arg;
 	nstime_t delta;
 	rpc_program_t *rp;
 
@@ -322,25 +333,28 @@ win_destroy_cb(void *dummy _U_, gpointer data _U_)
 void
 gtk_rpcprogs_init(char *optarg _U_)
 {
+	char *title_string;
 	GtkWidget *vbox;
 	GtkWidget *stat_label;
 	GtkWidget *tmp;
 	GString *error_string;
-    GtkWidget	*bt_close;
-    GtkWidget	*bbox;
+	GtkWidget *bt_close;
+	GtkWidget *bbox;
 
 	if(win){
 		gdk_window_raise(win->window);
 		return;
 	}
 
-	win=window_new(GTK_WINDOW_TOPLEVEL, "ONC-RPC Program Statistics");
+	title_string = rpcprogs_gen_title();
+	win=window_new(GTK_WINDOW_TOPLEVEL, title_string);
 
 	vbox=gtk_vbox_new(FALSE, 3);
 	gtk_container_add(GTK_CONTAINER(win), vbox);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 12);
 
-	stat_label=gtk_label_new("ONC-RPC Program Statistics");
+	stat_label=gtk_label_new(title_string);
+	g_free(title_string);
 	gtk_box_pack_start(GTK_BOX(vbox), stat_label, FALSE, FALSE, 0);
 
 
@@ -371,7 +385,7 @@ gtk_rpcprogs_init(char *optarg _U_)
 	gtk_table_attach_defaults(GTK_TABLE(table), tmp, 5,6,0,1);
 	gtk_label_set_justify(GTK_LABEL(tmp), GTK_JUSTIFY_RIGHT);
 
-	error_string=register_tap_listener("rpc", win, NULL, (void*)rpcprogs_reset, (void*)rpcprogs_packet, (void*)rpcprogs_draw);
+	error_string=register_tap_listener("rpc", win, NULL, rpcprogs_reset, rpcprogs_packet, rpcprogs_draw);
 	if(error_string){
 		fprintf(stderr, "ethereal: Couldn't register rpc,programs tap: %s\n",
 		    error_string->str);
@@ -380,19 +394,19 @@ gtk_rpcprogs_init(char *optarg _U_)
 	}
 
 	/* Button row. */
-    bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
-    gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
+	bbox = dlg_button_row_new(GTK_STOCK_CLOSE, NULL);
+	gtk_box_pack_start(GTK_BOX(vbox), bbox, FALSE, FALSE, 0);
 
-    bt_close = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
-    window_set_cancel_button(win, bt_close, window_cancel_button_cb);
+	bt_close = OBJECT_GET_DATA(bbox, GTK_STOCK_CLOSE);
+	window_set_cancel_button(win, bt_close, window_cancel_button_cb);
 
-    SIGNAL_CONNECT(win, "delete_event", window_delete_event_cb, NULL);
+	SIGNAL_CONNECT(win, "delete_event", window_delete_event_cb, NULL);
 	SIGNAL_CONNECT(win, "destroy", win_destroy_cb, win);
 
-    gtk_widget_show_all(win);
-    window_present(win);
+	gtk_widget_show_all(win);
+	window_present(win);
 	
-    redissect_packets(&cfile);
+	redissect_packets(&cfile);
 }
 
 static void
@@ -407,5 +421,5 @@ register_tap_listener_gtkrpcprogs(void)
 	register_ethereal_tap("rpc,programs", gtk_rpcprogs_init);
 
 	register_tap_menu_item("ONC-RPC Programs", REGISTER_TAP_GROUP_NONE,
-        gtk_rpcprogs_cb, NULL, NULL, NULL);
+	gtk_rpcprogs_cb, NULL, NULL, NULL);
 }
