@@ -1,7 +1,7 @@
 /* rtp_stream.c
  * RTP streams summary addition for ethereal
  *
- * $Id: rtp_stream.c,v 1.15 2004/06/29 20:46:29 ulfl Exp $
+ * $Id: rtp_stream.c 12913 2005-01-01 12:49:54Z guy $
  *
  * Copyright 2003, Alcatel Business Systems
  * By Lars Ruoff <lars.ruoff@gmx.net>
@@ -34,9 +34,10 @@
 
 #include "globals.h"
 
-#include "tap.h"
+#include <epan/tap.h>
 #include "register.h"
-#include "packet-rtp.h"
+#include <epan/dissectors/packet-rtp.h>
+
 
 #include "alert_box.h"
 #include "simple_dialog.h"
@@ -52,6 +53,16 @@
 #include <string.h>
 
 
+gchar* address_to_str_w_none(address *addr){
+	
+	if(addr->type==AT_NONE){
+		return "NONE";
+	}
+	else{
+		return(address_to_str(addr));
+	}
+}
+	
 /****************************************************************************/
 /* the one and only global rtpstream_tapinfo_t structure */
 static rtpstream_tapinfo_t the_tapinfo_struct =
@@ -69,9 +80,9 @@ gint rtp_stream_info_cmp(gconstpointer aa, gconstpointer bb)
 		return 0;
 	if (a==NULL || b==NULL)
 		return 1;
-	if ((a->src_addr == b->src_addr)
+	if (ADDRESSES_EQUAL(&(a->src_addr), &(b->src_addr))
 		&& (a->src_port == b->src_port)
-		&& (a->dest_addr == b->dest_addr)
+		&& ADDRESSES_EQUAL(&(a->dest_addr), &(b->dest_addr))
 		&& (a->dest_port == b->dest_port)
 		&& (a->ssrc == b->ssrc))
 		return 0;
@@ -105,9 +116,14 @@ void rtpstream_reset(rtpstream_tapinfo_t *tapinfo)
 	return;
 }
 
+static void rtpstream_reset_cb(void *arg)
+{
+	rtpstream_reset(arg);
+}
+
 /****************************************************************************/
 /* redraw the output */
-void rtpstream_draw(rtpstream_tapinfo_t *tapinfo _U_)
+void rtpstream_draw(void *arg _U_)
 {
 /* XXX: see rtpstream_on_update in rtp_streams_dlg.c for comments
 	gtk_signal_emit_by_name(top_level, "signal_rtpstream_update");
@@ -149,12 +165,12 @@ static void rtp_write_header(rtp_stream_info_t *strinfo, FILE *file)
 	guint16 padding;       /* 2 padding bytes */
 	
 	fprintf(file, "#!rtpplay%s %s/%u\n", RTPFILE_VERSION,
-		ip_to_str((guint8*) &strinfo->dest_addr),
+		address_to_str_w_none(&(strinfo->dest_addr)),
 		strinfo->dest_port);
 
 	start_sec = g_htonl(strinfo->start_sec);
 	start_usec = g_htonl(strinfo->start_usec);
-	source = strinfo->src_addr; /* already is in network order */
+	source = *(strinfo->src_addr.data); /* rtpdump only accepts guint32 as source, will be fake for IPv6 */
 	port = g_htons(strinfo->src_port);
 	padding = 0;
 
@@ -186,18 +202,19 @@ static void rtp_write_sample(rtp_sample_t* sample, FILE* file)
 
 /****************************************************************************/
 /* whenever a RTP packet is seen by the tap listener */
-int rtpstream_packet(rtpstream_tapinfo_t *tapinfo _U_, packet_info *pinfo, epan_dissect_t *edt _U_, struct _rtp_info *rtpinfo _U_)
+static int rtpstream_packet(void *arg, packet_info *pinfo, epan_dissect_t *edt _U_, const void *arg2)
 {
+	rtpstream_tapinfo_t *tapinfo = arg;
+	const struct _rtp_info *rtpinfo = arg2;
 	rtp_stream_info_t tmp_strinfo;
 	rtp_stream_info_t *strinfo = NULL;
 	GList* list;
-
 	rtp_sample_t sample;
 
 	/* gather infos on the stream this packet is part of */
-	g_memmove(&(tmp_strinfo.src_addr), pinfo->src.data, 4);
+	COPY_ADDRESS(&(tmp_strinfo.src_addr), &(pinfo->src));
 	tmp_strinfo.src_port = pinfo->srcport;
-	g_memmove(&(tmp_strinfo.dest_addr), pinfo->dst.data, 4);
+	COPY_ADDRESS(&(tmp_strinfo.dest_addr), &(pinfo->dst));
 	tmp_strinfo.dest_port = pinfo->destport;
 	tmp_strinfo.ssrc = rtpinfo->info_sync_src;
 	tmp_strinfo.pt = rtpinfo->info_payload_type;
@@ -250,6 +267,7 @@ int rtpstream_packet(rtpstream_tapinfo_t *tapinfo _U_, packet_info *pinfo, epan_
 		}
 	}
 	else if (tapinfo->mode == TAP_MARK) {
+
 		if (rtp_stream_info_cmp(&tmp_strinfo, tapinfo->filter_stream_fwd)==0
 			|| rtp_stream_info_cmp(&tmp_strinfo, tapinfo->filter_stream_rev)==0)
 		{
@@ -386,8 +404,8 @@ register_tap_listener_rtp_stream(void)
 		register_ethereal_tap("rtp", rtpstream_init_tap);
 
 		error_string = register_tap_listener("rtp", &the_tapinfo_struct,
-			NULL,
-			(void*)rtpstream_reset, (void*)rtpstream_packet, (void*)rtpstream_draw);
+			NULL, rtpstream_reset_cb, rtpstream_packet,
+			rtpstream_draw);
 
 		if (error_string != NULL) {
 			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
