@@ -3,7 +3,7 @@
  * Helper routines common to all service response time statistics
  * tap.
  *
- * $Id: service_response_time_table.c,v 1.19 2004/06/02 07:12:11 ulfl Exp $
+ * $Id: service_response_time_table.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -106,8 +106,8 @@ srt_sort_column(GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2)
 	int i1, i2;
 	float f1,f2;
 
-	GtkCListRow *row1 = (GtkCListRow *) ptr1;
-	GtkCListRow *row2 = (GtkCListRow *) ptr2;
+	const GtkCListRow *row1 = ptr1;
+	const GtkCListRow *row2 = ptr2;
 
 	text1 = GTK_CELL_TEXT (row1->cell[clist->sort_column])->text;
 	text2 = GTK_CELL_TEXT (row2->cell[clist->sort_column])->text;
@@ -465,7 +465,7 @@ init_srt_table_row(srt_stat_table *rst, int index, char *procedure)
 }
 
 void
-add_srt_table_data(srt_stat_table *rst, int index, nstime_t *req_time, packet_info *pinfo)
+add_srt_table_data(srt_stat_table *rst, int index, const nstime_t *req_time, packet_info *pinfo)
 {
 	srt_procedure_t *rp;
 	nstime_t delta;
