@@ -1,7 +1,7 @@
 /* sip_stat.c
  * sip_stat   2004 Martin Mathieson
  *
- * $Id: sip_stat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: sip_stat.c 12910 2005-01-01 02:57:02Z guy $
  * Copied from http_stat.c
  *
  * Ethereal - Network traffic analyzer
@@ -338,9 +338,9 @@ sipstat_reset(void *psp)
 
 /* Main entry point to SIP tap */
 static int
-sipstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, void *pri)
+sipstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const void *pri)
 {
-    sip_info_value_t *value=pri;
+    const sip_info_value_t *value=pri;
     sipstat_t *sp = (sipstat_t *)psp;
 
     /* Total number of packets, including continuation packets */
