@@ -1,7 +1,7 @@
 /* smb_stat.c
  * smb_stat   2003 Ronnie Sahlberg
  *
- * $Id: smb_stat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: smb_stat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -85,10 +85,10 @@ smbstat_reset(void *pss)
 }
 
 static int
-smbstat_packet(void *pss, packet_info *pinfo, epan_dissect_t *edt _U_, void *psi)
+smbstat_packet(void *pss, packet_info *pinfo, epan_dissect_t *edt _U_, const void *psi)
 {
 	smbstat_t *ss=(smbstat_t *)pss;
-	smb_info_t *si=psi;
+	const smb_info_t *si=psi;
 
 	/* we are only interested in reply packets */
 	if(si->request){
@@ -252,10 +252,10 @@ static void
 smbstat_start_button_clicked(GtkWidget *item _U_, gpointer data _U_)
 {
 	GString *str;
-	char *filter;
+	const char *filter;
 
 	str = g_string_new("smb,srt");
-	filter=(char *)gtk_entry_get_text(GTK_ENTRY(filter_entry));
+	filter=gtk_entry_get_text(GTK_ENTRY(filter_entry));
 	if(filter[0]!=0){
 		g_string_sprintfa(str,",%s", filter);
 	}
