@@ -1,7 +1,7 @@
 /* ui_util.c
  * UI utility routines
  *
- * $Id: ui_util.c,v 1.29 2004/07/07 05:36:10 guy Exp $
+ * $Id: ui_util.c 12918 2005-01-01 23:25:49Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -41,7 +41,7 @@
 
 #include "gtkglobals.h"
 #include "ui_util.h"
-#include "prefs.h"
+#include <epan/prefs.h>
 #include "epan/epan.h"
 #include "../ui_util.h"
 #include "compat_macros.h"
@@ -108,7 +108,7 @@ static gboolean window_geom_load(const gchar *name, window_geometry_t *geom);
 static void
 window_icon_realize_cb (GtkWidget *win, gpointer data _U_)
 {
-#ifndef WIN32
+#ifndef _WIN32
   static GdkPixmap *icon_pmap = NULL;
   static GdkBitmap *icon_mask = NULL;
   GtkStyle         *style;
@@ -139,9 +139,15 @@ window_new(GtkWindowType type, const gchar *title)
 
   /* XXX - which one is the correct default policy? or use a preference for this? */
   /* GTK_WIN_POS_NONE, GTK_WIN_POS_CENTER or GTK_WIN_POS_MOUSE */
+  /* a lot of people dislike GTK_WIN_POS_MOUSE */
 
   /* set the initial position (must be done, before show is called!) */
-  gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_MOUSE);
+#if GTK_MAJOR_VERSION >= 2 	 
+/*  gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_CENTER_ON_PARENT);*/
+#else	 
+/*  gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_CENTER);*/
+#endif
+  gtk_window_set_position(GTK_WINDOW(win), GTK_WIN_POS_NONE);
 
 #if GTK_MAJOR_VERSION < 2
   /* allow window to be shrinked by user, as gtk_widget_set_usize() will set minimum size and */
@@ -161,7 +167,7 @@ window_new_with_geom(GtkWindowType type, const gchar *title, const gchar *geom_n
   window_geometry_t geom;
   GtkWidget *win = window_new(type, title);
 
-  OBJECT_SET_DATA(win, WINDOW_GEOM_KEY, geom_name);
+  OBJECT_SET_DATA(win, WINDOW_GEOM_KEY, (gpointer)geom_name);
 
   /* do we have a previously saved size and position of this window? */
   if(geom_name) {
@@ -511,13 +517,17 @@ window_destroy(GtkWidget *win)
   window_geometry_t geom;
   const gchar *name;
 
-  /* this must be done *before* destroy is running, as the window geometry */
-  /* cannot be retrieved at destroy time (so don't use event "destroy" for this) */
-  window_get_geometry(win, &geom);
+  /* get_geometry must be done *before* destroy is running, as the window geometry
+   * cannot be retrieved at destroy time (so don't use event "destroy" for this) */
+  /* ...and don't do this at all, if we currently have no GdkWindow (e.g. if the 
+   * GtkWidget is hidden) */
+  if(!GTK_WIDGET_NO_WINDOW(win) && GTK_WIDGET_VISIBLE(win)) {
+      window_get_geometry(win, &geom);
 
-  name = OBJECT_GET_DATA(win, WINDOW_GEOM_KEY);
-  if(name) {
-    window_geom_save(name, &geom);
+      name = OBJECT_GET_DATA(win, WINDOW_GEOM_KEY);
+      if(name) {
+        window_geom_save(name, &geom);
+      }
   }
 
   gtk_widget_destroy(win);
@@ -560,8 +570,13 @@ GtkWidget *xpm_to_widget(const char ** xpm) {
 void
 set_main_window_name(gchar *window_name)
 {
-  gtk_window_set_title(GTK_WINDOW(top_level), window_name);
-  gdk_window_set_icon_name(top_level->window, window_name);
+  gchar *title;
+
+  /* use user-defined window title if preference is set */
+  title = create_user_window_title(window_name);
+  gtk_window_set_title(GTK_WINDOW(top_level), title);
+  gdk_window_set_icon_name(top_level->window, title);
+  g_free(title);
 }
 
 
@@ -969,7 +984,7 @@ simple_list_new(gint cols, gchar **titles) {
         G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
     plugins_list = tree_view_new(GTK_TREE_MODEL(store));
     g_object_unref(G_OBJECT(store));
-    gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(plugins_list), (gboolean) titles);
+    gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(plugins_list), (titles != NULL));
     for(i=0; i<cols; i++) {
         renderer = gtk_cell_renderer_text_new();
         column = gtk_tree_view_column_new_with_attributes(titles ? titles[i] : "", renderer,
@@ -982,3 +997,42 @@ simple_list_new(gint cols, gchar **titles) {
     return plugins_list;
 }
 
+extern void
+copy_to_clipboard(GString *str)  
+{
+#if (GTK_MAJOR_VERSION >= 2)
+        GtkClipboard    *cb;
+
+      	cb = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);     /* Get the default clipboard */
+	gtk_clipboard_set_text(cb, str->str, -1);            /* Copy the byte data into the clipboard */
+#else
+        GtkWidget *window;
+        GtkWidget *text;
+
+        window = window_new (GTK_WINDOW_TOPLEVEL,"");
+        text = gtk_text_new (NULL, NULL);                 /* Create the GtkText widget */
+        gtk_container_add (GTK_CONTAINER (window), text); /* Avoid a GTK assertion */
+        gtk_widget_realize (text);   /* Realizing a widget creates a window for it, ready for us to insert some text */
+        gtk_text_insert (GTK_TEXT (text), NULL, NULL, NULL, str->str, -1);
+        gtk_editable_select_region((GtkEditable *)text, 0, -1); /* Select ALL text */
+        gtk_editable_copy_clipboard((GtkEditable *)text); /* Copy the byte data into the clipboard */
+#endif
+}
+
+/*
+ * Create a new window title string with user-defined title preference.
+ * (Or ignore it if unspecified).
+ */
+gchar *
+create_user_window_title(gchar *caption)
+{
+	/* fail-safe */
+	if (caption == NULL)
+		return g_strdup("");
+
+	/* no user-defined title specified */
+	if ((prefs.gui_window_title == NULL) || (*prefs.gui_window_title == '\0'))
+		return g_strdup(caption);
+
+	return g_strdup_printf("%s %s", prefs.gui_window_title, caption);
+}
