@@ -1,8 +1,8 @@
 /* packet-docsis.c
  * Routines for docsis dissection
- * Copyright 2002, Anand V. Narwani <anarwani@cisco.com>
+ * Copyright 2002, Anand V. Narwani <anand[AT]narwani.org>
  *
- * $Id: packet-docsis.c,v 1.11 2003/01/31 03:17:56 guy Exp $
+ * $Id: packet-docsis.c 12593 2004-11-24 09:13:52Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -25,7 +25,7 @@
 
 
 /* This code is based on the DOCSIS 1.1 specification available at:
- * http://www.cablemodem.com/specifications.html
+ * http://www.cablemodem.com/specifications/specifications11.html
  *
  * DOCSIS Captures can be facilitated using the Cable Monitor Feature
  * available on Cisco Cable Modem Termination Systems :
@@ -34,8 +34,15 @@
  * This dissector depends on the presence of a DOCSIS enapsulation type.
  * There is no simple way to distinguish DOCSIS Frames from Ethernet frames,
  * since the frames are copied from the RF interface on the CMTS to
- * a Fast Ethernet interface; Thus a preference was needed to enable
+ * a Fast Ethernet interface; thus a preference was needed to enable
  * the DOCSIS encapsulation type.
+ *
+ * The current CVS version of libpcap allows a link-layer header type to
+ * be specified for some interfaces on some platforms; for Ethernet
+ * interfaces, it allows DOCSIS to be specified.  If an Ethernet capture
+ * is done with a link-layer type of DOCSIS, the file will have a link-
+ * layer type of DLT_DOCSIS; Ethereal will treat the frames in that capture
+ * as DOCSIS frames.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,7 +62,7 @@
 #include <epan/packet.h>
 
 
-#ifndef __ETHEREAL_STATIC__
+#ifndef ENABLE_STATIC
 G_MODULE_EXPORT const gchar version[] = VERSION;
 #endif
 
@@ -115,7 +122,7 @@ static int hf_docsis_ehdr_grants = -1;
 static int hf_docsis_reserved = -1;
 
 static dissector_handle_t docsis_handle;
-static dissector_handle_t eth_handle;
+static dissector_handle_t eth_withoutfcs_handle;
 static dissector_handle_t data_handle;
 static dissector_handle_t docsis_mgmt_handle;
 static dissector_table_t docsis_dissector_table;
@@ -161,10 +168,10 @@ static const value_string fcparm_vals[] = {
   {0x1C, "Concatenation Header"},
   {0, NULL}
 };
-static const value_string ehdron_vals[] = {
-  {0x00, "Extended Header Absent"},
-  {0x01, "Extended Header Present"},
-  {0, NULL}
+
+static const true_false_string ehdron_tfs = {
+  "Extended Header Present",
+  "Extended Header Absent"
 };
 
 static const true_false_string ena_dis_tfs = {
@@ -172,29 +179,16 @@ static const true_false_string ena_dis_tfs = {
   "Disabled"
 };
 
-static const value_string true_false_vals[] = {
-  { 0x00 , "False"},
-  { 0x01 , "True" },
-  { 0x00 , NULL }
+static const true_false_string qind_tfs = {
+  "Rate overrun",
+  "Rate non-overrun"
 };
 
-static const value_string on_off_vals[] = {
-  { 0x00 , "On"},
-  { 0x01 , "Off" },
-  { 0x00 , NULL }
+static const true_false_string odd_even_tfs = {
+  "Odd Key",
+  "Even Key",
 };
 
-static const value_string ena_dis_vals[] = {
-  {0, "Disabled"},
-  {1, "Enabled"},
-  {0, NULL}
-};
-
-static const value_string odd_even_vals[] = {
-  {1, "Odd Key"},
-  {0, "Even Key"},
-  {0, NULL}
-};
 /* Code to actually dissect the packets */
 /* Code to Dissect the extended header */
 static void
@@ -334,7 +328,8 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
   guint8 hdrlen;
   guint16 len_sid;
   tvbuff_t *next_tvb, *mgt_tvb;
-  guint16 pdulen, captured_length, framelen;
+  gint pdulen, captured_length;
+  guint16 framelen;
   gboolean isfrag = FALSE;
 
 /* Set up structures needed to add the protocol subtree and manage it */
@@ -373,7 +368,7 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
   else
     {
       framelen = 6 + len_sid;
-      pdulen = len_sid - ((guint16) (mac_parm & 0xFF));
+      pdulen = len_sid - (mac_parm + 2);
     }
 
 /* if this is a concatenated frame setup the length of the concatenated
@@ -510,33 +505,33 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
     }
 
 /* If this protocol has a sub-dissector call it here, see section 1.8 */
-  if ((fctype == FCTYPE_PACKET) && (len_sid > mac_parm))
+  switch (fctype)
     {
-      next_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
-      call_dissector (eth_handle, next_tvb, pinfo, tree);
-      if (concatlen > 0)
+    case FCTYPE_PACKET:
+      if (pdulen >= 0)
 	{
-	  concatlen = concatlen - framelen;
-	  concatpos += framelen;
+	  if (pdulen > 0)
+	    {
+	      next_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
+	      call_dissector (eth_withoutfcs_handle, next_tvb, pinfo, tree);
+	    }
+	  if (concatlen > 0)
+	    {
+	      concatlen = concatlen - framelen;
+	      concatpos += framelen;
+	    }
 	}
-    }
-
-  if ((fctype == FCTYPE_PACKET) && (pdulen == 0))
-    {
-      if (concatlen > 0)
-        {
-          concatlen = concatlen - framelen;
-          concatpos += framelen;
-        }
-    }
-  if (fctype == FCTYPE_MACSPC)
-    {
+      break;
+    case FCTYPE_MACSPC:
       switch (fcparm)
 	{
 	case 0x00:
 	case 0x01:
-	  mgt_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
-	  call_dissector (docsis_mgmt_handle, mgt_tvb, pinfo, tree);
+	  if (pdulen > 0)
+	    {
+	      mgt_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
+	      call_dissector (docsis_mgmt_handle, mgt_tvb, pinfo, tree);
+	    }
 	  if (concatlen > 0)
 	    {
 	      concatlen = concatlen - framelen;
@@ -550,8 +545,11 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 	  /* For Fragmentation Frames simply dissect using the data
 	   * dissector as we don't handle them yet
 	   */
-	  mgt_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
-	  call_dissector (data_handle, mgt_tvb, pinfo, tree);
+	  if (pdulen > 0)
+	    {
+	      mgt_tvb = tvb_new_subset (tvb, hdrlen, captured_length, pdulen);
+	      call_dissector (data_handle, mgt_tvb, pinfo, tree);
+	    }
 	  if (concatlen > 0)
 	    {
 	      concatlen = concatlen - framelen;
@@ -576,6 +574,7 @@ dissect_docsis (tvbuff_t * tvb, packet_info * pinfo, proto_tree * tree)
 	    col_set_str (pinfo->cinfo, COL_INFO, "Concatenated Frame");
 	  break;
 	}
+      break;
     }
 }
 
@@ -610,7 +609,7 @@ proto_register_docsis (void)
      },
     {&hf_docsis_ehdron,
      {"EHDRON", "docsis.ehdron",
-      FT_UINT8, BASE_HEX, VALS (ehdron_vals), 0x01,
+      FT_BOOLEAN, 8, TFS (&ehdron_tfs), 0x01,
       "Extended Header Presence", HFILL}
      },
     {&hf_docsis_macparm,
@@ -655,12 +654,12 @@ proto_register_docsis (void)
      },
     {&hf_docsis_frag_first,
      {"First Frame", "docsis.frag_first",
-      FT_UINT8, BASE_DEC, VALS(true_false_vals), 0x20,
+      FT_BOOLEAN, 8, NULL, 0x20,
       "First Frame", HFILL}
      },
     {&hf_docsis_frag_last,
      {"Last Frame", "docsis.frag_last",
-      FT_UINT8, BASE_DEC, VALS(true_false_vals), 0x10,
+      FT_BOOLEAN, 8, NULL, 0x10,
       "Last Frame", HFILL}
      },
     {&hf_docsis_frag_seq,
@@ -705,12 +704,12 @@ proto_register_docsis (void)
      },
     {&hf_docsis_ehdr_qind,
      {"Queue Indicator", "docsis.ehdr.qind",
-      FT_UINT8, BASE_DEC, VALS(on_off_vals), 0x80,
+      FT_BOOLEAN, 8, TFS(&qind_tfs), 0x80,
       "Queue Indicator", HFILL}
      },
     {&hf_docsis_ehdr_grants,
      {"Active Grants", "docsis.ehdr.act_grants",
-      FT_UINT8, BASE_DEC, NULL, 0x0,
+      FT_UINT8, BASE_DEC, NULL, 0x7F,
       "Active Grants", HFILL}
      },
     {&hf_docsis_hcs,
@@ -720,12 +719,12 @@ proto_register_docsis (void)
      },
     {&hf_docsis_bpi_en,
      {"Encryption", "docsis.bpi_en",
-      FT_UINT8, BASE_HEX, VALS (ena_dis_vals), 0x80,
+      FT_BOOLEAN, 8, TFS (&ena_dis_tfs), 0x80,
       "BPI Enable", HFILL},
      },
     {&hf_docsis_toggle_bit,
      {"Toggle", "docsis.toggle_bit",
-      FT_UINT8, BASE_HEX, VALS (odd_even_vals), 0x40,
+      FT_BOOLEAN, 8, TFS (&odd_even_tfs), 0x40,
       "Toggle", HFILL},
      },
 
@@ -766,12 +765,12 @@ proto_reg_handoff_docsis (void)
   dissector_add ("wtap_encap", WTAP_ENCAP_DOCSIS, docsis_handle);
 
   docsis_mgmt_handle = find_dissector ("docsis_mgmt");
-  eth_handle = find_dissector ("eth");
+  eth_withoutfcs_handle = find_dissector ("eth_withoutfcs");
 }
 
 /* Start the functions we need for the plugin stuff */
 
-#ifndef __ETHEREAL_STATIC__
+#ifndef ENABLE_STATIC
 
 G_MODULE_EXPORT void
 plugin_reg_handoff (void)
@@ -797,9 +796,12 @@ plugin_reg_handoff (void)
   proto_reg_handoff_docsis_dsdreq ();
   proto_reg_handoff_docsis_regrsp ();
   proto_reg_handoff_docsis_ucd ();
+  proto_reg_handoff_docsis_type29ucd ();
   proto_reg_handoff_docsis_dsareq ();
   proto_reg_handoff_docsis_dsdrsp ();
   proto_reg_handoff_docsis_vsif ();
+  proto_reg_handoff_docsis_intrngreq ();
+
 }
 
 G_MODULE_EXPORT void
@@ -834,10 +836,12 @@ plugin_init (plugin_address_table_t * pat
       proto_register_docsis_dsdreq ();
       proto_register_docsis_regrsp ();
       proto_register_docsis_ucd ();
+      proto_register_docsis_type29ucd ();
       proto_register_docsis_dsareq ();
       proto_register_docsis_dsdrsp ();
       proto_register_docsis_rngreq ();
       proto_register_docsis_vsif ();
+      proto_register_docsis_intrngreq (); 
 
     }
 }
