@@ -3,7 +3,7 @@
  * By Steve Limkemann <stevelim@dgtech.com>
  * Copyright 1998 Steve Limkemann
  *
- * $Id: packet-gryphon.c 12115 2004-09-27 22:55:15Z guy $
+ * $Id: packet-gryphon.c 12550 2004-11-21 03:01:15Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -51,7 +51,7 @@ G_MODULE_EXPORT const gchar version[] = VERSION;
 /*
  * See
  *
- *	http://www.dgtech.com/gryphon/docs/html/
+ *	http://www.dgtech.com/gryphon/sys/www/docs/html/
  */
 
 static int proto_gryphon = -1;
