@@ -6,7 +6,7 @@
  * Extended by Jan Kiszka <jan.kiszka@web.de>
  * Copyright 2003 Jan Kiszka
  *
- * $Id: packet-irda.c,v 1.8 2004/06/30 15:42:24 tuexen Exp $
+ * $Id: packet-irda.c 12140 2004-09-29 22:20:21Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -43,6 +43,8 @@
 #include <gmodule.h>
 #include <epan/packet.h>
 #include <epan/proto.h>
+#include <epan/conversation.h>
+#include <epan/xdlc.h>
 
 #include "plugins/plugin_api_defs.h"
 
