@@ -1,7 +1,7 @@
 /* packet-lwres.c
  * Routines for light weight reslover (lwres, part of BIND9) packet disassembly
  *
- * $Id: packet-lwres.c,v 1.3 2003/09/05 07:44:47 jmayer Exp $
+ * $Id: packet-lwres.c 12140 2004-09-29 22:20:21Z guy $
  *
  * Copyright (c) 2003 by Oleg Terletsky <oleg.terletsky@comverse.com>
  *
@@ -30,13 +30,17 @@
 
 #include "plugins/plugin_api.h"
 #include "moduleinfo.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <gmodule.h>
 #include <ctype.h>
 #include <time.h>
 #include <string.h>
-#include "prefs.h"
+
+#include <epan/packet.h>
+#include <epan/prefs.h>
+
 #include "plugins/plugin_api_defs.h"
 
 #define LWRES_LWPACKET_LENGTH           (4 * 5 + 2 * 4)
