@@ -8,7 +8,7 @@
  *          PKT-SP-EC-MGCP-I09-040113, January 13, 2004, Cable Television 
  *          Laboratories, Inc., http://www.PacketCable.com/
  *
- * $Id: packet-mgcp.c 12139 2004-09-29 19:30:10Z guy $
+ * $Id: packet-mgcp.c 12958 2005-01-05 10:23:26Z guy $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  * Copyright (c) 2004 by Thomas Anders <thomas.anders [AT] blue-cable.de>
@@ -280,7 +280,7 @@ mgcp_call_hash(gconstpointer k)
 {
 	const mgcp_call_info_key* key = (const mgcp_call_info_key*) k;
 
-	return key->transid  + (guint32)(key->conversation);
+	return key->transid  + key->conversation->index;
 }
 
 /*
@@ -1510,7 +1510,7 @@ dissect_mgcp_connectionparams(proto_tree *parent_tree, tvbuff_t *tvb, gint offse
   }
   g_strfreev(typval);
   g_strfreev(tokens);
-
+  g_free(tokenline);
 }
 
 /*
