@@ -2,7 +2,7 @@
  * Routines for OPSI protocol dissection
  * Copyright 2004, Laurent Rabret (France Telecom R&D) <laurent.rabret@i.hate.spams.org>
  *
- * $Id: packet-opsi.c 12364 2004-10-21 02:11:04Z gerald $
+ * $Id: packet-opsi.c 12505 2004-11-10 10:46:40Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -453,6 +453,10 @@ dissect_attributes(tvbuff_t *tvb, proto_tree *opsi_tree, int offset, int length)
 			proto_tree_add_text(ntree, tvb, offset+2, 2, "Length (%d)", attribute_length);
 			opsi_attributes[i].dissect(tvb, ntree, opsi_attributes[i].hf_type_attribute, offset, attribute_length);
 		}
+		if (attribute_length < 4) {
+			/* Length must be at least 4, for the type and length. */
+			break;
+		}
 		offset += attribute_length;
 		length -= attribute_length;
 	}
