@@ -1,7 +1,7 @@
 /* plugin_api.h
  * Routines for Ethereal plugins.
  *
- * $Id: plugin_api.h,v 1.63 2004/06/30 17:57:53 guy Exp $
+ * $Id: plugin_api.h 13010 2005-01-12 21:44:53Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * Copyright 2000 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -41,25 +41,28 @@
 /* file generted by plugin_gen.py */
 #include "Xplugin_api.h"
 
-#endif
-
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/report_err.h>
-#include "prefs.h"
+#include <epan/prefs.h>
 #include "reassemble.h"
-#include "packet-giop.h"
-#include "packet-tpkt.h"
-#include "packet-tcp.h"
-#include "packet-rpc.h"
-#include "tap.h"
+#include <epan/dissectors/packet-giop.h>
+#include <epan/dissectors/packet-tpkt.h>
+#include <epan/dissectors/packet-tcp.h>
+#include <epan/dissectors/packet-rpc.h>
+#include <epan/tap.h>
 #include "asn1.h"
-#include "packet-per.h"
-#include "packet-ber.h"
-#include "xdlc.h"
-#include "crc16.h"
+#include <epan/dissectors/packet-per.h>
+#include <epan/dissectors/packet-ber.h>
+#include <epan/dissectors/packet-rtp.h>
+#include <epan/dissectors/packet-rtcp.h>
+#include <epan/xdlc.h>
+#include <epan/crc16.h>
 #include "epan/except.h"
 #include "epan/filesystem.h"
+#include "epan/dissectors/packet-dcerpc.h"
+
+#endif /* PLUGINS_NEED_ADDRESS_TABLE */
 
 #include "plugin_table.h"
 
