@@ -1,7 +1,7 @@
 /* plugin_api_list.c
  * Used to generate various included files for plugin API
  *
- * $Id: plugin_api_list.c 12265 2004-10-11 18:34:54Z guy $
+ * $Id: plugin_api_list.c 13010 2005-01-12 21:44:53Z ulfl $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -33,6 +33,7 @@
 #include <epan/except.h>
 #include <epan/prefs.h>
 #include "reassemble.h"
+#include <epan/dissectors/packet-dcerpc.h>
 #include <epan/dissectors/packet-giop.h>
 #include <epan/dissectors/packet-per.h>
 #include <epan/dissectors/packet-ber.h>
@@ -53,7 +54,7 @@ void col_append_fstr(column_info*, gint, const gchar*, ...);
 void col_prepend_fstr(column_info*, gint, const gchar*, ...);
 void col_add_str(column_info*, gint, const gchar*);
 void col_append_str(column_info*, gint, const gchar*);
-void col_set_str(column_info*, gint, gchar*);
+void col_set_str(column_info*, gint, const gchar*);
 
 void register_init_routine(void (*func)(void));
 void register_postseq_cleanup_routine(void (*func)(void));
@@ -70,7 +71,7 @@ void conversation_set_dissector(conversation_t *,
 
 int proto_register_protocol(char*, char*, char*);
 void proto_register_field_array(int, hf_register_info*, int);
-void proto_register_subtree_array(int**, int);
+void proto_register_subtree_array(int *const *, int);
 
 void dissector_add(const char *, guint32, dissector_handle_t);
 void dissector_delete(const char *, guint32,
@@ -295,7 +296,7 @@ gboolean show_fragment_tree(fragment_data *, const fragment_items *, proto_tree
 gboolean show_fragment_seq_tree(fragment_data *, const fragment_items *, proto_tree *, packet_info *, tvbuff_t *);
 
 int register_tap(char *);
-void tap_queue_packet(int, packet_info *, void *);
+void tap_queue_packet(int, packet_info *, const void *);
 
 void asn1_open(ASN1_SCK *, tvbuff_t *, int );
 void asn1_close(ASN1_SCK *, int *);
@@ -355,7 +356,7 @@ dissector_table_t find_dissector_table(const char *);
 dissector_handle_t dissector_get_port_handle(dissector_table_t, guint32);
 char *dissector_handle_get_short_name(dissector_handle_t);
 int dissector_handle_get_protocol_index(dissector_handle_t);
-void new_register_dissector(const char *, new_dissector_t, int); 
+void new_register_dissector(const char *, new_dissector_t, int);
 dissector_handle_t new_create_dissector_handle(new_dissector_t, int);
 
 void register_giop_user_module(giop_sub_dissector_t *sub, gchar *name, gchar *module, int sub_proto);
@@ -418,20 +419,20 @@ void report_read_failure(const char *filename, int err);
 
 guint32 dissect_per_bit_string(tvbuff_t*, guint32, packet_info*, proto_tree*, int, int, int);
 
-int dissect_ber_identifier(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, guint8 *class, gboolean *pc, guint32 *tag);
+int dissect_ber_identifier(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint8 *class, gboolean *pc, gint32 *tag);
 int dissect_ber_length(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, guint32 *length, gboolean *ind);
-int dissect_ber_integer(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, guint32 *value);
+int dissect_ber_integer(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, guint32 *value);
 int dissect_ber_boolean(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id);
-int dissect_ber_choice(packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_choice *ch, gint hf_id, gint ett_id);
-int dissect_ber_generalized_time(packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id);
-int dissect_ber_sequence(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence *seq, gint hf_id, gint ett_id);
-int dissect_ber_sequence_of(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence *seq, gint hf_id, gint ett_id);
-int dissect_ber_set_of(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence *seq, gint hf_id, gint ett_id);
+int dissect_ber_choice(packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_choice_t *ch, gint hf_id, gint ett_id);
+int dissect_ber_GeneralizedTime(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id);
+int dissect_ber_sequence(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence_t *seq, gint hf_id, gint ett_id);
+int dissect_ber_sequence_of(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence_t *seq, gint hf_id, gint ett_id);
+int dissect_ber_set_of(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, const ber_sequence_t *seq, gint hf_id, gint ett_id);
 int dissect_ber_octet_string(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, tvbuff_t **tvb_out);
 int dissect_ber_bitstring(gboolean implicit_tag, packet_info *pinfo, proto_tree *parent_tree, tvbuff_t *tvb, int offset, asn_namedbit const *named_bits, gint hf_id, gint ett_id, tvbuff_t **tvb_out);
-int dissect_ber_restricted_string(gboolean implicit_tag, guint32 type, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, tvbuff_t **tvb_out);
+int dissect_ber_restricted_string(gboolean implicit_tag, gint32 type, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, tvbuff_t **tvb_out);
 int dissect_ber_object_identifier(gboolean implicit_tag, packet_info *pinfo, proto_tree *tree, tvbuff_t *tvb, int offset, gint hf_id, char *value_string);
-int get_ber_identifier(tvbuff_t *tvb, int offset, guint8 *class, gboolean *pc, guint32 *tag);
+int get_ber_identifier(tvbuff_t *tvb, int offset, gint8 *class, gboolean *pc, gint32 *tag);
 int get_ber_length(tvbuff_t *tvb, int offset, guint32 *length, gboolean *ind);
 proto_tree* proto_item_get_subtree(proto_item *ti);
 proto_item* proto_tree_get_parent(proto_tree *tree);
@@ -499,3 +500,28 @@ proto_item *proto_tree_add_debug_text(proto_tree *tree, const char *format, ...)
 
 void rtp_add_address(packet_info *pinfo, address *addr, int port, int other_port, gchar *setup_method, guint32 setup_frame_number);
 void rtcp_add_address(packet_info *pinfo, address *addr, int port, int other_port, gchar *setup_method, guint32 setup_frame_number);
+
+GString *register_tap_listener(char *, void *, char *, tap_reset_cb, tap_packet_cb, tap_draw_cb);
+const char *get_datafile_dir(void);
+char* proto_registrar_get_abbrev(int n);
+header_field_info* proto_registrar_get_byname(const char *field_name);
+double fvalue_get_floating(fvalue_t *fv);
+char *fvalue_to_string_repr(fvalue_t *fv, ftrepr_t rtype, char *buf);
+guint32 fvalue_get_integer(fvalue_t *fv);
+
+int dissect_dcerpc_uint8 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                          proto_tree *tree, guint8 *drep,
+                          int hfindex, guint8 *pdata);
+int dissect_dcerpc_uint16 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                           proto_tree *tree, guint8 *drep,
+                           int hfindex, guint16 *pdata);
+int dissect_dcerpc_uint32 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                           proto_tree *tree, guint8 *drep,
+                           int hfindex, guint32 *pdata);
+int dissect_dcerpc_uuid_t (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                           proto_tree *tree, char *drep,
+                           int hfindex, e_uuid_t *pdata);
+void dcerpc_init_uuid (int proto, int ett, e_uuid_t *uuid, guint16 ver, dcerpc_sub_dissector *procs, int opnum_hf);
+int dissect_ndr_uint32 (tvbuff_t *tvb, gint offset, packet_info *pinfo,
+                        proto_tree *tree, guint8 *drep,
+                        int hfindex, guint32 *pdata);
