@@ -1,7 +1,7 @@
 /* reassemble.c
  * Routines for {fragment,segment} reassembly
  *
- * $Id: reassemble.c,v 1.51 2004/06/25 06:16:35 sahlberg Exp $
+ * $Id: reassemble.c 11410 2004-07-18 18:06:47Z gram $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -32,7 +32,7 @@
 
 #include "reassemble.h"
 
-#include "packet-dcerpc.h"
+#include <epan/dissectors/packet-dcerpc.h>
 
 typedef struct _fragment_key {
 	address src;
