@@ -3,7 +3,7 @@
  * Copyright 2003, Michael Lum <mlum [AT] telostech.com>
  * In association with Telos Technology Inc.
  *
- * $Id: tap-ansi_astat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: tap-ansi_astat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -60,16 +60,14 @@ typedef struct _ansi_a_stat_t {
 static int
 ansi_a_stat_packet(
     void			*tapdata,
-    packet_info			*pinfo,
+    packet_info			*pinfo _U_,
     epan_dissect_t		*edt _U_,
-    void			*data)
+    const void			*data)
 {
     ansi_a_stat_t		*stat_p = tapdata;
-    ansi_a_tap_rec_t		*tap_p = data;
+    const ansi_a_tap_rec_t	*tap_p = data;
 
 
-    pinfo = pinfo;
-
     switch (tap_p->pdu_type)
     {
     case BSSAP_PDU_TYPE_BSMAP:
