@@ -3,7 +3,7 @@
  * Copyright 2003, Michael Lum <mlum [AT] telostech.com>
  * In association with Telos Technology Inc.
  *
- * $Id: tap-gsm_astat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: tap-gsm_astat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -66,15 +66,12 @@ typedef struct _gsm_a_stat_t {
 static int
 gsm_a_stat_packet(
     void			*tapdata,
-    packet_info			*pinfo,
+    packet_info			*pinfo _U_,
     epan_dissect_t		*edt _U_,
-    void			*data)
+    const void			*data)
 {
     gsm_a_stat_t		*stat_p = tapdata;
-    gsm_a_tap_rec_t		*tap_p = data;
-
-
-    pinfo = pinfo;
+    const gsm_a_tap_rec_t	*tap_p = data;
 
     switch (tap_p->pdu_type)
     {
