@@ -1,7 +1,7 @@
 /* tap-mgcpstat.c
  * mgcpstat   2003 Lars Roland
  *
- * $Id: tap-mgcpstat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: tap-mgcpstat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -66,10 +66,10 @@ static const value_string mgcp_mesage_type[] = {
 };
 
 static int
-mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, void *pmi)
+mgcpstat_packet(void *pms, packet_info *pinfo, epan_dissect_t *edt _U_, const void *pmi)
 {
 	mgcpstat_t *ms=(mgcpstat_t *)pms;
-	mgcp_info_t *mi=pmi;
+	const mgcp_info_t *mi=pmi;
 	nstime_t delta;
 
 	switch (mi->mgcp_type) {
