@@ -1,7 +1,7 @@
 /* tap-rpcstat.c
  * rpcstat   2002 Ronnie Sahlberg
  *
- * $Id: tap-rpcstat.c 12128 2004-09-29 00:06:36Z guy $
+ * $Id: tap-rpcstat.c 12910 2005-01-01 02:57:02Z guy $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -128,10 +128,10 @@ rpcstat_reset(void *prs)
  * !0: state has changed, call (*draw) sometime later
  */
 static int
-rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, void *pri)
+rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, const void *pri)
 {
 	rpcstat_t *rs=prs;
-	rpc_call_info_value *ri=pri;
+	const rpc_call_info_value *ri=pri;
 	nstime_t delta;
 	rpc_procedure_t *rp;
 
@@ -318,7 +318,7 @@ rpcstat_init(char *optarg)
 	g_hash_table_foreach(rpc_procs, (GHFunc)rpcstat_find_procs, NULL);
 	if(rpc_min_proc==-1){
 		fprintf(stderr,"tethereal: Invalid -z rpc,rrt,%d,%d\n",rpc_program,rpc_version);
-		fprintf(stderr,"   Program:%d version:%d is not supported by tethereal.\n", rpc_program, rpc_version);
+		fprintf(stderr,"   Program:%d version:%d isn't supported by tethereal.\n", rpc_program, rpc_version);
 		exit(1);
 	}
 
