@@ -1,6 +1,6 @@
 /* file_access.c
  *
- * $Id: file_access.c,v 1.14 2004/06/30 06:58:59 guy Exp $
+ * $Id: file_access.c 12258 2004-10-11 07:18:20Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -394,8 +394,8 @@ static const struct file_type_info {
 	  NULL, NULL },
 
 	/* WTAP_FILE_NETTL */
-	{ "HP-UX nettl trace", NULL,
-	  NULL, NULL },
+	{ "HP-UX nettl trace", "nettl",
+	  nettl_dump_can_write_encap, nettl_dump_open },
 
 	/* WTAP_FILE_TOSHIBA */
 	{ "Toshiba Compact ISDN Router snoop trace", NULL,
