@@ -1,6 +1,6 @@
 /* libpcap.c
  *
- * $Id: libpcap.c,v 1.120 2004/06/07 20:28:50 guy Exp $
+ * $Id: libpcap.c 12700 2004-12-09 19:12:28Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -289,7 +289,7 @@ static const struct {
 	{ 121,		WTAP_ENCAP_HHDLC },	/* HiPath HDLC */
 	{ 122,		WTAP_ENCAP_IP_OVER_FC },   /* RFC 2625 IP-over-FC */
 	{ 123,		WTAP_ENCAP_ATM_PDUS },  /* SunATM */
-	{ 127,		WTAP_ENCAP_IEEE_802_11_WLAN_BSD },  /* 802.11 plus BSD WLAN header */
+	{ 127,		WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP },  /* 802.11 plus radiotap WLAN header */
 	{ 128,		WTAP_ENCAP_TZSP },	/* Tazmen Sniffer Protocol */
 	{ 129,		WTAP_ENCAP_ARCNET_LINUX },
 
@@ -335,6 +335,23 @@ static const struct {
 
 	{ 165,		WTAP_ENCAP_BACNET_MS_TP },
 
+	/*
+	 * 166 is reserved for a PPP variant in which the first byte
+	 * of the 0xff03 header, the 0xff, is replaced by a direction
+	 * byte.  I don't know whether any captures look like that,
+	 * but it is used for some Linux IP filtering (ipfilter?).
+	 *
+	 * 167 and 168 are reserved for more Juniper private-chassis-
+	 * internal meta-information.
+	 */
+
+	{ 169,		WTAP_ENCAP_GPRS_LLC },
+
+	/*
+	 * 170 and 171 are reserved for ITU-T G.7041/Y.1303 Generic
+	 * Framing Procedure.
+	 */
+
 	/*
 	 * To repeat:
 	 *
@@ -1152,7 +1169,7 @@ static gboolean libpcap_read(wtap *wth, int *err, gchar **err_info,
 
 	case WTAP_ENCAP_IEEE_802_11:
 	case WTAP_ENCAP_PRISM_HEADER:
-	case WTAP_ENCAP_IEEE_802_11_WLAN_BSD:
+	case WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP:
 	case WTAP_ENCAP_IEEE_802_11_WLAN_AVS:
 		/*
 		 * We don't know whether there's an FCS in this frame or not.
@@ -1266,7 +1283,7 @@ libpcap_seek_read(wtap *wth, long seek_off,
 
 	case WTAP_ENCAP_IEEE_802_11:
 	case WTAP_ENCAP_PRISM_HEADER:
-	case WTAP_ENCAP_IEEE_802_11_WLAN_BSD:
+	case WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP:
 	case WTAP_ENCAP_IEEE_802_11_WLAN_AVS:
 		/*
 		 * We don't know whether there's an FCS in this frame or not.
