@@ -1,6 +1,6 @@
 /* wtap.c
  *
- * $Id: wtap.c 12047 2004-09-19 07:13:52Z guy $
+ * $Id: wtap.c 12678 2004-12-07 17:54:08Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -129,8 +129,8 @@ static const struct encap_type_info {
 	/* WTAP_ENCAP_IEEE_802_11_WITH_RADIO */
 	{ "IEEE 802.11 Wireless LAN with radio information", "ieee-802-11-radio" },
 
-	/* WTAP_ENCAP_IEEE_802_11_WLAN_BSD */
-	{ "IEEE 802.11 plus BSD WLAN header", "ieee-802-11-bsd" },
+	/* WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP */
+	{ "IEEE 802.11 plus radiotap WLAN header", "ieee-802-11-radiotap" },
 
 	/* WTAP_ENCAP_IEEE_802_11_WLAN_AVS */
 	{ "IEEE 802.11 plus AVS WLAN header", "ieee-802-11-avs" },
@@ -257,6 +257,9 @@ static const struct encap_type_info {
 
 	/* WTAP_ENCAP_RAW_ICMPV6 */
 	{ "Raw ICMPv6", "raw-icmpv6" },
+
+	/* WTAP_ENCAP_GPRS_LLC */
+	{ "GPRS LLC", "gprs-llc" },
 };
 
 /* Name that should be somewhat descriptive. */
