@@ -1,6 +1,6 @@
 /* wtap.h
  *
- * $Id: wtap.h,v 1.155 2004/06/07 20:28:51 guy Exp $
+ * $Id: wtap.h 12678 2004-12-07 17:54:08Z guy $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -112,7 +112,7 @@
 #define WTAP_ENCAP_IEEE_802_11			20
 #define WTAP_ENCAP_PRISM_HEADER			21
 #define WTAP_ENCAP_IEEE_802_11_WITH_RADIO	22
-#define WTAP_ENCAP_IEEE_802_11_WLAN_BSD		23
+#define WTAP_ENCAP_IEEE_802_11_WLAN_RADIOTAP	23
 #define WTAP_ENCAP_IEEE_802_11_WLAN_AVS		24
 #define WTAP_ENCAP_SLL				25
 #define WTAP_ENCAP_FRELAY			26
@@ -153,9 +153,12 @@
 #define WTAP_ENCAP_SYMANTEC			61
 #define WTAP_ENCAP_APPLE_IP_OVER_IEEE1394	62
 #define WTAP_ENCAP_BACNET_MS_TP			63
+#define WTAP_ENCAP_RAW_ICMP			64
+#define WTAP_ENCAP_RAW_ICMPV6			65
+#define WTAP_ENCAP_GPRS_LLC			67
 
 /* last WTAP_ENCAP_ value + 1 */
-#define WTAP_NUM_ENCAP_TYPES			64
+#define WTAP_NUM_ENCAP_TYPES			67
 
 /* File types that can be read by wiretap.
    We support writing some many of these file types, too, so we
