@@ -8,6 +8,13 @@
 
 #include "config.h"
 
+/****************** specific to ethereal ********************************/
+/*
+ * Uncomment the following line to restore XML_DO_VALIDITY_CHECKING
+ * behavior which is causing issues on WIN32 platforms. See:
+ * http://www.ethereal.com/lists/ethereal-dev/200410/msg00194.html
+ */
+/* #define ETHEREAL_XML_DO_VALIDITY_CHECKING */
 /****************** From xml headers ************************************/
 
 /*
@@ -121,7 +128,7 @@ extern void xmlCheckVersion(int version);
 #endif
 
 #ifndef LIBXML_DLL_IMPORT
-#if defined(WIN32) && !defined(STATIC)
+#if defined(_WIN32) && !defined(STATIC)
 #define LIBXML_DLL_IMPORT __declspec(dllimport)
 #else
 #define LIBXML_DLL_IMPORT
@@ -188,7 +195,7 @@ typedef enum {
 
 typedef unsigned char xmlChar;
 
-#ifndef WIN32
+#ifndef _WIN32
 #ifndef CHAR
 #define CHAR xmlChar
 #endif
@@ -1088,16 +1095,15 @@ typedef struct {
 	char            *(*xmlGetProp)(xmlNodePtr, char *);
 	int              (*xmlKeepBlanksDefault)(int);
 	int              (*xmlSubstituteEntitiesDefault)(int);
-
-	/* Variables */
-	int              *xmlDoValidityCheckingDefaultValue;
-
+#ifdef ETHEREAL_XML_DO_VALIDITY_CHECKING
+  int              *xmlDoValidityCheckingDefaultValue;
+#endif
 } XML_STUB;
 
 XML_EXTERN XML_STUB XmlStub;
 XML_EXTERN int XmlStubInitialized;
 
-#ifdef WIN32
+#ifdef _WIN32
 /* We're in windows, use the windows filename */
 #define XML_LIBRARY "libxml2.dll"
 #else
@@ -1111,7 +1117,7 @@ XML_EXTERN int XmlStubInitialized;
  * is not installed on the current system.  (Or it's not in
  * the LD path)
  */
-int loadLibXML();
+int loadLibXML(void);
 
 
 
